' //////////////////////////////////////////////////////////////////////
' TITLE: EPM_HDMF_EEPROM_DEMO_010.SPIN 
'
' DESCRIPTION:
'   Demonstrates the features of the Hydra Dense Music Format (HDMF) player.        
'
' AUTHOR:  Eric Moyer
'
' UPDATES: Search the Parallax forums at http://forums.parallax.com for the latest version.
'
' CONTROLS:
'          Two NES gamepads, or a gamepad and the keyboard
'          Press START or <Spacebar> at the GAME OVER screen to return to the options menu.
'
'          Gamepad 0    Function 
'          ---------    ------------------------------------------------------------------------
'          UP           Move cursor up   
'          DOWN         Move cursor down
'          A            Start song
'          B            Stop song
'
' //////////////////////////////////////////////////////////////////////
'
'  Revision History
'
'  Rev  Date      Description
'  ---  --------  ---------------------------------------------------
'  010  05-22-07  Public release         
'
' //////////////////////////////////////////////////////////////////////


'///////////////////////////////////////////////////////////////////////
' CONSTANTS SECTION ////////////////////////////////////////////////////
'///////////////////////////////////////////////////////////////////////

CON

  _clkmode = xtal2 + pll8x            ' enable external clock and pll times 8
  _xinfreq = 10_000_000 + 0000        ' set frequency to 10 MHZ plus some error for xtals that are not exact add 1000-5000 usually works
  _stack = ($1800 + $1800 + 64) >> 2  ' accomodate display memory and stack

  'DEBUG OPTIONS:
  DEBUG__ENABLE_MUSIC_DEBUG     = FALSE

  MAX_SONGS = 10
  
  ' graphics driver and screen constants
  PARAMCOUNT        = 14        
  OFFSCREEN_BUFFER  = $5000           ' offscreen buffer
  ONSCREEN_BUFFER   = $6800           ' onscreen buffer

  ' size of graphics tile map
  X_TILES           = 16
  Y_TILES           = 12
  
  SCREEN_WIDTH      = 256
  SCREEN_HEIGHT     = 192 

  ' Display constants 
  TEXT_LINE_SPACING = 13

  ' angular constants to make object declarations easier
  ANG_0    = $0000
  ANG_360  = $2000
  ANG_240  = ($2000*2/3)
  ANG_180  = ($2000/2)
  ANG_270  = ($2000*3/4)
  ANG_120  = ($2000/3)
  ANG_90   = ($2000/4)
  ANG_60   = ($2000/6)
  ANG_45   = ($2000/8)
  ANG_30   = ($2000/12)
  ANG_22_5 = ($2000/16)
  ANG_15   = ($2000/24)
  ANG_10   = ($2000/36)
  ANG_5    = ($2000/72)
  ANG_1    = ($2000/360)

  ' constants for math functions
  SIN      = 0
  COS      = 1

  ' NES bit encodings
  NES_RIGHT  = %00000001
  NES_LEFT   = %00000010
  NES_DOWN   = %00000100
  NES_UP     = %00001000
  NES_START  = %00010000
  NES_SELECT = %00100000
  NES_B      = %01000000
  NES_A      = %10000000

  'Menu Flags
  MENU_FLAG__A_HELD                 = %00000001
  MENU_FLAG__UP_DOWN_HELD           = %00000010
  MENU_FLAG__REPEAT_GO_TIME_MET     = %00000100
  MENU_FLAG__DO_REPEAT_CLICK        = %00001000


  'Vector drawing commands
  VECTOR_MOVE           = $4000
  VECTOR_DRAW           = $8000
  VECTOR_END            = $0000
   
'///////////////////////////////////////////////////////////////////////
' VARIABLES SECTION ////////////////////////////////////////////////////
'///////////////////////////////////////////////////////////////////////

VAR

    long  tv_status     '0/1/2 = off/visible/invisible           read-only
  long  tv_enable     '0/? = off/on                            write-only
  long  tv_pins       '%ppmmm = pins                           write-only
  long  tv_mode       '%ccinp = chroma,interlace,ntsc/pal,swap write-only
  long  tv_screen     'pointer to screen (words)               write-only
  long  tv_colors     'pointer to colors (longs)               write-only               
  long  tv_hc         'horizontal cells                        write-only
  long  tv_vc         'vertical cells                          write-only
  long  tv_hx         'horizontal cell expansion               write-only
  long  tv_vx         'vertical cell expansion                 write-only
  long  tv_ho         'horizontal offset                       write-only
  long  tv_vo         'vertical offset                         write-only
  long  tv_broadcast  'broadcast frequency (Hz)                write-only
  long  tv_auralcog   'aural fm cog                            write-only

  word  screen[x_tiles * y_tiles] ' storage for screen tile map
  long  colors[64]                ' color look up table

  ' songs
  long song[MAX_SONGS]
  long song_size[MAX_SONGS]                       
  long debug_data[10]

  ' nes gamepad vars
  long nes_buttons
  long button_temp
  
'///////////////////////////////////////////////////////////////////////
' OBJECT DECLARATION SECTION ///////////////////////////////////////////
'///////////////////////////////////////////////////////////////////////
OBJ

  tv    : "EPM_tv_drv_011.spin"                ' Paralax tv driver, modified for 2 color 
  gr    : "EPM_graphics_drv_spacewar_012.spin" ' Paralax graphics driver, modified for 2 color 
  hdmf  : "EPM_HDMF_driver_010.spin"          'HDMF song player
    

'///////////////////////////////////////////////////////////////////////
' EXPORT PUBLICS  //////////////////////////////////////////////////////
'///////////////////////////////////////////////////////////////////////

PUB start | i , dx, dy

  '//// GLOBAL INITIALIZTION
  
  'start tv
  longmove(@tv_status, @tvparams, paramcount)
  tv_screen := @screen
  tv_colors := @colors
  tv.start(@tv_status)

  ' Start keyboard driver
  'key.start(3)

  'start music driver
  if DEBUG__ENABLE_MUSIC_DEBUG
    hdmf.start(@debug_data)
  else
    hdmf.start(0)

  'init debug LED
  DIRA [0] := 1 ' output 
  
  'init colors
  repeat i from 0 to 64
    colors[i] := $00001010 * (i+4) & $F + $FB060C02

  'init tile screen
  repeat dx from 0 to tv_hc - 1
    repeat dy from 0 to tv_vc - 1
      screen[dy * tv_hc + dx] := onscreen_buffer >> 6 + dy + dx * tv_vc + ((dy & $3F) << 10)

  'start and setup graphics
  gr.start
  gr.setup(16, 12, 128, 96, offscreen_buffer)

  '//// MAIN EXECUTION MANAGER
  repeat
    'PlaySong
    Configure_Options 

PUB Configure_Options | i, y, selected_option, string_ptr, num_options, menu_flags, key_repeat_ticks, current_option_mask, done
 
  selected_option := 0
  menu_flags      := 0
  done            := false

  repeat i from 0 to MAX_SONGS -1
    song[i] := 0
 {
 option_strings           byte    "SUNDAY",0
                         byte    "IF IT AINT LOVE",0               
                         byte    "BEALE STREET BLUES",0                         
                         byte    "PRELUDE AND FUGUE IN C MINOR",0                         
                         byte    "FIG LEAF RAG",0     
                         byte    "SUPER MARIO WORLD END",0                                 
                         byte    "KING CHANTICLEER",0                 
                         byte    "SENSATION", 0
                         }
  i:=0
  song[i] := @_song_sunday
  song_size[i++] := @_end_of_ram_songs - @_song_sunday
  
  song[i] := $00008000 | hdmf#EEPROM_ASSET     'If it ain't love  
  ++i
  
  song[i] := $0000b307 | hdmf#EEPROM_ASSET     'Beele street blues    
  song_size[i-1] := song[i]-song[i-1]
  ++i
  
  song[i] := $0000cfd0 | hdmf#EEPROM_ASSET     'Bach   
  song_size[i-1] := song[i]-song[i-1]
  ++i
  
  song[i] := $0000fb15 | hdmf#EEPROM_ASSET     'Fig leaf rag
  song_size[i-1] := song[i]-song[i-1]
  ++i
  
  song[i] := $00013cda | hdmf#EEPROM_ASSET     'Super mario world end     
  song_size[i-1] := song[i]-song[i-1]
  ++i

  song[i] := $00015691 | hdmf#EEPROM_ASSET     'King Chanticleer
  song_size[i-1] := song[i]-song[i-1]
  ++i
  
  song[i] := $0001a71a | hdmf#EEPROM_ASSET     'Sensation
  song_size[i-1] := song[i]-song[i-1]
  song_size[i] := $0471d
  ++i

  

    
  repeat 

    '//// Clear screen
    gr.clear        ' Clear bitmap

    '//// GET USER INPUT
    nes_buttons := NES_Read_Gamepad
    nes_buttons &= $ff
    if nes_buttons == $ff
      nes_buttons := 0
    
    '//// Draw titles
    gr.textmode(1,1,6,1)
    gr.colorwidth(2,0)
    gr.text(-50, 86, @title1_string)
    gr.text(-28, 73, @title2_string)
    gr.text(-110, -74, @title3_string)
    gr.text(-123, -87, @title4_string) 

    '//// Draw options states
    string_ptr := @option_strings
    y := 55
    num_options := 0
    current_option_mask := $00000001
    repeat while (byte[string_ptr] <> $ff)

      '//// Draw option name
      gr.text(-30, y, string_ptr)
      repeat while byte[string_ptr] <> $0
          ++string_ptr
      ++string_ptr

      if song[num_options] & hdmf#EEPROM_ASSET
        gr.text(-74, y, @eeprom_string)
      else
        gr.text(-74, y, @ram_string)     
      
      '//// Draw song size
      Int_To_String(@uint_string_0, song_size[num_options] )
      gr.text(-110, y , @uint_string_0)
      
      '//// Toggle option, if seleted
      '     Note: 'num_options' at this point is really the current option.
      if (nes_buttons & NES_A) and (selected_option == num_options) and not(menu_flags & MENU_FLAG__A_HELD)
         if not DEBUG__ENABLE_MUSIC_DEBUG 
            hdmf.play_song(song[num_options], 0 {hdmf#HDMF__LOOP})
         else
            'Tell hdmf to play the first note  
            debug_data[0] := hdmf#DEBUG_STATE_PLAY_NOTE
            'Start song           
            hdmf.play_song(song[num_options], 0 {hdmf#HDMF__LOOP}) 
            repeat
              'Wait for note to finish  
              repeat while debug_data[0] <> hdmf#DEBUG_STATE_NOTE_DONE

              'Dump the debug data
              gr.clear
              y := 70

              repeat i from 1 to 8 
                Int_To_Hex_String(@hex_string_0, debug_data[i])
                gr.text(-70,y,@hex_string_0)
                gr.finish
                y-= 13

              gr.copy(onscreen_buffer)

              'Wait for 'A' press
              nes_buttons := 0
              repeat while not (nes_buttons & NES_A)
                nes_buttons := NES_Read_Gamepad
              waitcnt(1000000 + cnt)
              repeat while (nes_buttons & NES_A)
                nes_buttons := NES_Read_Gamepad
              waitcnt(1000000 + cnt)

              'Tell hdmf to play next note
              debug_data[0] := hdmf#DEBUG_STATE_PLAY_NOTE     
              
              
            
       
      '//// Advance to next line
      y -= 13
      ++num_options
      current_option_mask <<= 1
    
    '//// Point to current option
    y :=55 -(13 * selected_option)
    gr.vec(-123, y, $0020, ANG_0, @player_ship0)

    '//// PROCESS MENU SELECTION, ON KEY DOWN EVENTS WITH KEY REPEATS
    if menu_flags & MENU_FLAG__UP_DOWN_HELD 
      ++key_repeat_ticks
      if not(nes_buttons & CONSTANT(NES_DOWN | NES_UP))
        menu_flags &= CONSTANT(!(MENU_FLAG__UP_DOWN_HELD | MENU_FLAG__REPEAT_GO_TIME_MET | MENU_FLAG__DO_REPEAT_CLICK))
      if not(menu_flags & MENU_FLAG__REPEAT_GO_TIME_MET) and (key_repeat_ticks => 8)
        menu_flags |= CONSTANT(MENU_FLAG__REPEAT_GO_TIME_MET | MENU_FLAG__DO_REPEAT_CLICK)
      if (menu_flags & MENU_FLAG__REPEAT_GO_TIME_MET) and (key_repeat_ticks => 2)
        menu_flags |= MENU_FLAG__DO_REPEAT_CLICK  
        
    if (not(menu_flags & MENU_FLAG__UP_DOWN_HELD)) or (menu_flags & MENU_FLAG__DO_REPEAT_CLICK)
      if nes_buttons & NES_UP  
        menu_flags |= MENU_FLAG__UP_DOWN_HELD
        if selected_option == 0
          selected_option := num_options - 1
        else
          --selected_option
      if nes_buttons & NES_DOWN  
        menu_flags |= MENU_FLAG__UP_DOWN_HELD  
        if selected_option == num_options - 1
          selected_option := 0
        else
          ++selected_option
      key_repeat_ticks := 0
      menu_flags &= !MENU_FLAG__DO_REPEAT_CLICK

    '//// PROCESS "STOP SONG"
    if (nes_buttons & NES_B)
       hdmf.stop_song      

    '//// PROCESS BUTTON HELD FLAG
    if (nes_buttons & NES_A) 
       menu_flags |= MENU_FLAG__A_HELD
    else 
       menu_flags &= !MENU_FLAG__A_HELD

    '//// COPY BITMAP TO DISPLAY
    gr.copy(onscreen_buffer)

PUB Int_To_Hex_String(str, i) | t, nibble
   
  ' does an sprintf(str, "%08lX", i); job
  ' assumes that '0x' is already in the first 2 character positions of the string
  str+=9
  repeat t from 0 to 7
    nibble := i & $0000000f
    if nibble =< 9
      BYTE[str] := 48 {'0'} + nibble
    else
      BYTE[str] := CONSTANT(65 {'A'} - 10) + nibble
    str--
    i >>= 4

PUB Int_To_String(str, i) | t
   
  ' does an sprintf(str, "%05d", i); job
  str+=4
  repeat t from 0 to 4
    BYTE[str] := 48+(i // 10)
    i/=10
    str--

PUB Signed_Int_To_String(str, i) | t
   
  'Print the sign
  if (i<0)
    i := -i
    BYTE[str] := 45  ' ASCII '-'
  else
    BYTE[str] := 43  ' ASCII '+' 
    
  str+=5
  repeat t from 0 to 4
    BYTE[str] := 48+(i // 10)
    i/=10
    str--
    
PUB Fixed_To_String(str, fixed) | t , i
  ' does an sprintf(str, "%+05.04f", i); job

  'Print the sign
  if (fixed<0)
    fixed := -fixed
    BYTE[str] := 45  ' ASCII '-' 
  else
    BYTE[str] := 43  ' ASCII '+'     
    
  'Print the fractional portion
  str+=10
  i := ((fixed & $0000_FFFF) * 10000) ~>16 'Get the fractional part, and convert to 5 decimal digits of accuracy.
  repeat t from 0 to 3
    BYTE[str] := 48+(i // 10)
    i/=10
    str--
   
  'Print the decimal point
  BYTE[str] := 46  '46 = ASCII Decimal point
  str-- 
   
  'Print the decimal portion
  i:=fixed~>16
  repeat t from 0 to 4
    BYTE[str] := 48+(i // 10)
    i/=10
    str--

' ////////////////////////////////////////////////////////////////////

PUB SinCos(op, angle): xy               
  if (op==COS)
    angle+=$800   

  if angle & $1000 
    if angle & $800
      -angle
    angle |= $7000
    xy := -word[angle << 1]
  else
    if angle & $800
      -angle
    angle |= $7000
    xy := word[angle << 1]

' //////////////////////////////////////////////////////////////////////


PUB NES_Read_Gamepad : nes_bits        |  i

' //////////////////////////////////////////////////////////////////
' NES Game Paddle Read
' //////////////////////////////////////////////////////////////////       
' reads both gamepads in parallel encodes 8-bits for each in format
' right game pad #1 [15..8] : left game pad #0 [7..0]
'
' set I/O ports to proper direction
' P3 = JOY_CLK      (4)
' P4 = JOY_SH/LDn   (5) 
' P5 = JOY_DATAOUT0 (6)
' P6 = JOY_DATAOUT1 (7)
' NES Bit Encoding
'
' RIGHT  = %00000001
' LEFT   = %00000010
' DOWN   = %00000100
' UP     = %00001000
' START  = %00010000
' SELECT = %00100000
' B      = %01000000
' A      = %10000000

' step 1: set I/Os
DIRA [3] := 1 ' output
DIRA [4] := 1 ' output
DIRA [5] := 0 ' input
DIRA [6] := 0 ' input

' step 2: set clock and latch to 0
OUTA [3] := 0 ' JOY_CLK = 0
OUTA [4] := 0 ' JOY_SH/LDn = 0
'Delay(1)

' step 3: set latch to 1
OUTA [4] := 1 ' JOY_SH/LDn = 1
'Delay(1)

' step 4: set latch to 0
OUTA [4] := 0 ' JOY_SH/LDn = 0

' step 5: read first bit of each game pad

' data is now ready to shift out
' first bit is ready 
nes_bits := 0

' left controller
nes_bits := INA[5] | (INA[6] << 8)

' step 7: read next 7 bits
repeat i from 0 to 6
 OUTA [3] := 1 ' JOY_CLK = 1
 'Delay(1)             
 OUTA [3] := 0 ' JOY_CLK = 0
 nes_bits := (nes_bits << 1)
 nes_bits := nes_bits | INA[5] | (INA[6] << 8)

 'Delay(1)             
' invert bits to make positive logic
nes_bits := (!nes_bits & $FFFF)

' //////////////////////////////////////////////////////////////////
' End NES Game Paddle Read
' //////////////////////////////////////////////////////////////////


'///////////////////////////////////////////////////////////////////////
' DATA SECTION /////////////////////////////////////////////////////////
'///////////////////////////////////////////////////////////////////////

DAT


' BLACK HOLES ///////////////////////////////////////////////////////////
{
' black hole initialization
black_x                  long 20,  80, -90 ' x position of each black hole
black_y                  long 50, -60, -10 ' y position of each black hole
black_gravity            long  8,  4,  2   ' single value that is "lumped" parameter that relates to the final "pull"
                                           ' of the black hole relative to the ship's constant mass
}

' STRING STORAGE //////////////////////////////////////////////////////
{
score_string            byte    "Score",0               'text
hiscore_string          byte    "High",0                'text
ships_string            byte    "Ships",0               'text
}

' TV PARAMETERS FOR DRIVER /////////////////////////////////////////////

tvparams                long    0               'status
                        long    1               'enable
                        long    %011_0000       'pins
                        long    %0000           'mode
                        long    0               'screen
                        long    0               'colors
                        long    x_tiles         'hc
                        long    y_tiles         'vc
                        long    10              'hx timing stretch
                        long    1               'vx
                        long    0               'ho
                        long    0               'vo
                        long    55_250_000      'broadcast
                        long    0               'auralcog

' POLYGON OBJECTS ///////////////////////////////////////////////////////
  
player_ship0            word    VECTOR_MOVE + ANG_0             
                        word    50

                        word    VECTOR_DRAW + ANG_120+ANG_10
                        word    50

                        word    VECTOR_DRAW + ANG_180
                        word    10

                        word    VECTOR_DRAW + ANG_240-ANG_10  
                        word    50

                        word    VECTOR_DRAW + ANG_0
                        word    50

                        word    VECTOR_END
                        

fixed_pt_string_0        byte    "-00000.0000",0    'text
int_string_0             byte    "-00000",0         'text
uint_string_0            byte    "00000",0         'text 
hex_string_0             byte    "0X00000000",0     'text
game_over_string         byte    "GAME OVER",0      'text
game_over_restart        byte    "PRESS <START>",0  'text
debug_string             byte    "DEBUG",0          'text
ram_string               byte    "RAM",0            'text
eeprom_string            byte    "EEPROM",0         'text

title1_string            byte    "HDMF - EEPROM DEMO",0                            'text
title2_string            byte    "VERSION 1.0",0                                 'text
title3_string            byte    "WRITTEN BY ERIC MOYER. FOR THE LATEST",0       'text
title4_string            byte    "VERSION SEARCH HTTP://FORUMS.PARALLAX.COM",0   'text
title_start_string       byte    "PRESS <START> TO BEGIN",0                      'text 

options_string           byte    "SONGS",0        'text
                        
option_strings           byte    "SUNDAY",0
                         byte    "IF IT AINT LOVE",0               
                         byte    "BEALE STREET BLUES",0                         
                         byte    "PRELUDE AND FUGUE, C MINOR",0                         
                         byte    "FIG LEAF RAG",0     
                         byte    "SUPER MARIO WORLD END",0                                 
                         byte    "KING CHANTICLEER",0                 
                         byte    "SENSATION", 0     
                         byte    $ff                                'end of option string list
                         

                        
on_string                byte    "ON",0              'text
off_string               byte    "OFF",0             'text

_song_sunday
        byte    $02, $EF, $AD, $79, $35          'Instrument 0
        byte    $FF                              'End of Instrument list
        byte    $00, $02, $2A, $0A, $07
        byte    $00, $22, $0B, $0A, $04
        byte    $01, $41, $5D, $0A, $80, $90
        byte    $00, $62, $4B, $0A, $1C
        byte    $00, $80, $93, $0A, $80, $90
        byte    $00, $A0, $D0, $0A, $80, $90
        byte    $18, $02, $BA, $0A, $0E
        byte    $0B, $23, $3F, $0A, $0B
        byte    $24, $04, $17, $0A, $1A
        byte    $17, $23, $3F, $0A, $0E
        byte    $0B, $02, $BA, $0A, $1C
        byte    $18, $22, $4B, $0A, $0F
        byte    $0B, $01, $88, $0A, $80, $91
        byte    $00, $62, $6E, $0A, $1C
        byte    $00, $20, $A5, $0A, $80, $91
        byte    $00, $41, $06, $0A, $77
        byte    $17, $82, $93, $0A, $11
        byte    $0D, $63, $10, $0A, $1C
        byte    $17, $83, $DC, $0A, $0F
        byte    $0B, $64, $97, $0A, $1C
        byte    $18, $84, $17, $0A, $0B
        byte    $24, $44, $17, $0A, $0F
        byte    $0B, $61, $72, $0A, $80, $90
        byte    $00, $83, $A4, $0A, $1A
        byte    $00, $A0, $9C, $0A, $80, $90
        byte    $00, $01, $06, $0A, $80, $90
        byte    $17, $22, $E4, $0A, $0F
        byte    $0B, $42, $4B, $0A, $1C
        byte    $18, $22, $6E, $0A, $11
        byte    $0C, $42, $93, $0A, $1C
        byte    $18, $22, $BA, $0A, $0F
        byte    $0B, $42, $E4, $0A, $1C
        byte    $17, $23, $10, $0A, $11
        byte    $0D, $41, $5D, $0A, $46
        byte    $00, $83, $3F, $0A, $0C
        byte    $00, $00, $93, $0A, $6C
        byte    $00, $60, $F7, $0A, $6C
        byte    $22, $22, $E4, $0A, $1C
        byte    $18, $83, $10, $0A, $0F
        byte    $0C, $21, $88, $0A, $0B
        byte    $16, $22, $6E, $0A, $30
        byte    $00, $41, $EE, $0A, $30
        byte    $00, $81, $5D, $0A, $30
        byte    $0D, $A0, $C4, $0A, $27
        byte    $22, $03, $10, $0A, $21
        byte    $00, $64, $97, $0A, $3F
        byte    $00, $22, $4B, $0A, $3F
        byte    $00, $40, $41, $0A, $49
        byte    $00, $80, $A5, $0A, $49
        byte    $24, $01, $4A, $0A, $0A
        byte    $00, $A1, $06, $0A, $0A
        byte    $00, $00, $C4, $0A, $0A
        byte    $17, $03, $10, $0A, $37
        byte    $00, $A4, $17, $0A, $4B
        byte    $00, $22, $0B, $0A, $4B
        byte    $00, $62, $93, $0A, $49
        byte    $0C, $40, $31, $0A, $3E
        byte    $23, $81, $4A, $0A, $0A
        byte    $00, $01, $06, $0A, $0A
        byte    $00, $00, $C4, $0A, $0A
        byte    $18, $03, $10, $0A, $15
        byte    $00, $80, $52, $0A, $54
        byte    $0B, $22, $93, $0A, $0A
        byte    $00, $43, $DC, $0A, $0A
        byte    $00, $60, $C4, $0A, $16
        byte    $00, $A1, $EE, $0A, $0A
        byte    $22, $02, $4B, $0A, $1C
        byte    $00, $23, $10, $0A, $1C
        byte    $00, $44, $97, $0A, $1C
        byte    $00, $60, $C4, $0A, $0A
        byte    $00, $A1, $06, $0A, $0A
        byte    $00, $61, $4A, $0A, $0A
        byte    $18, $64, $55, $0A, $11
        byte    $00, $A2, $2A, $0A, $11
        byte    $0C, $02, $0B, $0A, $1C
        byte    $00, $20, $B9, $0A, $4B
        byte    $00, $40, $4E, $0A, $4B
        byte    $18, $61, $B8, $0A, $0B
        byte    $0B, $01, $37, $0A, $0A
        byte    $00, $61, $06, $0A, $0A
        byte    $00, $80, $DC, $0A, $0A
        byte    $17, $01, $B8, $0A, $48
        byte    $00, $61, $5D, $0A, $1A
        byte    $0D, $80, $AF, $0A, $48
        byte    $00, $A0, $49, $0A, $48
        byte    $22, $21, $5D, $0A, $0A
        byte    $00, $41, $26, $0A, $0A
        byte    $00, $60, $F7, $0A, $0A
        byte    $18, $22, $4B, $0A, $69
        byte    $00, $43, $10, $0A, $70
        byte    $00, $61, $88, $0A, $78
        byte    $00, $01, $EE, $0A, $79
        byte    $0B, $80, $F7, $0A, $28
        byte    $00, $A0, $62, $0A, $28
        byte    $24, $80, $DC, $0A, $27
        byte    $00, $A0, $57, $0A, $27
        byte    $22, $80, $C4, $0A, $28
        byte    $00, $A0, $52, $0A, $27
        byte    $24, $22, $4B, $0A, $1C
        byte    $00, $43, $70, $0A, $1C
        byte    $00, $61, $B8, $0A, $1C
        byte    $00, $A0, $3A, $0A, $27
        byte    $00, $00, $93, $0A, $27
        byte    $18, $83, $A4, $0A, $0F
        byte    $00, $21, $D2, $0A, $11
        byte    $0B, $41, $B8, $0A, $1C
        byte    $00, $60, $8B, $0A, $4B
        byte    $00, $00, $37, $0A, $44
        byte    $17, $21, $9F, $0A, $11
        byte    $0D, $41, $88, $0A, $0A
        byte    $00, $82, $2A, $0A, $0A
        byte    $00, $A3, $10, $0A, $0A
        byte    $00, $20, $C4, $0A, $0A
        byte    $00, $20, $DC, $0A, $0A
        byte    $00, $21, $15, $0A, $0A
        byte    $16, $22, $0B, $0A, $0B
        byte    $00, $42, $93, $0A, $0B
        byte    $00, $81, $4A, $0A, $0B
        byte    $00, $A1, $B8, $0A, $0B
        byte    $0C, $01, $06, $0A, $27
        byte    $00, $20, $B9, $0A, $15
        byte    $00, $40, $6E, $0A, $24
        byte    $18, $21, $B8, $0A, $4B
        byte    $00, $62, $4B, $0A, $4B
        byte    $00, $81, $26, $0A, $4B
        byte    $00, $A1, $72, $0A, $4B
        byte    $0B, $40, $B9, $0A, $28
        byte    $00, $00, $49, $0A, $28
        byte    $23, $00, $C4, $0A, $27
        byte    $00, $40, $52, $0A, $27
        byte    $23, $20, $DC, $0A, $28
        byte    $00, $60, $5C, $0A, $28
        byte    $24, $01, $88, $0A, $0B
        byte    $00, $43, $10, $0A, $0B
        byte    $00, $80, $62, $0A, $25
        byte    $00, $A0, $F7, $0A, $25
        byte    $22, $00, $B9, $0A, $27
        byte    $00, $20, $4E, $0A, $27
        byte    $18, $42, $93, $0A, $0F
        byte    $0B, $63, $10, $0A, $0B
        byte    $00, $81, $88, $0A, $0B
        byte    $00, $A0, $49, $0A, $4B
        byte    $24, $02, $E4, $0A, $0B
        byte    $00, $23, $DC, $0A, $0B
        byte    $00, $40, $9C, $0A, $27
        byte    $00, $61, $EE, $0A, $0B
        byte    $17, $03, $70, $0A, $16
        byte    $00, $22, $0B, $0A, $16
        byte    $00, $61, $B8, $0A, $16
        byte    $0B, $80, $A5, $0A, $49
        byte    $00, $40, $41, $0A, $4A
        byte    $18, $03, $70, $0A, $08
        byte    $00, $22, $0B, $0A, $08
        byte    $00, $61, $B8, $0A, $08
        byte    $0C, $01, $B8, $0A, $0A
        byte    $00, $22, $0B, $0A, $0A
        byte    $00, $63, $70, $0A, $0A
        byte    $00, $A0, $C4, $0A, $0A
        byte    $00, $01, $06, $0A, $0A
        byte    $00, $01, $4A, $0A, $0A
        byte    $23, $00, $B9, $0A, $4B
        byte    $00, $20, $4E, $0A, $4B
        byte    $22, $41, $37, $0A, $0A
        byte    $00, $61, $06, $0A, $0A
        byte    $00, $80, $DC, $0A, $0A
        byte    $24, $40, $AF, $0A, $48
        byte    $00, $60, $49, $0A, $48
        byte    $18, $03, $10, $0A, $0B
        byte    $00, $22, $93, $0A, $0B
        byte    $00, $81, $EE, $0A, $0B
        byte    $0B, $01, $5D, $0A, $16
        byte    $00, $20, $F7, $0A, $16
        byte    $00, $80, $C4, $0A, $16
        byte    $17, $02, $6E, $0A, $11
        byte    $00, $21, $D2, $0A, $11
        byte    $0D, $82, $93, $0A, $1A
        byte    $00, $A1, $EE, $0A, $1A
        byte    $00, $40, $62, $0A, $28
        byte    $17, $01, $88, $0A, $11
        byte    $0B, $21, $72, $0A, $1C
        byte    $00, $60, $F7, $0A, $28
        byte    $00, $80, $7B, $0A, $28
        byte    $18, $01, $88, $0A, $11
        byte    $0C, $22, $4B, $0A, $3E
        byte    $00, $41, $EE, $0A, $3D
        byte    $00, $A0, $83, $0A, $48
        byte    $23, $01, $4A, $0A, $0A
        byte    $00, $61, $06, $0A, $0A
        byte    $00, $80, $C4, $0A, $0A
        byte    $17, $02, $0B, $0A, $48
        byte    $00, $61, $B8, $0A, $48
        byte    $00, $81, $88, $0A, $48
        byte    $0B, $20, $41, $0A, $0B
        byte    $24, $21, $4A, $0A, $0A
        byte    $00, $41, $06, $0A, $0A
        byte    $00, $A0, $C4, $0A, $0A
        byte    $17, $23, $10, $0A, $16
        byte    $00, $43, $DC, $0A, $25
        byte    $00, $A1, $EE, $0A, $25
        byte    $00, $02, $93, $0A, $25
        byte    $0C, $60, $C4, $0A, $4A
        byte    $17, $24, $97, $0A, $30
        byte    $00, $83, $10, $0A, $30
        byte    $00, $02, $4B, $0A, $30
        byte    $0C, $41, $4A, $0A, $0A
        byte    $00, $A1, $06, $0A, $0A
        byte    $23, $42, $6E, $0A, $0B
        byte    $00, $A2, $E4, $0A, $0B
        byte    $00, $04, $17, $0A, $0B
        byte    $00, $20, $4E, $0A, $4B
        byte    $00, $80, $B9, $0A, $4B
        byte    $00, $62, $0B, $0A, $0B
        byte    $22, $02, $0B, $0A, $0B
        byte    $00, $42, $6E, $0A, $0B
        byte    $00, $63, $70, $0A, $0B
        byte    $00, $A1, $B8, $0A, $0B
        byte    $00, $00, $DC, $0A, $0A
        byte    $00, $01, $06, $0A, $0A
        byte    $00, $01, $37, $0A, $0A
        byte    $24, $02, $4B, $0A, $20
        byte    $00, $42, $BA, $0A, $3D
        byte    $00, $63, $70, $0A, $3D
        byte    $00, $A0, $49, $0A, $49
        byte    $00, $20, $AF, $0A, $49
        byte    $00, $81, $B8, $0A, $3D
        byte    $23, $01, $26, $0A, $0A
        byte    $00, $00, $F7, $0A, $0A
        byte    $00, $00, $C4, $0A, $0A
        byte    $17, $02, $4B, $0A, $54
        byte    $00, $43, $10, $0A, $54
        byte    $00, $61, $88, $0A, $54
        byte    $00, $81, $EE, $0A, $54
        byte    $0D, $20, $F7, $0A, $27
        byte    $00, $A0, $62, $0A, $27
        byte    $22, $20, $DC, $0A, $27
        byte    $00, $A0, $57, $0A, $27
        byte    $23, $00, $C4, $0A, $49
        byte    $00, $40, $52, $0A, $49
        byte    $17, $23, $70, $0A, $0B
        byte    $00, $62, $4B, $0A, $0B
        byte    $00, $81, $B8, $0A, $0B
        byte    $0D, $21, $5D, $0A, $0A
        byte    $00, $61, $26, $0A, $0A
        byte    $00, $80, $E9, $0A, $0A
        byte    $17, $23, $A4, $0A, $0F
        byte    $00, $61, $D2, $0A, $0F
        byte    $0B, $82, $93, $0A, $1C
        byte    $00, $A3, $70, $0A, $1C
        byte    $00, $01, $B8, $0A, $1C
        byte    $00, $40, $6E, $0A, $28
        byte    $00, $21, $15, $0A, $4B
        byte    $18, $61, $9F, $0A, $11
        byte    $0C, $01, $88, $0A, $0A
        byte    $00, $80, $37, $0A, $25
        byte    $0B, $01, $72, $0A, $0A
        byte    $0D, $01, $5D, $0A, $0A
        byte    $0B, $01, $4A, $0A, $3D
        byte    $00, $41, $06, $0A, $25
        byte    $00, $60, $6E, $0A, $25
        byte    $24, $20, $B9, $0A, $46
        byte    $00, $80, $49, $0A, $0E
        byte    $16, $42, $4B, $0A, $0B
        byte    $00, $62, $0B, $0A, $0B
        byte    $00, $81, $72, $0A, $0B
        byte    $0C, $00, $49, $0A, $0C
        byte    $18, $02, $6E, $0A, $0C
        byte    $00, $41, $37, $0A, $0C
        byte    $0B, $60, $DC, $0A, $16
        byte    $17, $02, $93, $0A, $0C
        byte    $00, $21, $4A, $0A, $0E
        byte    $0D, $00, $F7, $0A, $25
        byte    $00, $40, $62, $0A, $25
        byte    $17, $21, $88, $0A, $0F
        byte    $0B, $61, $4A, $0A, $0B
        byte    $00, $80, $B9, $0A, $28
        byte    $00, $A0, $4E, $0A, $28
        byte    $24, $01, $88, $0A, $1C
        byte    $00, $23, $10, $0A, $1A
        byte    $00, $40, $49, $0A, $49
        byte    $00, $60, $AF, $0A, $49
        byte    $17, $81, $9F, $0A, $0F
        byte    $0B, $01, $B8, $0A, $1D
        byte    $18, $22, $0B, $0A, $28
        byte    $0B, $00, $A5, $0A, $4B
        byte    $00, $80, $41, $0A, $4B
        byte    $17, $41, $06, $0A, $11
        byte    $0D, $21, $37, $0A, $1C
        byte    $17, $41, $4A, $0A, $0F
        byte    $0B, $21, $88, $0A, $1D
        byte    $00, $60, $AF, $0A, $4B
        byte    $00, $A0, $49, $0A, $4B
        byte    $18, $00, $C4, $0A, $11
        byte    $0C, $20, $DC, $0A, $1C
        byte    $18, $01, $06, $0A, $5E
        byte    $00, $40, $C4, $0A, $5E
        byte    $0B, $20, $A5, $0A, $27
        byte    $00, $80, $41, $0A, $27
        byte    $22, $60, $AF, $0A, $28
        byte    $00, $A0, $49, $0A, $28
        byte    $24, $20, $B9, $0A, $27
        byte    $00, $80, $4E, $0A, $27
        byte    $23, $00, $C4, $0A, $27
        byte    $00, $40, $52, $0A, $28
        byte    $24, $20, $DC, $0A, $15
        byte    $00, $60, $7B, $0A, $49
        byte    $17, $04, $97, $0A, $0B
        byte    $00, $22, $4B, $0A, $0B
        byte    $0B, $01, $26, $0A, $0A
        byte    $00, $20, $DC, $0A, $0A
        byte    $18, $03, $DC, $0A, $46
        byte    $00, $22, $E4, $0A, $46
        byte    $00, $41, $EE, $0A, $46
        byte    $0C, $80, $D0, $0A, $15
        byte    $00, $A0, $52, $0A, $49
        byte    $23, $61, $26, $0A, $0A
        byte    $00, $80, $F7, $0A, $0A
        byte    $00, $60, $D0, $0A, $0A
        byte    $17, $03, $3F, $0A, $0F
        byte    $0B, $22, $93, $0A, $0B
        byte    $00, $43, $DC, $0A, $0B
        byte    $00, $61, $EE, $0A, $0B
        byte    $00, $80, $7B, $0A, $49
        byte    $00, $00, $DC, $0A, $16
        byte    $24, $02, $E4, $0A, $0B
        byte    $00, $24, $17, $0A, $0B
        byte    $00, $42, $0B, $0A, $0B
        byte    $00, $60, $DC, $0A, $0A
        byte    $00, $A1, $26, $0A, $0A
        byte    $18, $04, $97, $0A, $0B
        byte    $00, $23, $3F, $0A, $0B
        byte    $00, $42, $4B, $0A, $0B
        byte    $0B, $00, $D0, $0A, $49
        byte    $00, $20, $52, $0A, $4B
        byte    $17, $45, $27, $0A, $27
        byte    $00, $62, $93, $0A, $16
        byte    $0C, $81, $4A, $0A, $0A
        byte    $00, $A1, $26, $0A, $0A
        byte    $00, $60, $F7, $0A, $0A
        byte    $18, $63, $10, $0A, $49
        byte    $00, $83, $DC, $0A, $49
        byte    $00, $A1, $EE, $0A, $49
        byte    $00, $42, $93, $0A, $49
        byte    $0B, $01, $15, $0A, $16
        byte    $00, $20, $6E, $0A, $48
        byte    $23, $01, $4A, $0A, $0A
        byte    $00, $01, $15, $0A, $0A
        byte    $00, $00, $C4, $0A, $0A
        byte    $17, $03, $3F, $0A, $11
        byte    $0C, $42, $4B, $0A, $1C
        byte    $00, $63, $DC, $0A, $1C
        byte    $00, $80, $57, $0A, $4B
        byte    $00, $A0, $D0, $0A, $49
        byte    $18, $01, $EE, $0A, $0F
        byte    $0B, $21, $5D, $0A, $0A
        byte    $00, $43, $3F, $0A, $1C
        byte    $00, $60, $F7, $0A, $0A
        byte    $00, $01, $26, $0A, $0A
        byte    $17, $03, $70, $0A, $63
        byte    $00, $22, $93, $0A, $27
        byte    $00, $62, $2A, $0A, $27
        byte    $0D, $40, $52, $0A, $28
        byte    $17, $81, $B8, $0A, $0A
        byte    $00, $A1, $4A, $0A, $0A
        byte    $00, $21, $15, $0A, $0A
        byte    $0B, $20, $8B, $0A, $27
        byte    $00, $60, $37, $0A, $28
        byte    $23, $40, $93, $0A, $28
        byte    $00, $80, $3E, $0A, $28
        byte    $24, $00, $A5, $0A, $27
        byte    $00, $20, $45, $0A, $27
        byte    $22, $42, $E4, $0A, $1C
        byte    $00, $63, $DC, $0A, $1C
        byte    $00, $82, $0B, $0A, $1C
        byte    $00, $A0, $49, $0A, $46
        byte    $00, $00, $B9, $0A, $16
        byte    $18, $02, $2A, $0A, $11
        byte    $0C, $21, $06, $0A, $0A
        byte    $00, $42, $4B, $0A, $1C
        byte    $00, $60, $B9, $0A, $0A
        byte    $00, $80, $DC, $0A, $0A
        byte    $18, $03, $70, $0A, $57
        byte    $00, $22, $93, $0A, $57
        byte    $00, $61, $B8, $0A, $57
        byte    $0B, $40, $C4, $0A, $4B
        byte    $00, $80, $6E, $0A, $4B
        byte    $24, $A1, $4A, $0A, $0A
        byte    $00, $A1, $06, $0A, $0A
        byte    $00, $A0, $DC, $0A, $0A
        byte    $22, $A0, $B9, $0A, $27
        byte    $00, $40, $49, $0A, $27
        byte    $18, $04, $97, $0A, $0B
        byte    $00, $22, $4B, $0A, $0B
        byte    $0B, $00, $C4, $0A, $28
        byte    $00, $20, $52, $0A, $28
        byte    $17, $43, $DC, $0A, $11
        byte    $0D, $62, $4B, $0A, $1C
        byte    $00, $84, $97, $0A, $1C
        byte    $00, $A0, $57, $0A, $27
        byte    $00, $00, $D0, $0A, $27
        byte    $17, $23, $A4, $0A, $0E
        byte    $0B, $41, $EE, $0A, $0B
        byte    $00, $63, $DC, $0A, $0A
        byte    $00, $80, $5C, $0A, $29
        byte    $00, $20, $DC, $0A, $28
        byte    $24, $02, $4B, $0A, $29
        byte    $00, $42, $BA, $0A, $29
        byte    $00, $63, $70, $0A, $0F
        byte    $00, $A0, $62, $0A, $48
        byte    $00, $20, $F7, $0A, $46
        byte    $00, $81, $B8, $0A, $08
        byte    $0B, $81, $B8, $0A, $08
        byte    $05, $63, $70, $0A, $08
        byte    $06, $81, $B8, $0A, $08
        byte    $07, $63, $70, $0A, $2C
        byte    $04, $81, $B8, $0A, $28
        byte    $01, $01, $5D, $0A, $0A
        byte    $00, $41, $26, $0A, $0A
        byte    $00, $00, $C4, $0A, $0A
        byte    $23, $01, $D2, $0A, $1D
        byte    $00, $43, $10, $0A, $1C
        byte    $00, $20, $A5, $0A, $28
        byte    $00, $A1, $88, $0A, $28
        byte    $17, $61, $EE, $0A, $12
        byte    $0D, $02, $0B, $0A, $1C
        byte    $00, $41, $72, $0A, $29
        byte    $00, $80, $9C, $0A, $28
        byte    $17, $22, $2A, $0A, $0F
        byte    $0B, $03, $10, $0A, $1C
        byte    $00, $60, $93, $0A, $28
        byte    $18, $21, $88, $0A, $0C
        byte    $0C, $01, $37, $0A, $27
        byte    $00, $20, $AF, $0A, $27
        byte    $23, $41, $26, $0A, $25
        byte    $00, $60, $7B, $0A, $25
        byte    $22, $00, $F7, $0A, $27
        byte    $00, $20, $62, $0A, $27
        byte    $18, $43, $DC, $0A, $11
        byte    $0C, $63, $10, $0A, $2E
        byte    $00, $84, $97, $0A, $3E
        byte    $00, $A2, $4B, $0A, $3E
        byte    $00, $00, $52, $0A, $49
        byte    $00, $20, $C4, $0A, $15
        byte    $23, $21, $4A, $0A, $0A
        byte    $00, $41, $06, $0A, $0A
        byte    $00, $20, $C4, $0A, $0A
        byte    $17, $23, $10, $0A, $0B
        byte    $00, $44, $17, $0A, $0B
        byte    $00, $62, $0B, $0A, $0B
        byte    $00, $82, $93, $0A, $0B
        byte    $0D, $20, $41, $0A, $15
        byte    $22, $01, $4A, $0A, $0A
        byte    $00, $21, $06, $0A, $0A
        byte    $00, $40, $C4, $0A, $0A
        byte    $18, $03, $10, $0A, $0B
        byte    $00, $23, $DC, $0A, $0B
        byte    $00, $41, $EE, $0A, $0B
        byte    $00, $62, $93, $0A, $0B
        byte    $0C, $00, $C4, $0A, $15
        byte    $00, $20, $52, $0A, $49
        byte    $16, $04, $97, $0A, $0B
        byte    $00, $43, $10, $0A, $0B
        byte    $00, $62, $4B, $0A, $0B
        byte    $0D, $01, $4A, $0A, $0A
        byte    $00, $41, $06, $0A, $0A
        byte    $00, $60, $C4, $0A, $0A
        byte    $22, $02, $0B, $0A, $1C
        byte    $00, $40, $B9, $0A, $4B
        byte    $00, $60, $4E, $0A, $4B
        byte    $18, $21, $B8, $0A, $27
        byte    $0C, $01, $37, $0A, $0A
        byte    $00, $81, $06, $0A, $0A
        byte    $00, $A0, $DC, $0A, $0A
        byte    $18, $02, $BA, $0A, $49
        byte    $0B, $22, $4B, $0A, $20
        byte    $00, $83, $70, $0A, $3E
        byte    $00, $A1, $B8, $0A, $3E
        byte    $00, $40, $49, $0A, $4B
        byte    $00, $60, $AF, $0A, $4B
        byte    $23, $21, $5D, $0A, $0A
        byte    $00, $21, $26, $0A, $0A
        byte    $00, $20, $F7, $0A, $0A
        byte    $18, $22, $4B, $0A, $4C
        byte    $00, $03, $10, $0A, $4C
        byte    $00, $81, $88, $0A, $4C
        byte    $00, $A1, $EE, $0A, $4C
        byte    $0B, $40, $F7, $0A, $25
        byte    $00, $60, $62, $0A, $25
        byte    $22, $40, $DC, $0A, $28
        byte    $00, $60, $57, $0A, $28
        byte    $24, $00, $C4, $0A, $32
        byte    $00, $20, $52, $0A, $4A
        byte    $1C, $46, $20, $0A, $0A
        byte    $04, $66, $7D, $0A, $08
        byte    $03, $86, $E0, $0A, $1A
        byte    $00, $A4, $97, $0A, $1A
        byte    $00, $43, $70, $0A, $1A
        byte    $17, $07, $49, $0A, $11
        byte    $00, $63, $A4, $0A, $11
        byte    $0D, $43, $70, $0A, $1C
        byte    $00, $86, $E0, $0A, $1C
        byte    $00, $A1, $15, $0A, $49
        byte    $00, $20, $6E, $0A, $49
        byte    $00, $00, $C4, $0A, $49
        byte    $17, $66, $7D, $0A, $16
        byte    $00, $43, $3F, $0A, $0F
        byte    $0B, $83, $10, $0A, $0A
        byte    $0D, $42, $E4, $0A, $0A
        byte    $0B, $42, $BA, $0A, $0A
        byte    $0B, $41, $72, $0A, $4C
        byte    $00, $62, $93, $0A, $27
        byte    $00, $80, $93, $0A, $4C
        byte    $00, $01, $06, $0A, $4C
        byte    $24, $23, $70, $0A, $1C
        byte    $17, $62, $93, $0A, $0F
        byte    $0B, $22, $0B, $0A, $1C
        byte    $00, $A0, $6E, $0A, $4B
        byte    $18, $01, $B8, $0A, $11
        byte    $0C, $21, $72, $0A, $1A
        byte    $18, $01, $4A, $0A, $0F
        byte    $0B, $21, $37, $0A, $1D
        byte    $00, $40, $AF, $0A, $5B
        byte    $00, $60, $62, $0A, $5D
        byte    $17, $01, $4A, $0A, $11
        byte    $0D, $21, $88, $0A, $1A
        byte    $16, $00, $C4, $0A, $12
        byte    $0C, $20, $F7, $0A, $1C
        byte    $18, $01, $4A, $0A, $0C
        byte    $0B, $20, $AF, $0A, $0B
        byte    $00, $40, $62, $0A, $0B
        byte    $24, $00, $A5, $0A, $4A
        byte    $00, $20, $41, $0A, $49
        byte    $17, $40, $C4, $0A, $0F
        byte    $0B, $61, $06, $0A, $1A
        byte    $18, $41, $88, $0A, $0F
        byte    $0C, $61, $26, $0A, $1C
        byte    $00, $80, $7B, $0A, $49
        byte    $17, $00, $F7, $0A, $0F
        byte    $0C, $20, $C4, $0A, $1C
        byte    $17, $01, $37, $0A, $0F
        byte    $0B, $21, $15, $0A, $1C
        byte    $00, $40, $75, $0A, $4B
        byte    $17, $00, $E9, $0A, $11
        byte    $0D, $20, $C4, $0A, $1C
        byte    $17, $00, $9C, $0A, $20
        byte    $0B, $20, $4E, $0A, $49
        byte    $24, $00, $9C, $0A, $0C
        byte    $23, $02, $6E, $0A, $23
        byte    $00, $41, $37, $0A, $49
        byte    $00, $60, $83, $0A, $33
        byte    $17, $23, $A4, $0A, $0B
        byte    $00, $81, $D2, $0A, $0B
        byte    $0B, $21, $06, $0A, $0A
        byte    $00, $80, $D0, $0A, $0A
        byte    $00, $A0, $9C, $0A, $0A
        byte    $18, $02, $6E, $0A, $17
        byte    $0C, $21, $D2, $0A, $0B
        byte    $00, $63, $A4, $0A, $0B
        byte    $00, $80, $34, $0A, $27
        byte    $00, $A0, $83, $0A, $27
        byte    $23, $00, $8B, $0A, $28
        byte    $00, $20, $3A, $0A, $28
        byte    $17, $43, $3F, $0A, $0B
        byte    $00, $62, $6E, $0A, $0B
        byte    $00, $81, $9F, $0A, $0B
        byte    $0D, $43, $10, $0A, $27
        byte    $00, $61, $88, $0A, $27
        byte    $00, $80, $34, $0A, $49
        byte    $22, $01, $06, $0A, $0A
        byte    $00, $21, $D2, $0A, $1C
        byte    $00, $A0, $9C, $0A, $0A
        byte    $00, $40, $D0, $0A, $0A
        byte    $18, $01, $B8, $0A, $11
        byte    $0C, $21, $9F, $0A, $19
        byte    $00, $40, $93, $0A, $29
        byte    $00, $60, $3E, $0A, $29
        byte    $16, $01, $5D, $0A, $0C
        byte    $0D, $01, $26, $0A, $1A
        byte    $00, $20, $7B, $0A, $27
        byte    $17, $41, $72, $0A, $0F
        byte    $0B, $01, $88, $0A, $1C
        byte    $00, $61, $15, $0A, $49
        byte    $00, $80, $75, $0A, $0C
        byte    $18, $21, $9F, $0A, $11
        byte    $0C, $01, $B8, $0A, $1C
        byte    $00, $40, $75, $0A, $0B
        byte    $18, $21, $D2, $0A, $0E
        byte    $0B, $02, $6E, $0A, $1A
        byte    $00, $40, $4E, $0A, $27
        byte    $17, $21, $37, $0A, $33
        byte    $0C, $00, $E9, $0A, $15
        byte    $00, $60, $62, $0A, $27
        byte    $23, $01, $5D, $0A, $1C
        byte    $00, $40, $E9, $0A, $16
        byte    $00, $80, $5C, $0A, $25
        byte    $18, $21, $72, $0A, $11
        byte    $0B, $01, $37, $0A, $28
        byte    $00, $41, $D2, $0A, $0B
        byte    $00, $60, $83, $0A, $28
        byte    $00, $A0, $E9, $0A, $28
        byte    $17, $21, $72, $0A, $0B
        byte    $0C, $21, $5D, $0A, $4B
        byte    $00, $40, $57, $0A, $28
        byte    $18, $02, $BA, $0A, $33
        byte    $00, $62, $0B, $0A, $33
        byte    $00, $81, $B8, $0A, $33
        byte    $0B, $A1, $06, $0A, $28
        byte    $00, $40, $6E, $0A, $28
        byte    $24, $01, $26, $0A, $27
        byte    $00, $20, $75, $0A, $27
        byte    $17, $44, $17, $0A, $0B
        byte    $00, $63, $3F, $0A, $0B
        byte    $00, $82, $4B, $0A, $0B
        byte    $0B, $41, $37, $0A, $27
        byte    $00, $60, $83, $0A, $27
        byte    $18, $03, $3F, $0A, $4B
        byte    $0B, $22, $0B, $0A, $3E
        byte    $00, $84, $17, $0A, $3F
        byte    $00, $A0, $8B, $0A, $28
        byte    $00, $41, $4A, $0A, $28
        byte    $24, $61, $5D, $0A, $27
        byte    $00, $40, $93, $0A, $27
        byte    $17, $A3, $A4, $0A, $11
        byte    $0B, $02, $6E, $0A, $1C
        byte    $00, $23, $10, $0A, $1C
        byte    $00, $84, $17, $0A, $1C
        byte    $00, $40, $9C, $0A, $27
        byte    $00, $61, $88, $0A, $28
        byte    $00, $A2, $0B, $0A, $1C
        byte    $18, $04, $55, $0A, $11
        byte    $00, $22, $2A, $0A, $11
        byte    $0C, $82, $4B, $0A, $1C
        byte    $00, $A4, $97, $0A, $1D
        byte    $00, $40, $8B, $0A, $27
        byte    $00, $61, $5D, $0A, $27
        byte    $18, $04, $DD, $0A, $11
        byte    $00, $22, $6E, $0A, $0F
        byte    $0B, $82, $2A, $0A, $0B
        byte    $00, $A4, $55, $0A, $0B
        byte    $00, $20, $83, $0A, $28
        byte    $00, $41, $37, $0A, $28
        byte    $24, $02, $0B, $0A, $0B
        byte    $00, $64, $17, $0A, $0B
        byte    $00, $80, $9C, $0A, $25
        byte    $00, $A1, $15, $0A, $25
        byte    $16, $01, $9F, $0A, $0F
        byte    $0C, $21, $06, $0A, $27
        byte    $00, $40, $68, $0A, $27
        byte    $18, $01, $9F, $0A, $0F
        byte    $0B, $61, $5D, $0A, $1D
        byte    $00, $80, $E9, $0A, $28
        byte    $00, $A0, $62, $0A, $29
        byte    $17, $01, $37, $0A, $12
        byte    $0D, $21, $9F, $0A, $1C
        byte    $00, $40, $DC, $0A, $4B
        byte    $00, $60, $57, $0A, $0B
        byte    $17, $01, $5D, $0A, $0B
        byte    $0B, $00, $57, $0A, $0B
        byte    $18, $01, $06, $0A, $0F
        byte    $0B, $21, $15, $0A, $08
        byte    $01, $61, $26, $0A, $3E
        byte    $00, $80, $D0, $0A, $29
        byte    $00, $A0, $75, $0A, $27
        byte    $23, $00, $52, $0A, $28
        byte    $17, $21, $5D, $0A, $11
        byte    $0B, $41, $9F, $0A, $1D
        byte    $00, $60, $C4, $0A, $4A
        byte    $00, $80, $4E, $0A, $0B
        byte    $18, $02, $0B, $0A, $0B
        byte    $0C, $00, $4E, $0A, $0B
        byte    $22, $00, $9C, $0A, $4B
        byte    $00, $20, $68, $0A, $4B
        byte    $24, $41, $37, $0A, $0A
        byte    $00, $61, $06, $0A, $0A
        byte    $00, $80, $D0, $0A, $0A
        byte    $23, $41, $15, $0A, $16
        byte    $00, $60, $75, $0A, $49
        byte    $17, $05, $C8, $0A, $0F
        byte    $00, $22, $E4, $0A, $0F
        byte    $0B, $43, $10, $0A, $19
        byte    $00, $86, $20, $0A, $1A
        byte    $00, $A1, $37, $0A, $0A
        byte    $00, $00, $E9, $0A, $0A
        byte    $00, $21, $15, $0A, $0A
        byte    $18, $07, $49, $0A, $11
        byte    $00, $23, $A4, $0A, $11
        byte    $0C, $46, $7D, $0A, $1C
        byte    $00, $83, $3F, $0A, $1A
        byte    $18, $04, $DD, $0A, $0E
        byte    $00, $22, $6E, $0A, $0E
        byte    $0B, $42, $93, $0A, $1C
        byte    $00, $65, $27, $0A, $1A
        byte    $00, $81, $9F, $0A, $0A
        byte    $00, $A1, $06, $0A, $0A
        byte    $00, $01, $37, $0A, $0A
        byte    $17, $05, $75, $0A, $0F
        byte    $00, $22, $BA, $0A, $0F
        byte    $0D, $46, $20, $0A, $1C
        byte    $00, $63, $10, $0A, $1A
        byte    $17, $05, $75, $0A, $0B
        byte    $00, $22, $BA, $0A, $0B
        byte    $0B, $01, $5D, $0A, $0A
        byte    $00, $21, $37, $0A, $0A
        byte    $00, $41, $06, $0A, $0A
        byte    $18, $02, $2A, $0A, $32
        byte    $0C, $21, $15, $0A, $27
        byte    $00, $40, $75, $0A, $25
        byte    $23, $61, $D2, $0A, $1C
        byte    $00, $80, $E9, $0A, $28
        byte    $17, $01, $72, $0A, $0F
        byte    $0B, $21, $88, $0A, $1D
        byte    $00, $40, $C4, $0A, $16
        byte    $00, $60, $4E, $0A, $37
        byte    $18, $01, $D2, $0A, $11
        byte    $0C, $21, $15, $0A, $0A
        byte    $00, $42, $0B, $0A, $0E
        byte    $00, $80, $C4, $0A, $0A
        byte    $00, $A0, $E9, $0A, $0A
        byte    $23, $01, $D2, $0A, $20
        byte    $00, $22, $6E, $0A, $32
        byte    $00, $40, $4E, $0A, $3A
        byte    $00, $61, $88, $0A, $3B
        byte    $24, $01, $15, $0A, $0A
        byte    $00, $80, $9C, $0A, $0A
        byte    $16, $01, $9F, $0A, $08
        byte    $01, $22, $6E, $0A, $57
        byte    $00, $41, $B8, $0A, $57
        byte    $00, $61, $5D, $0A, $57
        byte    $0B, $01, $06, $0A, $27
        byte    $00, $80, $6E, $0A, $25
        byte    $23, $A0, $DC, $0A, $28
        byte    $00, $80, $57, $0A, $28
        byte    $23, $00, $D0, $0A, $27
        byte    $00, $80, $75, $0A, $27
        byte    $18, $24, $17, $0A, $0B
        byte    $00, $42, $BA, $0A, $0B
        byte    $00, $62, $0B, $0A, $0B
        byte    $0B, $20, $B9, $0A, $28
        byte    $00, $40, $4E, $0A, $28
        byte    $17, $03, $3F, $0A, $12
        byte    $0D, $62, $BA, $0A, $2F
        byte    $00, $84, $17, $0A, $2F
        byte    $00, $A2, $0B, $0A, $2F
        byte    $00, $20, $49, $0A, $16
        byte    $00, $40, $AF, $0A, $27
        byte    $22, $00, $B9, $0A, $27
        byte    $00, $20, $49, $0A, $27
        byte    $18, $44, $17, $0A, $0B
        byte    $00, $63, $10, $0A, $0B
        byte    $00, $82, $0B, $0A, $0B
        byte    $0B, $40, $C4, $0A, $28
        byte    $00, $60, $4E, $0A, $28
        byte    $17, $03, $A4, $0A, $11
        byte    $0D, $23, $10, $0A, $37
        byte    $00, $84, $17, $0A, $2E
        byte    $00, $A2, $0B, $0A, $2E
        byte    $00, $00, $45, $0A, $27
        byte    $00, $40, $AF, $0A, $27
        byte    $22, $60, $9C, $0A, $28
        byte    $00, $00, $41, $0A, $28
        byte    $18, $24, $17, $0A, $0B
        byte    $00, $42, $0B, $0A, $0C
        byte    $0C, $20, $8B, $0A, $27
        byte    $00, $40, $4E, $0A, $27
        byte    $18, $03, $DC, $0A, $11
        byte    $0B, $64, $17, $0A, $1A
        byte    $00, $82, $0B, $0A, $1A
        byte    $00, $A0, $34, $0A, $28
        byte    $17, $02, $6E, $0A, $11
        byte    $0D, $22, $4B, $0A, $1A
        byte    $00, $40, $B9, $0A, $27
        byte    $00, $60, $4E, $0A, $27
        byte    $16, $02, $2A, $0A, $11
        byte    $0C, $22, $0B, $0A, $1A
        byte    $00, $80, $AF, $0A, $27
        byte    $00, $A0, $49, $0A, $27
        byte    $18, $01, $9F, $0A, $0E
        byte    $0B, $21, $5D, $0A, $0C
        byte    $00, $40, $A5, $0A, $28
        byte    $00, $60, $45, $0A, $28
        byte    $24, $01, $37, $0A, $23
        byte    $00, $21, $9F, $0A, $23
        byte    $00, $80, $41, $0A, $27
        byte    $00, $A0, $9C, $0A, $27
        byte    $17, $40, $D0, $0A, $57
        byte    $0B, $60, $8B, $0A, $28
        byte    $00, $00, $3A, $0A, $28
        byte    $24, $20, $83, $0A, $28
        byte    $00, $80, $34, $0A, $40
        byte    $23, $00, $B9, $0A, $27
        byte    $22, $20, $AF, $0A, $4B
        byte    $00, $40, $62, $0A, $4B
        byte    $24, $01, $5D, $0A, $0A
        byte    $00, $61, $26, $0A, $0A
        byte    $00, $80, $E9, $0A, $0A
        byte    $17, $03, $3F, $0A, $12
        byte    $0C, $62, $0B, $0A, $0B
        byte    $00, $84, $17, $0A, $0B
        byte    $00, $A0, $41, $0A, $4A
        byte    $00, $20, $A5, $0A, $4A
        byte    $23, $01, $D2, $0A, $0B
        byte    $00, $42, $93, $0A, $0B
        byte    $00, $63, $A4, $0A, $0B
        byte    $00, $80, $E9, $0A, $0A
        byte    $00, $81, $06, $0A, $0A
        byte    $00, $81, $4A, $0A, $0A
        byte    $23, $02, $0B, $0A, $1D
        byte    $00, $44, $17, $0A, $1D
        byte    $00, $60, $62, $0A, $4B
        byte    $00, $80, $AF, $0A, $4B
        byte    $17, $21, $EE, $0A, $0F
        byte    $0B, $01, $5D, $0A, $0A
        byte    $00, $41, $D2, $0A, $1C
        byte    $00, $A0, $E9, $0A, $0A
        byte    $00, $21, $26, $0A, $0A
        byte    $18, $01, $B8, $0A, $11
        byte    $0C, $21, $9F, $0A, $1C
        byte    $00, $40, $A5, $0A, $15
        byte    $00, $A0, $41, $0A, $15
        byte    $18, $02, $93, $0A, $0B
        byte    $00, $41, $D2, $0A, $0B
        byte    $00, $61, $88, $0A, $0B
        byte    $0B, $00, $E9, $0A, $28
        byte    $00, $20, $A5, $0A, $28
        byte    $00, $40, $5C, $0A, $28
        byte    $17, $63, $10, $0A, $2F
        byte    $00, $82, $6E, $0A, $2F
        byte    $00, $A1, $B8, $0A, $2F
        byte    $0D, $00, $DC, $0A, $80, $8B
        byte    $00, $20, $9C, $0A, $15
        byte    $00, $40, $57, $0A, $15
        byte    $22, $21, $5D, $0A, $0A
        byte    $00, $41, $9F, $0A, $1C
        byte    $00, $61, $06, $0A, $0A
        byte    $00, $81, $37, $0A, $0A
        byte    $18, $21, $B8, $0A, $0F
        byte    $0C, $43, $10, $0A, $1A
        byte    $00, $62, $6E, $0A, $1A
        byte    $00, $80, $57, $0A, $0E
        byte    $16, $21, $B8, $0A, $12
        byte    $0D, $42, $2A, $0A, $0B
        byte    $00, $62, $E4, $0A, $0B
        byte    $00, $81, $5D, $0A, $0A
        byte    $00, $A1, $06, $0A, $0A
        byte    $00, $21, $37, $0A, $0A
        byte    $17, $22, $6E, $0A, $69
        byte    $00, $42, $BA, $0A, $69
        byte    $00, $61, $B8, $0A, $69
        byte    $00, $82, $0B, $0A, $69
        byte    $0B, $01, $5D, $0A, $28
        byte    $00, $A0, $93, $0A, $28
        byte    $24, $01, $4A, $0A, $27
        byte    $00, $A0, $8B, $0A, $27
        byte    $23, $01, $37, $0A, $16
        byte    $00, $A0, $83, $0A, $4A
        byte    $24, $01, $B8, $0A, $0A
        byte    $00, $21, $37, $0A, $0A
        byte    $00, $41, $06, $0A, $0A
        byte    $21, $01, $15, $0A, $08
        byte    $01, $21, $26, $0A, $4C
        byte    $12, $0C, $40, $0A, $0A
        byte    $08, $4A, $EA, $0A, $0A
        byte    $09, $09, $2D, $0A, $0A
        byte    $09, $4A, $EA, $0A, $0A
        byte    $08, $09, $2D, $0A, $0A
        byte    $09, $48, $2D, $0A, $0A
        byte    $09, $06, $7D, $0A, $0A
        byte    $00, $60, $D0, $0A, $4B
        byte    $00, $80, $75, $0A, $4C
        byte    $09, $27, $49, $0A, $0A
        byte    $09, $06, $7D, $0A, $0A
        byte    $09, $25, $75, $0A, $0A
        byte    $08, $04, $97, $0A, $0A
        byte    $0A, $05, $75, $0A, $0A
        byte    $08, $24, $97, $0A, $0A
        byte    $08, $04, $17, $0A, $0A
        byte    $0A, $00, $DC, $0A, $49
        byte    $00, $23, $3F, $0A, $0A
        byte    $00, $40, $57, $0A, $49
        byte    $00, $A0, $9C, $0A, $49
        byte    $08, $64, $17, $0A, $0A
        byte    $09, $23, $3F, $0A, $0A
        byte    $09, $62, $BA, $0A, $0A
        byte    $08, $22, $4B, $0A, $0A
        byte    $09, $62, $BA, $0A, $0A
        byte    $09, $22, $4B, $0A, $0A
        byte    $09, $62, $0B, $0A, $0A
        byte    $08, $21, $9F, $0A, $0A
        byte    $00, $80, $D0, $0A, $4B
        byte    $00, $60, $75, $0A, $41
        byte    $0A, $02, $0B, $0A, $0A
        byte    $08, $21, $9F, $0A, $0A
        byte    $0A, $01, $5D, $0A, $0A
        byte    $08, $21, $26, $0A, $30
        byte    $17, $00, $4E, $0A, $56
        byte    $0B, $40, $C4, $0A, $4B
        byte    $18, $22, $BA, $0A, $11
        byte    $0C, $61, $D2, $0A, $1C
        byte    $00, $82, $6E, $0A, $1C
        byte    $00, $A1, $37, $0A, $0A
        byte    $00, $20, $E9, $0A, $0A
        byte    $00, $21, $15, $0A, $0A
        byte    $18, $22, $BA, $0A, $0F
        byte    $0B, $61, $D2, $0A, $1C
        byte    $00, $82, $6E, $0A, $1C
        byte    $00, $A0, $57, $0A, $28
        byte    $00, $00, $D0, $0A, $28
        byte    $17, $21, $5D, $0A, $11
        byte    $0D, $41, $72, $0A, $1C
        byte    $00, $60, $DC, $0A, $27
        byte    $00, $80, $5C, $0A, $27
        byte    $16, $01, $88, $0A, $11
        byte    $0C, $21, $5D, $0A, $12
        byte    $00, $40, $E9, $0A, $25
        byte    $00, $A0, $62, $0A, $25
        byte    $16, $01, $88, $0A, $0A
        byte    $07, $21, $5D, $0A, $0A
        byte    $06, $01, $37, $0A, $0A
        byte    $00, $60, $9C, $0A, $28
        byte    $00, $80, $41, $0A, $28
        byte    $17, $01, $37, $0A, $42
        byte    $0D, $20, $93, $0A, $27
        byte    $00, $40, $3E, $0A, $27
        byte    $22, $60, $8B, $0A, $24
        byte    $00, $80, $3A, $0A, $24
        byte    $18, $07, $49, $0A, $4B
        byte    $00, $24, $DD, $0A, $4B
        byte    $00, $43, $A4, $0A, $4B
        byte    $24, $61, $37, $0A, $68
        byte    $00, $80, $E9, $0A, $54
        byte    $00, $A0, $83, $0A, $66
        byte    $22, $06, $7D, $0A, $0F
        byte    $00, $23, $3F, $0A, $0E
        byte    $0B, $47, $49, $0A, $1C
        byte    $00, $23, $A4, $0A, $1C
        byte    $18, $06, $7D, $0A, $0B
        byte    $00, $23, $3F, $0A, $0B
        byte    $0C, $00, $D0, $0A, $27
        byte    $17, $24, $DD, $0A, $16
        byte    $0B, $46, $20, $0A, $0B
        byte    $00, $63, $10, $0A, $0B
        byte    $00, $80, $C4, $0A, $27
        byte    $24, $07, $49, $0A, $1D
        byte    $00, $23, $A4, $0A, $1C
        byte    $00, $40, $E9, $0A, $1C
        byte    $18, $66, $E0, $0A, $11
        byte    $00, $83, $70, $0A, $0F
        byte    $00, $A0, $DC, $0A, $0F
        byte    $0B, $06, $7D, $0A, $1A
        byte    $00, $23, $3F, $0A, $1A
        byte    $00, $40, $D0, $0A, $4A
        byte    $17, $62, $BA, $0A, $0B
        byte    $00, $85, $75, $0A, $27
        byte    $00, $A0, $7B, $0A, $33
        byte    $00, $01, $26, $0A, $33
        byte    $23, $22, $BA, $0A, $11
        byte    $0C, $61, $15, $0A, $2B
        byte    $00, $84, $55, $0A, $1C
        byte    $00, $00, $75, $0A, $4B
        byte    $00, $40, $AF, $0A, $4B
        byte    $18, $23, $A4, $0A, $0F
        byte    $0B, $82, $BA, $0A, $1D
        byte    $17, $22, $6E, $0A, $11
        byte    $0D, $61, $15, $0A, $49
        byte    $00, $82, $BA, $0A, $1A
        byte    $00, $A0, $9C, $0A, $49
        byte    $00, $00, $C4, $0A, $49
        byte    $17, $22, $2A, $0A, $0F
        byte    $0B, $41, $EE, $0A, $1A
        byte    $18, $22, $0B, $0A, $0F
        byte    $0C, $40, $E9, $0A, $49
        byte    $00, $82, $6E, $0A, $1A
        byte    $00, $00, $83, $0A, $49
        byte    $00, $20, $B9, $0A, $49
        byte    $16, $61, $72, $0A, $12
        byte    $0D, $81, $D2, $0A, $1C
        byte    $17, $62, $6E, $0A, $0B
        byte    $00, $A2, $BA, $0A, $0B
        byte    $00, $81, $B8, $0A, $0B
        byte    $00, $62, $0B, $0A, $0B
        byte    $0B, $60, $DC, $0A, $48
        byte    $00, $80, $9C, $0A, $48
        byte    $00, $A0, $57, $0A, $0B
        byte    $18, $02, $6E, $0A, $0B
        byte    $00, $21, $37, $0A, $0B
        byte    $0C, $00, $57, $0A, $0C
        byte    $18, $02, $0B, $0A, $0B
        byte    $00, $21, $9F, $0A, $0B
        byte    $00, $41, $5D, $0A, $0B
        byte    $0B, $00, $75, $0A, $28
        byte    $17, $22, $0B, $0A, $0B
        byte    $00, $41, $9F, $0A, $0B
        byte    $00, $61, $5D, $0A, $0B
        byte    $0D, $20, $83, $0A, $27
        byte    $22, $00, $8B, $0A, $27
        byte    $23, $20, $93, $0A, $28
        byte    $12, $01, $37, $0A, $0C
        byte    $08, $41, $5D, $0A, $0A
        byte    $05, $01, $9F, $0A, $0A
        byte    $05, $42, $0B, $0A, $1C
        byte    $00, $61, $06, $0A, $1C
        byte    $00, $80, $9C, $0A, $27
        byte    $17, $02, $6E, $0A, $0F
        byte    $00, $21, $37, $0A, $0F
        byte    $0B, $42, $4B, $0A, $1C
        byte    $00, $61, $26, $0A, $1C
        byte    $00, $A0, $93, $0A, $28
        byte    $17, $02, $2A, $0A, $11
        byte    $00, $21, $15, $0A, $11
        byte    $0D, $41, $06, $0A, $1C
        byte    $00, $60, $8B, $0A, $15
        byte    $17, $00, $D0, $0A, $0F
        byte    $0B, $20, $AF, $0A, $1C
        byte    $00, $40, $8B, $0A, $25
        byte    $18, $00, $9C, $0A, $0F
        byte    $0B, $20, $D0, $0A, $1C
        byte    $00, $60, $41, $0A, $28
        byte    $17, $00, $83, $0A, $11
        byte    $0D, $20, $9C, $0A, $1A
        byte    $00, $40, $34, $0A, $27
        byte    $17, $00, $D0, $0A, $0F
        byte    $0B, $21, $06, $0A, $1C
        byte    $00, $60, $7B, $0A, $4B
        byte    $00, $80, $3E, $0A, $4B
        byte    $18, $01, $15, $0A, $11
        byte    $0C, $21, $26, $0A, $1A
        byte    $18, $01, $37, $0A, $0F
        byte    $0B, $21, $26, $0A, $1C
        byte    $00, $40, $75, $0A, $49
        byte    $00, $A0, $3A, $0A, $49
        byte    $17, $01, $37, $0A, $11
        byte    $0D, $20, $E9, $0A, $0A
        byte    $00, $61, $4A, $0A, $1A
        byte    $00, $80, $AF, $0A, $0A
        byte    $00, $00, $D0, $0A, $0A
        byte    $16, $01, $5D, $0A, $11
        byte    $0C, $21, $72, $0A, $1C
        byte    $00, $61, $15, $0A, $4A
        byte    $00, $80, $9C, $0A, $0A
        byte    $18, $01, $88, $0A, $0F
        byte    $0B, $21, $D2, $0A, $1D
        byte    $00, $40, $9C, $0A, $0A
        byte    $17, $01, $88, $0A, $11
        byte    $0D, $21, $9F, $0A, $1D
        byte    $00, $41, $06, $0A, $15
        byte    $00, $80, $68, $0A, $4B
        byte    $17, $01, $37, $0A, $0F
        byte    $0B, $21, $06, $0A, $0A
        byte    $00, $40, $D0, $0A, $0A
        byte    $24, $01, $15, $0A, $15
        byte    $00, $20, $75, $0A, $49
        byte    $23, $01, $15, $0A, $0A
        byte    $00, $40, $E9, $0A, $0A
        byte    $00, $60, $C4, $0A, $0A
        byte    $22, $02, $6E, $0A, $1A
        byte    $00, $41, $37, $0A, $16
        byte    $00, $60, $83, $0A, $4B
        byte    $18, $21, $EE, $0A, $11
        byte    $0C, $01, $37, $0A, $0A
        byte    $00, $42, $0B, $0A, $0B
        byte    $00, $80, $D0, $0A, $0A
        byte    $00, $A1, $06, $0A, $0A
        byte    $23, $01, $88, $0A, $1A
        byte    $00, $23, $10, $0A, $1A
        byte    $00, $40, $7B, $0A, $4B
        byte    $00, $81, $26, $0A, $16
        byte    $17, $61, $5D, $0A, $12
        byte    $0C, $01, $26, $0A, $0A
        byte    $00, $20, $F7, $0A, $0A
        byte    $00, $80, $D0, $0A, $0A
        byte    $18, $03, $3F, $0A, $0B
        byte    $00, $22, $2A, $0A, $0B
        byte    $00, $61, $9F, $0A, $0B
        byte    $0B, $00, $75, $0A, $4B
        byte    $17, $23, $10, $0A, $0B
        byte    $00, $42, $2A, $0A, $0B
        byte    $00, $61, $88, $0A, $0B
        byte    $0B, $21, $15, $0A, $0A
        byte    $00, $40, $E9, $0A, $0A
        byte    $00, $60, $C4, $0A, $0A
        byte    $18, $22, $6E, $0A, $11
        byte    $0C, $42, $2A, $0A, $4A
        byte    $00, $63, $10, $0A, $4A
        byte    $00, $80, $4E, $0A, $49
        byte    $00, $A1, $88, $0A, $4A
        byte    $23, $01, $15, $0A, $0A
        byte    $00, $20, $E9, $0A, $0A
        byte    $00, $00, $C4, $0A, $0A
        byte    $24, $01, $37, $0A, $27
        byte    $00, $20, $83, $0A, $27
        byte    $22, $41, $15, $0A, $28
        byte    $00, $60, $75, $0A, $28
        byte    $24, $01, $06, $0A, $27
        byte    $00, $20, $6E, $0A, $27
        byte    $23, $42, $93, $0A, $1A
        byte    $00, $65, $27, $0A, $1A
        byte    $00, $80, $5C, $0A, $27
        byte    $00, $A0, $DC, $0A, $27
        byte    $17, $05, $75, $0A, $0B
        byte    $00, $22, $BA, $0A, $0B
        byte    $0B, $00, $D0, $0A, $49
        byte    $00, $20, $57, $0A, $49
        byte    $18, $45, $27, $0A, $11
        byte    $00, $62, $93, $0A, $11
        byte    $0C, $82, $BA, $0A, $0B
        byte    $00, $A5, $75, $0A, $0B
        byte    $00, $41, $5D, $0A, $0A
        byte    $00, $60, $E9, $0A, $0A
        byte    $00, $41, $26, $0A, $0A
        byte    $23, $44, $17, $0A, $0B
        byte    $00, $62, $0B, $0A, $0B
        byte    $00, $80, $75, $0A, $30
        byte    $17, $04, $17, $0A, $0B
        byte    $00, $22, $0B, $0A, $0B
        byte    $0D, $01, $5D, $0A, $1A
        byte    $00, $22, $BA, $0A, $1A
        byte    $00, $41, $26, $0A, $0A
        byte    $00, $60, $D0, $0A, $0A
        byte    $00, $A0, $E9, $0A, $0A
        byte    $17, $42, $E4, $0A, $0F
        byte    $00, $61, $72, $0A, $0F
        byte    $0B, $03, $10, $0A, $1C
        byte    $00, $21, $88, $0A, $1C
        byte    $00, $80, $75, $0A, $0F
        byte    $18, $43, $3F, $0A, $0F
        byte    $00, $61, $9F, $0A, $0F
        byte    $0B, $01, $B8, $0A, $1C
        byte    $00, $23, $70, $0A, $1C
        byte    $00, $81, $15, $0A, $0A
        byte    $00, $A0, $C4, $0A, $0A
        byte    $00, $40, $E9, $0A, $0A
        byte    $17, $43, $A4, $0A, $11
        byte    $00, $61, $D2, $0A, $11
        byte    $0D, $03, $DC, $0A, $1C
        byte    $00, $21, $EE, $0A, $1C
        byte    $00, $80, $4E, $0A, $0E
        byte    $17, $43, $A4, $0A, $0B
        byte    $00, $61, $D2, $0A, $0B
        byte    $0B, $01, $15, $0A, $0A
        byte    $00, $20, $E9, $0A, $0A
        byte    $00, $40, $C4, $0A, $0A
        byte    $18, $03, $3F, $0A, $32
        byte    $00, $22, $6E, $0A, $32
        byte    $00, $41, $9F, $0A, $32
        byte    $0C, $61, $37, $0A, $49
        byte    $00, $80, $D0, $0A, $49
        byte    $00, $A0, $83, $0A, $49
        byte    $22, $02, $BA, $0A, $1C
        byte    $00, $21, $5D, $0A, $1C
        byte    $18, $42, $4B, $0A, $0F
        byte    $0B, $03, $3F, $0A, $1C
        byte    $00, $21, $9F, $0A, $1C
        byte    $17, $42, $BA, $0A, $0B
        byte    $00, $62, $4B, $0A, $0B
        byte    $0D, $01, $5D, $0A, $0A
        byte    $00, $21, $26, $0A, $0A
        byte    $00, $40, $F7, $0A, $0A
        byte    $17, $03, $3F, $0A, $0B
        byte    $00, $22, $2A, $0A, $0B
        byte    $00, $41, $9F, $0A, $0B
        byte    $0B, $00, $75, $0A, $5A
        byte    $18, $22, $6E, $0A, $11
        byte    $0C, $42, $BA, $0A, $1C
        byte    $00, $60, $E9, $0A, $48
        byte    $18, $23, $3F, $0A, $0F
        byte    $0B, $44, $17, $0A, $0B
        byte    $00, $82, $0B, $0A, $0B
        byte    $17, $04, $DD, $0A, $3A
        byte    $00, $22, $6E, $0A, $3A
        byte    $0D, $41, $15, $0A, $27
        byte    $00, $80, $9C, $0A, $27
        byte    $22, $61, $06, $0A, $15
        byte    $00, $A0, $68, $0A, $4B
        byte    $23, $01, $37, $0A, $0A
        byte    $00, $21, $06, $0A, $0A
        byte    $00, $40, $D0, $0A, $0A
        byte    $17, $05, $C8, $0A, $11
        byte    $00, $22, $E4, $0A, $11
        byte    $0D, $46, $20, $0A, $1A
        byte    $00, $63, $10, $0A, $1C
        byte    $00, $80, $75, $0A, $4A
        byte    $17, $07, $49, $0A, $0F
        byte    $00, $23, $A4, $0A, $0F
        byte    $0B, $43, $3F, $0A, $1C
        byte    $00, $66, $7D, $0A, $1C
        byte    $00, $A0, $C4, $0A, $0A
        byte    $00, $01, $15, $0A, $0A
        byte    $18, $04, $DD, $0A, $11
        byte    $00, $22, $6E, $0A, $11
        byte    $0C, $44, $17, $0A, $1A
        byte    $00, $62, $0B, $0A, $1A
        byte    $00, $A0, $83, $0A, $49
        byte    $18, $01, $D2, $0A, $11
        byte    $0B, $21, $37, $0A, $0A
        byte    $00, $41, $B8, $0A, $1C
        byte    $00, $60, $D0, $0A, $0A
        byte    $00, $81, $06, $0A, $0A
        byte    $17, $01, $9F, $0A, $0F
        byte    $0B, $23, $10, $0A, $1C
        byte    $00, $41, $88, $0A, $1C
        byte    $00, $60, $7B, $0A, $4B
        byte    $18, $02, $BA, $0A, $0C
        byte    $00, $81, $5D, $0A, $0C
        byte    $0C, $01, $26, $0A, $0A
        byte    $00, $20, $F7, $0A, $0A
        byte    $00, $40, $D0, $0A, $0A
        byte    $17, $03, $3F, $0A, $0E
        byte    $00, $21, $9F, $0A, $0E
        byte    $0C, $42, $BA, $0A, $1C
        byte    $00, $81, $5D, $0A, $1C
        byte    $00, $A0, $75, $0A, $44
        byte    $17, $01, $15, $0A, $11
        byte    $0C, $20, $E9, $0A, $1D
        byte    $18, $00, $C4, $0A, $33
        byte    $0B, $20, $4E, $0A, $27
        byte    $17, $41, $37, $0A, $0A
        byte    $00, $61, $15, $0A, $0A
        byte    $00, $80, $E9, $0A, $0A
        byte    $0B, $40, $D0, $0A, $28
        byte    $00, $60, $57, $0A, $28
        byte    $24, $00, $E9, $0A, $27
        byte    $00, $20, $62, $0A, $27
        byte    $23, $40, $F7, $0A, $28
        byte    $00, $60, $68, $0A, $28
        byte    $24, $01, $06, $0A, $15
        byte    $00, $20, $6E, $0A, $45
        byte    $22, $02, $93, $0A, $0B
        byte    $00, $43, $DC, $0A, $0B
        byte    $00, $65, $27, $0A, $0B
        byte    $00, $80, $DC, $0A, $0A
        byte    $00, $A1, $06, $0A, $0A
        byte    $00, $81, $37, $0A, $0A
        byte    $18, $05, $75, $0A, $27
        byte    $00, $44, $17, $0A, $25
        byte    $00, $62, $BA, $0A, $25
        byte    $0C, $20, $75, $0A, $32
        byte    $16, $85, $27, $0A, $11
        byte    $00, $A2, $93, $0A, $11
        byte    $0D, $02, $BA, $0A, $1A
        byte    $00, $45, $75, $0A, $1A
        byte    $00, $61, $5D, $0A, $0A
        byte    $00, $80, $D0, $0A, $0A
        byte    $00, $A1, $26, $0A, $0A
        byte    $17, $24, $17, $0A, $0B
        byte    $00, $62, $0B, $0A, $0B
        byte    $0B, $00, $75, $0A, $39
        byte    $18, $24, $17, $0A, $11
        byte    $00, $42, $0B, $0A, $11
        byte    $0C, $61, $5D, $0A, $0A
        byte    $00, $83, $3F, $0A, $1A
        byte    $00, $A0, $D0, $0A, $0A
        byte    $00, $21, $26, $0A, $0A
        byte    $18, $02, $BA, $0A, $0E
        byte    $0B, $21, $D2, $0A, $1C
        byte    $00, $41, $15, $0A, $28
        byte    $00, $60, $75, $0A, $28
        byte    $17, $01, $EE, $0A, $12
        byte    $0D, $22, $0B, $0A, $1D
        byte    $00, $81, $26, $0A, $28
        byte    $00, $A0, $7B, $0A, $28
        byte    $17, $01, $D2, $0A, $0F
        byte    $0B, $21, $88, $0A, $1C
        byte    $00, $40, $83, $0A, $27
        byte    $18, $01, $37, $0A, $0F
        byte    $0B, $21, $15, $0A, $1C
        byte    $00, $60, $75, $0A, $28
        byte    $17, $01, $9F, $0A, $0B
        byte    $00, $41, $06, $0A, $0B
        byte    $0D, $00, $68, $0A, $49
        byte    $17, $21, $37, $0A, $0F
        byte    $0B, $40, $F7, $0A, $0A
        byte    $00, $60, $9C, $0A, $28
        byte    $0C, $21, $06, $0A, $0A
        byte    $0C, $21, $37, $0A, $0A
        byte    $0C, $21, $06, $0A, $1C
        byte    $00, $40, $4E, $0A, $27
        byte    $17, $00, $D0, $0A, $0E
        byte    $0C, $20, $AF, $0A, $1C
        byte    $00, $60, $45, $0A, $28
        byte    $17, $00, $9C, $0A, $0F
        byte    $0B, $20, $D0, $0A, $1A
        byte    $00, $40, $34, $0A, $28
        byte    $17, $00, $9C, $0A, $1A
        byte    $0D, $20, $8B, $0A, $27
        byte    $00, $60, $3A, $0A, $27
        byte    $22, $00, $9C, $0A, $28
        byte    $00, $40, $41, $0A, $28
        byte    $24, $20, $AF, $0A, $27
        byte    $00, $60, $45, $0A, $27
        byte    $23, $00, $A5, $0A, $4B
        byte    $00, $40, $41, $0A, $4B
        byte    $17, $24, $17, $0A, $0B
        byte    $00, $63, $10, $0A, $0B
        byte    $00, $82, $0B, $0A, $0B
        byte    $0D, $21, $06, $0A, $0A
        byte    $00, $61, $4A, $0A, $0A
        byte    $00, $80, $C4, $0A, $0A
        byte    $00, $A0, $E9, $0A, $0A
        byte    $16, $23, $A4, $0A, $11
        byte    $0C, $63, $10, $0A, $29
        byte    $00, $84, $17, $0A, $29
        byte    $00, $A2, $0B, $0A, $29
        byte    $00, $00, $49, $0A, $4B
        byte    $00, $20, $AF, $0A, $4B
        byte    $23, $41, $26, $0A, $0A
        byte    $00, $60, $E9, $0A, $0A
        byte    $00, $80, $C4, $0A, $0A
        byte    $17, $44, $17, $0A, $0B
        byte    $00, $63, $10, $0A, $0B
        byte    $00, $82, $0B, $0A, $0B
        byte    $0D, $40, $C4, $0A, $27
        byte    $00, $60, $52, $0A, $27
        byte    $17, $03, $A4, $0A, $0F
        byte    $0B, $23, $10, $0A, $2F
        byte    $00, $84, $17, $0A, $2F
        byte    $00, $A2, $0B, $0A, $2F
        byte    $00, $00, $49, $0A, $28
        byte    $00, $40, $AF, $0A, $28
        byte    $24, $60, $A5, $0A, $25
        byte    $00, $00, $41, $0A, $25
        byte    $18, $24, $17, $0A, $0B
        byte    $00, $43, $10, $0A, $0B
        byte    $00, $82, $0B, $0A, $0B
        byte    $0B, $20, $E9, $0A, $27
        byte    $00, $40, $5C, $0A, $27
        byte    $17, $03, $A4, $0A, $11
        byte    $0B, $63, $10, $0A, $1C
        byte    $00, $84, $17, $0A, $1C
        byte    $00, $A2, $0B, $0A, $1C
        byte    $00, $20, $57, $0A, $49
        byte    $00, $40, $DC, $0A, $16
        byte    $18, $02, $2A, $0A, $11
        byte    $0C, $41, $37, $0A, $0A
        byte    $00, $62, $6E, $0A, $1C
        byte    $00, $80, $DC, $0A, $0A
        byte    $00, $A1, $06, $0A, $0A
        byte    $18, $02, $2A, $0A, $0F
        byte    $0B, $42, $0B, $0A, $1C
        byte    $00, $61, $5D, $0A, $28
        byte    $00, $80, $93, $0A, $28
        byte    $17, $01, $D2, $0A, $11
        byte    $0C, $21, $B8, $0A, $1C
        byte    $00, $41, $4A, $0A, $27
        byte    $00, $A0, $8B, $0A, $27
        byte    $18, $01, $72, $0A, $0E
        byte    $0B, $21, $5D, $0A, $29
        byte    $00, $60, $83, $0A, $16
        byte    $17, $02, $6E, $0A, $4D
        byte    $00, $42, $0B, $0A, $4D
        byte    $00, $61, $B8, $0A, $4D
        byte    $0C, $81, $15, $0A, $29
        byte    $00, $A0, $75, $0A, $28
        byte    $23, $21, $06, $0A, $27
        byte    $00, $A0, $6E, $0A, $25
        byte    $23, $00, $DC, $0A, $27
        byte    $00, $40, $5C, $0A, $28
        byte    $24, $20, $D0, $0A, $80, $8E
        byte    $00, $60, $57, $0A, $80, $90
        byte    $22, $01, $26, $0A, $0A
        byte    $09, $41, $88, $0A, $0A
        byte    $09, $02, $0B, $0A, $0A
        byte    $09, $42, $4B, $0A, $0A
        byte    $09, $03, $10, $0A, $0A
        byte    $00, $80, $75, $0A, $49
        byte    $09, $44, $17, $0A, $0A
        byte    $08, $03, $A4, $0A, $0A
        byte    $09, $43, $3F, $0A, $0A
        byte    $09, $02, $BA, $0A, $0A
        byte    $08, $42, $4B, $0A, $0A
        byte    $0A, $02, $0B, $0A, $0A
        byte    $08, $41, $D2, $0A, $0A
        byte    $08, $01, $9F, $0A, $0A
        byte    $00, $A0, $3A, $0A, $2B
        byte    $0A, $01, $5D, $0A, $0A
        byte    $08, $21, $26, $0A, $0A
        byte    $09, $01, $06, $0A, $0A
        byte    $09, $20, $E9, $0A, $0A
        byte    $08, $00, $AF, $0A, $0A
        byte    $09, $20, $93, $0A, $0A
        byte    $09, $00, $83, $0A, $0B
        byte    $09, $20, $3A, $0A, $4B
        byte    $24, $00, $D0, $0A, $15
        byte    $13, $41, $26, $0A, $0B
        byte    $08, $01, $88, $0A, $0B
        byte    $07, $41, $5D, $0A, $0B
        byte    $00, $60, $4E, $0A, $27
        byte    $23, $01, $15, $0A, $1A
        byte    $00, $20, $75, $0A, $48
        byte    $17, $40, $C4, $0A, $12
        byte    $0D, $00, $B9, $0A, $1D
        byte    $17, $40, $C4, $0A, $0F
        byte    $0B, $00, $E9, $0A, $1C
        byte    $00, $60, $4E, $0A, $0E
        byte    $18, $21, $15, $0A, $11
        byte    $0C, $01, $37, $0A, $1C
        byte    $00, $40, $4E, $0A, $15
        byte    $17, $20, $9C, $0A, $21
        byte    $0B, $00, $93, $0A, $27
        byte    $00, $40, $3E, $0A, $27
        byte    $23, $20, $8B, $0A, $29
        byte    $00, $60, $3A, $0A, $29
        byte    $24, $03, $10, $0A, $0B
        byte    $00, $43, $DC, $0A, $0B
        byte    $00, $82, $93, $0A, $0B
        byte    $00, $A0, $F7, $0A, $27
        byte    $00, $22, $2A, $0A, $0B
        byte    $22, $02, $6E, $0A, $20
        byte    $00, $23, $10, $0A, $3F
        byte    $00, $43, $A4, $0A, $0F
        byte    $00, $60, $68, $0A, $49
        byte    $00, $81, $06, $0A, $16
        byte    $00, $A2, $0B, $0A, $08
        byte    $0B, $A2, $0B, $0A, $08
        byte    $07, $43, $A4, $0A, $08
        byte    $05, $82, $0B, $0A, $08
        byte    $06, $43, $A4, $0A, $08
        byte    $05, $02, $0B, $0A, $12
        byte    $02, $81, $9F, $0A, $0A
        byte    $00, $A1, $37, $0A, $0A
        byte    $00, $41, $06, $0A, $0A
        byte    $07, $43, $A4, $0A, $15
        byte    $11, $02, $BA, $0A, $48
        byte    $00, $83, $3F, $0A, $48
        byte    $00, $A2, $0B, $0A, $32
        byte    $00, $22, $6E, $0A, $32
        byte    $0B, $40, $4E, $0A, $0F
        byte    $24, $41, $9F, $0A, $0A
        byte    $00, $61, $37, $0A, $0A
        byte    $00, $21, $06, $0A, $0A
        byte    $16, $23, $10, $0A, $0B
        byte    $00, $43, $A4, $0A, $0B
        byte    $00, $62, $0B, $0A, $0B
        byte    $00, $A2, $6E, $0A, $0B
        byte    $0C, $00, $83, $0A, $46
        byte    $18, $23, $10, $0A, $08
        byte    $00, $43, $A4, $0A, $08
        byte    $00, $62, $0B, $0A, $08
        byte    $00, $82, $6E, $0A, $08
        byte    $0B, $22, $6E, $0A, $0B
        byte    $00, $42, $BA, $0A, $0B
        byte    $00, $63, $3F, $0A, $0B
        byte    $00, $82, $0B, $0A, $0B
        byte    $00, $A0, $D0, $0A, $0A
        byte    $00, $A1, $06, $0A, $0A
        byte    $00, $A1, $37, $0A, $0A
        byte    $24, $02, $4B, $0A, $2B
        byte    $00, $23, $10, $0A, $1C
        byte    $00, $41, $EE, $0A, $2B
        byte    $00, $60, $D0, $0A, $48
        byte    $00, $81, $9F, $0A, $2B
        byte    $17, $A2, $BA, $0A, $32
        byte    $0B, $21, $5D, $0A, $0A
        byte    $00, $01, $26, $0A, $0A
        byte    $00, $40, $F7, $0A, $0A
        byte    $24, $02, $6E, $0A, $25
        byte    $00, $23, $10, $0A, $3B
        byte    $00, $42, $2A, $0A, $25
        byte    $00, $80, $4E, $0A, $4B
        byte    $00, $61, $D2, $0A, $25
        byte    $23, $A1, $15, $0A, $0A
        byte    $00, $00, $E9, $0A, $0A
        byte    $00, $40, $C4, $0A, $0A
        byte    $17, $02, $2A, $0A, $48
        byte    $00, $42, $6E, $0A, $48
        byte    $00, $61, $88, $0A, $49
        byte    $00, $A1, $D2, $0A, $34
        byte    $0B, $21, $37, $0A, $28
        byte    $00, $80, $83, $0A, $28
        byte    $24, $21, $15, $0A, $27
        byte    $00, $80, $75, $0A, $27
        byte    $18, $A2, $0B, $0A, $0B
        byte    $00, $02, $BA, $0A, $0B
        byte    $00, $41, $72, $0A, $0B
        byte    $00, $61, $D2, $0A, $0B
        byte    $0B, $00, $83, $0A, $28
        byte    $17, $22, $0B, $0A, $08
        byte    $00, $42, $BA, $0A, $12
        byte    $00, $61, $72, $0A, $08
        byte    $00, $81, $D2, $0A, $08
        byte    $0D, $22, $0B, $0A, $0B
        byte    $00, $62, $6E, $0A, $0B
        byte    $00, $81, $D2, $0A, $0B
        byte    $00, $A0, $75, $0A, $27
        byte    $00, $01, $72, $0A, $0B
        byte    $17, $02, $6E, $0A, $0B
        byte    $00, $22, $BA, $0A, $0B
        byte    $00, $41, $B8, $0A, $0B
        byte    $00, $62, $0B, $0A, $0B
        byte    $0B, $01, $06, $0A, $28
        byte    $00, $20, $6E, $0A, $27
        byte    $17, $42, $0B, $0A, $21
        byte    $00, $61, $B8, $0A, $21
        byte    $00, $81, $37, $0A, $21
        byte    $0C, $A0, $DC, $0A, $28
        byte    $00, $20, $9C, $0A, $28
        byte    $00, $00, $57, $0A, $28
        byte    $23, $41, $26, $0A, $80, $8E
        byte    $00, $60, $D0, $0A, $80, $8E
        byte    $00, $80, $75, $0A, $80, $8E
        byte    $23, $01, $5D, $0A, $0A
        byte    $0C, $01, $9F, $0A, $0A
        byte    $0B, $02, $0B, $0A, $0A
        byte    $0D, $02, $BA, $0A, $1C
        byte    $17, $22, $93, $0A, $0B
        byte    $2F, $02, $93, $0A, $0A
        byte    $00, $20, $AF, $0A, $6D
        byte    $0B, $03, $3F, $0A, $0A
        byte    $0B, $04, $17, $0A, $0A
        byte    $0D, $05, $75, $0A, $1C
        byte    $17, $44, $17, $0A, $0B
        byte    $23, $04, $17, $0A, $0B
        byte    $0C, $01, $26, $0A, $0B
        byte    $00, $40, $D0, $0A, $0B
        byte    $00, $60, $75, $0A, $0B
        byte    $23, $01, $26, $0A, $80, $EC
        byte    $00, $20, $D0, $0A, $80, $EC
        byte    $00, $40, $A5, $0A, $80, $EC
        byte    $24, $61, $4A, $0A, $0A
        byte    $0B, $61, $EE, $0A, $0A
        byte    $0C, $62, $93, $0A, $0A
        byte    $0B, $63, $3F, $0A, $1D
        byte    $18, $82, $93, $0A, $0B
        byte    $2F, $62, $93, $0A, $0A
        byte    $08, $83, $3F, $0A, $0A
        byte    $0A, $63, $DC, $0A, $0A
        byte    $08, $85, $27, $0A, $0A
        byte    $08, $66, $7D, $0A, $1A
        byte    $18, $83, $3F, $0A, $0B
        byte    $24, $63, $3F, $0A, $0B
        byte    $0B, $01, $26, $0A, $0B
        byte    $00, $20, $D0, $0A, $0B
        byte    $00, $40, $A5, $0A, $0B
        byte    $22, $01, $37, $0A, $6D
        byte    $00, $20, $D0, $0A, $54
        byte    $00, $40, $83, $0A, $6E
        byte    $24, $64, $DD, $0A, $1C
        byte    $17, $83, $DC, $0A, $11
        byte    $0B, $64, $17, $0A, $12
        byte    $18, $24, $17, $0A, $0B
        byte    $0C, $21, $26, $0A, $80, $90
        byte    $00, $60, $D0, $0A, $80, $90
        byte    $00, $80, $7B, $0A, $80, $90
        byte    $23, $03, $DC, $0A, $1C
        byte    $17, $43, $3F, $0A, $11
        byte    $0D, $02, $BA, $0A, $1C
        byte    $16, $42, $6E, $0A, $12
        byte    $0C, $02, $4B, $0A, $1D
        byte    $18, $42, $6E, $0A, $0B
        byte    $0B, $01, $15, $0A, $48
        byte    $00, $40, $C4, $0A, $48
        byte    $00, $A0, $75, $0A, $48
        byte    $24, $22, $6E, $0A, $1D
        byte    $17, $63, $3F, $0A, $0C
        byte    $0B, $21, $06, $0A, $0B
        byte    $00, $80, $9C, $0A, $0B
        byte    $00, $60, $68, $0A, $0B
        byte    $24, $02, $6E, $0A, $1C
        byte    $18, $21, $EE, $0A, $0F
        byte    $0B, $02, $0B, $0A, $1C
        byte    $17, $22, $2A, $0A, $0F
        byte    $0B, $02, $6E, $0A, $0B
        byte    $24, $01, $37, $0A, $1C
        byte    $00, $20, $4E, $0A, $1C
        byte    $18, $41, $9F, $0A, $0B
        byte    $00, $60, $68, $0A, $0B
        byte    $2F, $00, $83, $0A, $80, $92
        byte    $00, $20, $34, $0A, $80, $92
        byte    $ff

_end_of_ram_songs
        byte    $ff