' //////////////////////////////////////////////////////////////////////
' TITLE: EPM_HDMF_Live_Player_010.SPIN 
'
' DESCRIPTION:
'
' AUTHOR:  Eric Moyer
'
' UPDATES: Search the Parallax forums at http://forums.parallax.com for the latest version. 
'
'                                                                   
'
' //////////////////////////////////////////////////////////////////////
'
'  Revision History
'
'  Rev  Date      Description
'  ---  --------  ---------------------------------------------------
'  001  05-19-07  Initial Creation
'  010  05-27-07  Added serial handshaking.
'                 Use 600 byte rx buffer.
'                 Public Release
'
'
' //////////////////////////////////////////////////////////////////////


'///////////////////////////////////////////////////////////////////////
' CONSTANTS SECTION ////////////////////////////////////////////////////
'///////////////////////////////////////////////////////////////////////

CON

  _clkmode = xtal2 + pll8x            ' enable external clock and pll times 8
  _xinfreq = 10_000_000 + 0000        ' set frequency to 10 MHZ plus some error for xtals that are not exact add 1000-5000 usually works
  _stack = ($1800 + $1800 + 64) >> 2  ' accomodate display memory and stack

  'DEBUG OPTIONS:
  DEBUG__SHOW_WATCH_VARIABLES   = TRUE
  DEBUG__ENABLE_DEBUG_MODE      = FALSE
  DEBUG__ENABLE_MUSIC_DEBUG     = FALSE

  MAX_SONGS = 10
  
  ' graphics driver and screen constants
  PARAMCOUNT        = 14        
  OFFSCREEN_BUFFER  = $5000           ' offscreen buffer
  ONSCREEN_BUFFER   = $6800           ' onscreen buffer

  ' size of graphics tile map
  X_TILES           = 16
  Y_TILES           = 12
  
  SCREEN_WIDTH      = 256
  SCREEN_HEIGHT     = 192 

  ' Display constants 
  TEXT_LINE_SPACING = 13

  ' angular constants to make object declarations easier
  ANG_0    = $0000
  ANG_360  = $2000
  ANG_240  = ($2000*2/3)
  ANG_180  = ($2000/2)
  ANG_270  = ($2000*3/4)
  ANG_120  = ($2000/3)
  ANG_90   = ($2000/4)
  ANG_60   = ($2000/6)
  ANG_45   = ($2000/8)
  ANG_30   = ($2000/12)
  ANG_22_5 = ($2000/16)
  ANG_15   = ($2000/24)
  ANG_10   = ($2000/36)
  ANG_5    = ($2000/72)
  ANG_1    = ($2000/360)

  ' constants for math functions
  SIN      = 0
  COS      = 1

  ' NES bit encodings
  NES_RIGHT  = %00000001
  NES_LEFT   = %00000010
  NES_DOWN   = %00000100
  NES_UP     = %00001000
  NES_START  = %00010000
  NES_SELECT = %00100000
  NES_B      = %01000000
  NES_A      = %10000000


  'Player states
  STATE_IDLE             = 0
  STATE_DOWNLOADING      = 1
  STATE_STOPPED          = 2
  STATE_PLAYING          = 3
  STATE_DOWNLOAD_TIMEOUT = 4

  'Serial Port
  SERIAL_QUEUE_SIZE    = 600
  SONG_BUFFER_SIZE     = 1024 * 7
  HANDSHAKE_CHUNK_SIZE = 512
  CHUNK_ACK            = 42   ' Send a "*" to acknowledge receipt of each chunk
   
'///////////////////////////////////////////////////////////////////////
' VARIABLES SECTION ////////////////////////////////////////////////////
'///////////////////////////////////////////////////////////////////////

VAR

  long  tv_status     '0/1/2 = off/visible/invisible           read-only
  long  tv_enable     '0/? = off/on                            write-only
  long  tv_pins       '%ppmmm = pins                           write-only
  long  tv_mode       '%ccinp = chroma,interlace,ntsc/pal,swap write-only
  long  tv_screen     'pointer to screen (words)               write-only
  long  tv_colors     'pointer to colors (longs)               write-only               
  long  tv_hc         'horizontal cells                        write-only
  long  tv_vc         'vertical cells                          write-only
  long  tv_hx         'horizontal cell expansion               write-only
  long  tv_vx         'vertical cell expansion                 write-only
  long  tv_ho         'horizontal offset                       write-only
  long  tv_vo         'vertical offset                         write-only
  long  tv_broadcast  'broadcast frequency (Hz)                write-only
  long  tv_auralcog   'aural fm cog                            write-only

  word  screen[x_tiles * y_tiles] ' storage for screen tile map
  long  colors[64]                ' color look up table

  ' songs
  byte song_data[SONG_BUFFER_SIZE]
  long song_ptr

  ' debug data
  long debug_data[11] 

  ' nes gamepad vars
  long nes_buttons
  long button_temp

  ' player state
  byte player_state

  'Serial I/O
  byte serial_rx_queue[SERIAL_QUEUE_SIZE]

  long rx_size

  'Serial Mesasging Protocol
  long msg_size
  long msg_bytes_received
  long msg_chunk_bytes_received
  byte msg_chunk_ack 
  
  'Serial Driver parameter block -----------------------------
  long  serial_rx
  long  serial_rxidx
  long  serial_tx
  long  serial_txidx
  long  serial_rxbuf
  long  serial_rxsize
  long  serial_txbuf
  long  serial_txsize
  
'///////////////////////////////////////////////////////////////////////
' OBJECT DECLARATION SECTION ///////////////////////////////////////////
'///////////////////////////////////////////////////////////////////////
OBJ

  tv    : "EPM_tv_drv_011.spin"                ' Paralax tv driver, modified for 2 color 
  gr    : "EPM_graphics_drv_spacewar_012.spin" ' Paralax graphics driver, modified for 2 color 
  hdmf  : "EPM_HDMF_driver_010.spin"           ' HDMF song player
  serial: "copio_drv_001.spin"                 ' Serial driver
    

'///////////////////////////////////////////////////////////////////////
' EXPORT PUBLICS  //////////////////////////////////////////////////////
'///////////////////////////////////////////////////////////////////////

PUB start | i , dx, dy

  '//// GLOBAL INITIALIZTION
  
  'start tv
  longmove(@tv_status, @tvparams, paramcount)
  tv_screen := @screen
  tv_colors := @colors
  tv.start(@tv_status)

  'start music driver
  if DEBUG__ENABLE_MUSIC_DEBUG
    hdmf.start(@debug_data)
  else
    hdmf.start(0)

  'init debug LED
  DIRA [0] := 1 ' output 
  
  'init colors
  repeat i from 0 to 64
    colors[i] := $00001010 * (i+4) & $F + $FB060C02

  'init tile screen
  repeat dx from 0 to tv_hc - 1
    repeat dy from 0 to tv_vc - 1
      screen[dy * tv_hc + dx] := onscreen_buffer >> 6 + dy + dx * tv_vc + ((dy & $3F) << 10)

  'start and setup graphics
  gr.start
  gr.setup(16, 12, 128, 96, offscreen_buffer)

  ' start serial engine
  msg_chunk_ack := CHUNK_ACK
  msg_chunk_bytes_received := 0
  serial.start(@serial_rx, 31, 30, 115200)
  serial.receive_circular(@serial_rx_queue, SERIAL_QUEUE_SIZE) ' Setup circular buffer for receive queue.

  '//// MAIN EXECUTION MANAGER
  repeat
    'PlaySong
    Configure_Options 

PUB Configure_Options | i, y, string_ptr, num_options, key_repeat_ticks, current_option_mask, done, download_timeout
 
  done               := false
  player_state       := STATE_IDLE
  msg_size           := 0
  download_timeout   := 0
  msg_bytes_received := 0
  
  repeat 

    '//// Clear screen
    gr.clear        ' Clear bitmap

    '//// GET USER INPUT
    nes_buttons := NES_Read_Gamepad
    nes_buttons &= $ff
    if nes_buttons == $ff
      nes_buttons := 0
    
    '//// Draw titles
    gr.textmode(1,1,6,1)
    gr.colorwidth(2,0)
    y:=86
    gr.text(-43, y, string("HDMF LIVE PLAYER"))

    y -= TEXT_LINE_SPACING
    gr.text(-28, y, string("VERSION 1.0"))

    y -= TEXT_LINE_SPACING
    if player_state == STATE_IDLE   
      gr.text(-123, y, string("STATE: IDLE"))
    elseif player_state == STATE_DOWNLOADING
      gr.text(-123, y, string("STATE: DOWNLOADING"))
    elseif player_state == STATE_STOPPED
      gr.text(-123, y, string("STATE: STOPPED"))
    elseif player_state == STATE_PLAYING
      gr.text(-123, y, string("STATE: PLAYING"))
    elseif player_state == STATE_DOWNLOAD_TIMEOUT
      gr.text(-123, y, string("STATE: RECEIVE TIMEOUT"))
      

    y -= TEXT_LINE_SPACING
    gr.text(-123, y, string("DOWNLOAD SIZE:"))
    Int_To_String(@uint_string_0, msg_size )
    gr.text(-32, y , @uint_string_0)

    y -= TEXT_LINE_SPACING
    gr.text(-123, y, string("RECEIVED:"))
    Int_To_String(@uint_string_0, msg_bytes_received )
    gr.text(-32, y , @uint_string_0)

    {
    'Show the system counter
    y -= TEXT_LINE_SPACING
    gr.text(-123, y, string("CNT:"))
    Int_To_Hex_String(@hex_string_0, cnt)
    gr.text(-32, y , @hex_string_0)
    }
    
    y:=-79
    gr.text(-110, y, string("WRITTEN BY ERIC MOYER. FOR THE LATEST"))
    y -= TEXT_LINE_SPACING 
    gr.text(-123, y, string("VERSION SEARCH HTTP://FORUMS.PARALLAX.COM"))

    '//// Process timeouts
    if (player_state == STATE_DOWNLOADING ) and (download_timeout > 0)
      --download_timeout
      if download_timeout == 0
        player_state := STATE_DOWNLOAD_TIMEOUT

    '//// Process playback complete
    if (player_state == STATE_PLAYING )
      if not hdmf.song_is_playing
        'Song is done
         player_state := STATE_IDLE
      
    '//// Process Serial data RX
    rx_size := serial.receive_queue(-1,-1)
    if player_state <> STATE_DOWNLOADING
      'If a download is starting
      if (rx_size => 4)
        player_state := STATE_DOWNLOADING  
        serial.receive_queue(@msg_size, 4)
        download_timeout := 25
        song_ptr := @song_data
        msg_bytes_received := 0
        msg_chunk_bytes_received := 4
        hdmf.stop_song
        {
        repeat while msg_bytes_received < msg_size
          rx_size := serial.receive_queue(-1,-1)
          if (rx_size <> 0)  
            serial.receive_queue(song_ptr, rx_size)
            msg_bytes_received += rx_size
            song_ptr += rx_size
            if msg_bytes_received => msg_size
               player_state := STATE_PLAYING
               hdmf.play_song(@song_data, 0) 
         }

    else
      'Process download data
      if (rx_size <> 0)
        serial.receive_queue(song_ptr, rx_size)
        msg_bytes_received += rx_size
        msg_chunk_bytes_received += rx_size
        song_ptr += rx_size

        'If a message chunk has been received
        if msg_chunk_bytes_received == HANDSHAKE_CHUNK_SIZE
          'Send a chunk ack
          serial.send(@msg_chunk_ack, 1)
          msg_chunk_bytes_received := 0

        'If full message received
        if msg_bytes_received => msg_size
           'Send a chunk ack  
           serial.send(@msg_chunk_ack, 1)
           'Play the song
           player_state := STATE_PLAYING
           hdmf.play_song(@song_data, 0) 
           

    '//// COPY BITMAP TO DISPLAY
    gr.copy(onscreen_buffer)

PUB Int_To_Hex_String(str, i) | t, nibble
   
  ' does an sprintf(str, "%08lX", i); job
  ' assumes that '0x' is already in the first 2 character positions of the string
  str+=9
  repeat t from 0 to 7
    nibble := i & $0000000f
    if nibble =< 9
      BYTE[str] := 48 {'0'} + nibble
    else
      BYTE[str] := CONSTANT(65 {'A'} - 10) + nibble
    str--
    i >>= 4

PUB Int_To_String(str, i) | t
   
  ' does an sprintf(str, "%05d", i); job
  str+=4
  repeat t from 0 to 4
    BYTE[str] := 48+(i // 10)
    i/=10
    str--

PUB Signed_Int_To_String(str, i) | t
   
  'Print the sign
  if (i<0)
    i := -i
    BYTE[str] := 45  ' ASCII '-'
  else
    BYTE[str] := 43  ' ASCII '+' 
    
  str+=5
  repeat t from 0 to 4
    BYTE[str] := 48+(i // 10)
    i/=10
    str--
    
PUB Fixed_To_String(str, fixed) | t , i
  ' does an sprintf(str, "%+05.04f", i); job

  'Print the sign
  if (fixed<0)
    fixed := -fixed
    BYTE[str] := 45  ' ASCII '-' 
  else
    BYTE[str] := 43  ' ASCII '+'     
    
  'Print the fractional portion
  str+=10
  i := ((fixed & $0000_FFFF) * 10000) ~>16 'Get the fractional part, and convert to 5 decimal digits of accuracy.
  repeat t from 0 to 3
    BYTE[str] := 48+(i // 10)
    i/=10
    str--
   
  'Print the decimal point
  BYTE[str] := 46  '46 = ASCII Decimal point
  str-- 
   
  'Print the decimal portion
  i:=fixed~>16
  repeat t from 0 to 4
    BYTE[str] := 48+(i // 10)
    i/=10
    str--

' //////////////////////////////////////////////////////////////////////


PUB NES_Read_Gamepad : nes_bits        |  i

' //////////////////////////////////////////////////////////////////
' NES Game Paddle Read
' //////////////////////////////////////////////////////////////////       
' reads both gamepads in parallel encodes 8-bits for each in format
' right game pad #1 [15..8] : left game pad #0 [7..0]
'
' set I/O ports to proper direction
' P3 = JOY_CLK      (4)
' P4 = JOY_SH/LDn   (5) 
' P5 = JOY_DATAOUT0 (6)
' P6 = JOY_DATAOUT1 (7)
' NES Bit Encoding
'
' RIGHT  = %00000001
' LEFT   = %00000010
' DOWN   = %00000100
' UP     = %00001000
' START  = %00010000
' SELECT = %00100000
' B      = %01000000
' A      = %10000000

' step 1: set I/Os
DIRA [3] := 1 ' output
DIRA [4] := 1 ' output
DIRA [5] := 0 ' input
DIRA [6] := 0 ' input

' step 2: set clock and latch to 0
OUTA [3] := 0 ' JOY_CLK = 0
OUTA [4] := 0 ' JOY_SH/LDn = 0
'Delay(1)

' step 3: set latch to 1
OUTA [4] := 1 ' JOY_SH/LDn = 1
'Delay(1)

' step 4: set latch to 0
OUTA [4] := 0 ' JOY_SH/LDn = 0

' step 5: read first bit of each game pad

' data is now ready to shift out
' first bit is ready 
nes_bits := 0

' left controller
nes_bits := INA[5] | (INA[6] << 8)

' step 7: read next 7 bits
repeat i from 0 to 6
 OUTA [3] := 1 ' JOY_CLK = 1
 'Delay(1)             
 OUTA [3] := 0 ' JOY_CLK = 0
 nes_bits := (nes_bits << 1)
 nes_bits := nes_bits | INA[5] | (INA[6] << 8)

 'Delay(1)             
' invert bits to make positive logic
nes_bits := (!nes_bits & $FFFF)

' //////////////////////////////////////////////////////////////////
' End NES Game Paddle Read
' //////////////////////////////////////////////////////////////////


'///////////////////////////////////////////////////////////////////////
' DATA SECTION /////////////////////////////////////////////////////////
'///////////////////////////////////////////////////////////////////////

DAT

' TV PARAMETERS FOR DRIVER /////////////////////////////////////////////

tvparams                long    0               'status
                        long    1               'enable
                        long    %011_0000       'pins
                        long    %0000           'mode
                        long    0               'screen
                        long    0               'colors
                        long    x_tiles         'hc
                        long    y_tiles         'vc
                        long    10              'hx timing stretch
                        long    1               'vx
                        long    0               'ho
                        long    0               'vo
                        long    55_250_000      'broadcast
                        long    0               'auralcog                        

fixed_pt_string_0        byte    "-00000.0000",0    'text
int_string_0             byte    "-00000",0         'text
uint_string_0            byte    "00000",0         'text 
hex_string_0             byte    "0X00000000",0     'text

ram_string               byte    "RAM",0            'text
eeprom_string            byte    "EEPROM",0         'text
  