' //////////////////////////////////////////////////////////////////////
' TITLE: EPM_HDMF_RAM_DEMO_010.SPIN 
'
' DESCRIPTION:
'   Demonstrates the features of the Hydra Dense Music Format (HDMF) player.        
'
' AUTHOR:  Eric Moyer
'
' UPDATES: Search the Parallax forums at http://forums.parallax.com for the latest version.
'
' CONTROLS:
'          Two NES gamepads, or a gamepad and the keyboard
'          Press START or <Spacebar> at the GAME OVER screen to return to the options menu.
'
'          Gamepad 0    Function 
'          ---------    ------------------------------------------------------------------------
'          UP           Move cursor up   
'          DOWN         Move cursor down
'          A            Start song
'          B            Stop song
'
' //////////////////////////////////////////////////////////////////////
'
'  Revision History
'
'  Rev  Date      Description
'  ---  --------  ---------------------------------------------------
'  001  05-12-07  Initial working release.
'  002  05-12-07  Use variable length duration in B4
'                 Swap duration and volume so vol in B3, Duration in B4
'  010  05-21-07  Public release         
'
' //////////////////////////////////////////////////////////////////////


'///////////////////////////////////////////////////////////////////////
' CONSTANTS SECTION ////////////////////////////////////////////////////
'///////////////////////////////////////////////////////////////////////

CON

  _clkmode = xtal2 + pll8x            ' enable external clock and pll times 8
  _xinfreq = 10_000_000 + 0000        ' set frequency to 10 MHZ plus some error for xtals that are not exact add 1000-5000 usually works
  _stack = ($1800 + $1800 + 64) >> 2  ' accomodate display memory and stack

  'DEBUG OPTIONS:
  DEBUG__ENABLE_MUSIC_DEBUG     = FALSE

  MAX_SONGS = 10
  
  ' graphics driver and screen constants
  PARAMCOUNT        = 14        
  OFFSCREEN_BUFFER  = $5000           ' offscreen buffer
  ONSCREEN_BUFFER   = $6800           ' onscreen buffer

  ' size of graphics tile map
  X_TILES           = 16
  Y_TILES           = 12
  
  SCREEN_WIDTH      = 256
  SCREEN_HEIGHT     = 192 

  ' Display constants 
  TEXT_LINE_SPACING = 13

  ' angular constants to make object declarations easier
  ANG_0    = $0000
  ANG_360  = $2000
  ANG_240  = ($2000*2/3)
  ANG_180  = ($2000/2)
  ANG_270  = ($2000*3/4)
  ANG_120  = ($2000/3)
  ANG_90   = ($2000/4)
  ANG_60   = ($2000/6)
  ANG_45   = ($2000/8)
  ANG_30   = ($2000/12)
  ANG_22_5 = ($2000/16)
  ANG_15   = ($2000/24)
  ANG_10   = ($2000/36)
  ANG_5    = ($2000/72)
  ANG_1    = ($2000/360)

  ' constants for math functions
  SIN      = 0
  COS      = 1

  ' NES bit encodings
  NES_RIGHT  = %00000001
  NES_LEFT   = %00000010
  NES_DOWN   = %00000100
  NES_UP     = %00001000
  NES_START  = %00010000
  NES_SELECT = %00100000
  NES_B      = %01000000
  NES_A      = %10000000

  'Menu Flags
  MENU_FLAG__A_HELD                 = %00000001
  MENU_FLAG__UP_DOWN_HELD           = %00000010
  MENU_FLAG__REPEAT_GO_TIME_MET     = %00000100
  MENU_FLAG__DO_REPEAT_CLICK        = %00001000


  'Vector drawing commands
  VECTOR_MOVE           = $4000
  VECTOR_DRAW           = $8000
  VECTOR_END            = $0000
   
'///////////////////////////////////////////////////////////////////////
' VARIABLES SECTION ////////////////////////////////////////////////////
'///////////////////////////////////////////////////////////////////////

VAR

  long  tv_status     '0/1/2 = off/visible/invisible           read-only
  long  tv_enable     '0/? = off/on                            write-only
  long  tv_pins       '%ppmmm = pins                           write-only
  long  tv_mode       '%ccinp = chroma,interlace,ntsc/pal,swap write-only
  long  tv_screen     'pointer to screen (words)               write-only
  long  tv_colors     'pointer to colors (longs)               write-only               
  long  tv_hc         'horizontal cells                        write-only
  long  tv_vc         'vertical cells                          write-only
  long  tv_hx         'horizontal cell expansion               write-only
  long  tv_vx         'vertical cell expansion                 write-only
  long  tv_ho         'horizontal offset                       write-only
  long  tv_vo         'vertical offset                         write-only
  long  tv_broadcast  'broadcast frequency (Hz)                write-only
  long  tv_auralcog   'aural fm cog                            write-only

  word  screen[x_tiles * y_tiles] ' storage for screen tile map
  long  colors[64]                ' color look up table

  ' songs
  long song[MAX_SONGS]

  ' nes gamepad vars
  long nes_buttons
  long button_temp
  
'///////////////////////////////////////////////////////////////////////
' OBJECT DECLARATION SECTION ///////////////////////////////////////////
'///////////////////////////////////////////////////////////////////////
OBJ

  tv    : "EPM_tv_drv_011.spin"                ' Paralax tv driver, modified for 2 color 
  gr    : "EPM_graphics_drv_spacewar_012.spin" ' Paralax graphics driver, modified for 2 color 
  hdmf  : "EPM_HDMF_driver_010.spin"            'HDMF song driver    

'///////////////////////////////////////////////////////////////////////
' EXPORT PUBLICS  //////////////////////////////////////////////////////
'///////////////////////////////////////////////////////////////////////

PUB start | i , dx, dy

  '//// GLOBAL INITIALIZTION
  
  'start tv
  longmove(@tv_status, @tvparams, paramcount)
  tv_screen := @screen
  tv_colors := @colors
  tv.start(@tv_status)

  ' Start keyboard driver
  'key.start(3)

  'start music driver
  hdmf.start(0)

  'init debug LED
  DIRA [0] := 1 ' output 
  
  'init colors
  repeat i from 0 to 64
    colors[i] := $00001010 * (i+4) & $F + $FB060C02

  'init tile screen
  repeat dx from 0 to tv_hc - 1
    repeat dy from 0 to tv_vc - 1
      screen[dy * tv_hc + dx] := onscreen_buffer >> 6 + dy + dx * tv_vc + ((dy & $3F) << 10)

  'start and setup graphics
  gr.start
  gr.setup(16, 12, 128, 96, offscreen_buffer)

  '//// MAIN EXECUTION MANAGER
  repeat
    'PlaySong
    Configure_Options 

PUB Configure_Options | i, y, song_size, selected_option, string_ptr, num_options, menu_flags, key_repeat_ticks, current_option_mask, done
 
  selected_option := 0
  menu_flags      := 0
  done            := false

  repeat i from 0 to MAX_SONGS -1
    song[i] := 0

  i:=0
  song[i++] := @_song_mspacman
  song[i++] := @_song_galaga
  song[i++] := @_song_mario
  song[i++] := @_song_zelda
  song[i++] := @_song_tron_win
  song[i++] := @_song_tron_lose
  song[i++] := @_end_of_songs
    
  repeat while not done

    '//// Clear screen
    gr.clear        ' Clear bitmap

    '//// GET USER INPUT
    nes_buttons := NES_Read_Gamepad
    nes_buttons &= $ff
    if nes_buttons == $ff
      nes_buttons := 0
    
    '//// Draw titles
    gr.textmode(1,1,6,1)
    gr.colorwidth(2,0)
    y:=86
    gr.text(-43, y, string("HDMF - RAM DEMO"))

    y -= TEXT_LINE_SPACING
    gr.text(-28, y, string("VERSION 1.0"))

    y:=-55
    if hdmf.song_is_playing
      gr.text(-23, y, string("PLAYING"))
    else
      gr.text(-23, y, string(" IDLE")) 

    y:=-79
    gr.text(-110, y, string("WRITTEN BY ERIC MOYER. FOR THE LATEST"))
    y -= TEXT_LINE_SPACING 
    gr.text(-123, y, string("VERSION SEARCH HTTP://FORUMS.PARALLAX.COM"))

    '//// Draw options states
    string_ptr := @option_strings
    y := 50
    num_options := 0
    current_option_mask := $00000001
    repeat while (byte[string_ptr] <> $ff)

      '//// Draw option name
      gr.text(-60, y, string_ptr)
      repeat while byte[string_ptr] <> $0
          ++string_ptr
      ++string_ptr
      
      '//// Draw song size
      song_size := song[num_options+1]  - song[num_options]
      Int_To_String(@uint_string_0, song_size )
      gr.text(-100, y , @uint_string_0)
      
      '//// Toggle option, if seleted
      '     Note: 'num_options' at this point is really the current option.
      if (nes_buttons & NES_A) and (selected_option == num_options) and not(menu_flags & MENU_FLAG__A_HELD)
         hdmf.play_song(song[num_options], 0 {hdmf#HDMF__LOOP})
       
      '//// Advance to next line
      y -= 13
      ++num_options
      current_option_mask <<= 1
    
    '//// Point to current option
    y :=50 -(13 * selected_option)
    gr.vec(-120, y, $0020, ANG_0, @player_ship0)

    '//// PROCESS MENU SELECTION, ON KEY DOWN EVENTS WITH KEY REPEATS
    if menu_flags & MENU_FLAG__UP_DOWN_HELD 
      ++key_repeat_ticks
      if not(nes_buttons & CONSTANT(NES_DOWN | NES_UP))
        menu_flags &= CONSTANT(!(MENU_FLAG__UP_DOWN_HELD | MENU_FLAG__REPEAT_GO_TIME_MET | MENU_FLAG__DO_REPEAT_CLICK))
      if not(menu_flags & MENU_FLAG__REPEAT_GO_TIME_MET) and (key_repeat_ticks => 8)
        menu_flags |= CONSTANT(MENU_FLAG__REPEAT_GO_TIME_MET | MENU_FLAG__DO_REPEAT_CLICK)
      if (menu_flags & MENU_FLAG__REPEAT_GO_TIME_MET) and (key_repeat_ticks => 2)
        menu_flags |= MENU_FLAG__DO_REPEAT_CLICK  
        
    if (not(menu_flags & MENU_FLAG__UP_DOWN_HELD)) or (menu_flags & MENU_FLAG__DO_REPEAT_CLICK)
      if nes_buttons & NES_UP  
        menu_flags |= MENU_FLAG__UP_DOWN_HELD
        if selected_option == 0
          selected_option := num_options - 1
        else
          --selected_option
      if nes_buttons & NES_DOWN  
        menu_flags |= MENU_FLAG__UP_DOWN_HELD  
        if selected_option == num_options - 1
          selected_option := 0
        else
          ++selected_option
      key_repeat_ticks := 0
      menu_flags &= !MENU_FLAG__DO_REPEAT_CLICK

    '//// PROCESS "START"
    if (nes_buttons & NES_START)  
      done := true

    '//// PROCESS "STOP SONG"
    if (nes_buttons & NES_B)
       hdmf.stop_song      

    '//// PROCESS BUTTON HELD FLAG
    if (nes_buttons & NES_A) 
       menu_flags |= MENU_FLAG__A_HELD
    else 
       menu_flags &= !MENU_FLAG__A_HELD

    '//// COPY BITMAP TO DISPLAY
    gr.copy(onscreen_buffer)

PUB Int_To_Hex_String(str, i) | t, nibble
   
  ' does an sprintf(str, "%08lX", i); job
  ' assumes that '0x' is already in the first 2 character positions of the string
  str+=9
  repeat t from 0 to 7
    nibble := i & $0000000f
    if nibble =< 9
      BYTE[str] := 48 {'0'} + nibble
    else
      BYTE[str] := CONSTANT(65 {'A'} - 10) + nibble
    str--
    i >>= 4

PUB Int_To_String(str, i) | t
   
  ' does an sprintf(str, "%05d", i); job
  str+=4
  repeat t from 0 to 4
    BYTE[str] := 48+(i // 10)
    i/=10
    str--

PUB Signed_Int_To_String(str, i) | t
   
  'Print the sign
  if (i<0)
    i := -i
    BYTE[str] := 45  ' ASCII '-'
  else
    BYTE[str] := 43  ' ASCII '+' 
    
  str+=5
  repeat t from 0 to 4
    BYTE[str] := 48+(i // 10)
    i/=10
    str--
    
PUB Fixed_To_String(str, fixed) | t , i
  ' does an sprintf(str, "%+05.04f", i); job

  'Print the sign
  if (fixed<0)
    fixed := -fixed
    BYTE[str] := 45  ' ASCII '-' 
  else
    BYTE[str] := 43  ' ASCII '+'     
    
  'Print the fractional portion
  str+=10
  i := ((fixed & $0000_FFFF) * 10000) ~>16 'Get the fractional part, and convert to 5 decimal digits of accuracy.
  repeat t from 0 to 3
    BYTE[str] := 48+(i // 10)
    i/=10
    str--
   
  'Print the decimal point
  BYTE[str] := 46  '46 = ASCII Decimal point
  str-- 
   
  'Print the decimal portion
  i:=fixed~>16
  repeat t from 0 to 4
    BYTE[str] := 48+(i // 10)
    i/=10
    str--

' ////////////////////////////////////////////////////////////////////

PUB SinCos(op, angle): xy               
  if (op==COS)
    angle+=$800   

  if angle & $1000 
    if angle & $800
      -angle
    angle |= $7000
    xy := -word[angle << 1]
  else
    if angle & $800
      -angle
    angle |= $7000
    xy := word[angle << 1]

' //////////////////////////////////////////////////////////////////////


PUB NES_Read_Gamepad : nes_bits        |  i

' //////////////////////////////////////////////////////////////////
' NES Game Paddle Read
' //////////////////////////////////////////////////////////////////       
' reads both gamepads in parallel encodes 8-bits for each in format
' right game pad #1 [15..8] : left game pad #0 [7..0]
'
' set I/O ports to proper direction
' P3 = JOY_CLK      (4)
' P4 = JOY_SH/LDn   (5) 
' P5 = JOY_DATAOUT0 (6)
' P6 = JOY_DATAOUT1 (7)
' NES Bit Encoding
'
' RIGHT  = %00000001
' LEFT   = %00000010
' DOWN   = %00000100
' UP     = %00001000
' START  = %00010000
' SELECT = %00100000
' B      = %01000000
' A      = %10000000

' step 1: set I/Os
DIRA [3] := 1 ' output
DIRA [4] := 1 ' output
DIRA [5] := 0 ' input
DIRA [6] := 0 ' input

' step 2: set clock and latch to 0
OUTA [3] := 0 ' JOY_CLK = 0
OUTA [4] := 0 ' JOY_SH/LDn = 0
'Delay(1)

' step 3: set latch to 1
OUTA [4] := 1 ' JOY_SH/LDn = 1
'Delay(1)

' step 4: set latch to 0
OUTA [4] := 0 ' JOY_SH/LDn = 0

' step 5: read first bit of each game pad

' data is now ready to shift out
' first bit is ready 
nes_bits := 0

' left controller
nes_bits := INA[5] | (INA[6] << 8)

' step 7: read next 7 bits
repeat i from 0 to 6
 OUTA [3] := 1 ' JOY_CLK = 1
 'Delay(1)             
 OUTA [3] := 0 ' JOY_CLK = 0
 nes_bits := (nes_bits << 1)
 nes_bits := nes_bits | INA[5] | (INA[6] << 8)

 'Delay(1)             
' invert bits to make positive logic
nes_bits := (!nes_bits & $FFFF)

' //////////////////////////////////////////////////////////////////
' End NES Game Paddle Read
' //////////////////////////////////////////////////////////////////


'///////////////////////////////////////////////////////////////////////
' DATA SECTION /////////////////////////////////////////////////////////
'///////////////////////////////////////////////////////////////////////

DAT


' BLACK HOLES ///////////////////////////////////////////////////////////
{
' black hole initialization
black_x                  long 20,  80, -90 ' x position of each black hole
black_y                  long 50, -60, -10 ' y position of each black hole
black_gravity            long  8,  4,  2   ' single value that is "lumped" parameter that relates to the final "pull"
                                           ' of the black hole relative to the ship's constant mass
}

' STRING STORAGE //////////////////////////////////////////////////////
{
score_string            byte    "Score",0               'text
hiscore_string          byte    "High",0                'text
ships_string            byte    "Ships",0               'text
}

' TV PARAMETERS FOR DRIVER /////////////////////////////////////////////

tvparams                long    0               'status
                        long    1               'enable
                        long    %011_0000       'pins
                        long    %0000           'mode
                        long    0               'screen
                        long    0               'colors
                        long    x_tiles         'hc
                        long    y_tiles         'vc
                        long    10              'hx timing stretch
                        long    1               'vx
                        long    0               'ho
                        long    0               'vo
                        long    55_250_000      'broadcast
                        long    0               'auralcog

' POLYGON OBJECTS ///////////////////////////////////////////////////////
  
player_ship0            word    VECTOR_MOVE + ANG_0             
                        word    50

                        word    VECTOR_DRAW + ANG_120+ANG_10
                        word    50

                        word    VECTOR_DRAW + ANG_180
                        word    10

                        word    VECTOR_DRAW + ANG_240-ANG_10  
                        word    50

                        word    VECTOR_DRAW + ANG_0
                        word    50

                        word    VECTOR_END
                      

fixed_pt_string_0        byte    "-00000.0000",0    'text
int_string_0             byte    "-00000",0         'text
uint_string_0            byte    "00000",0         'text 
hex_string_0             byte    "0X00000000",0     'text

option_strings           byte    "MS PAC MAN",0               'text
                         byte    "GALAGA",0                   'text
                         byte    "MARIO",0                    'text
                         byte    "ZELDA, (ZMM CLOCK TOWER)",0 'text
                         byte    "TRON SUCCESS",0             'text
                         byte    "TRON FAILURE",0             'text
                         byte    $ff                          'end of option string list


_song_mspacman
        byte    $02, $EF, $AD, $79, $35          'Instrument 0
        byte    $03, $EF, $AD, $79, $35          'Instrument 1
        byte    $FF                              'End of Instrument list
        byte    $00, $02, $0B, $2C, $08
        byte    $08, $02, $4B, $2C, $08
        byte    $09, $02, $93, $2C, $08
        byte    $08, $00, $AF, $0C, $18
        byte    $00, $22, $BA, $2C, $18
        byte    $19, $03, $70, $2C, $18
        byte    $19, $00, $83, $0C, $18
        byte    $00, $23, $10, $2C, $18
        byte    $19, $03, $A4, $2C, $18
        byte    $19, $00, $AF, $0C, $18
        byte    $00, $23, $70, $2C, $0C
        byte    $0C, $23, $A4, $2C, $0C
        byte    $0D, $04, $17, $2C, $0C
        byte    $0D, $03, $70, $2C, $0C
        byte    $0C, $00, $C4, $0C, $0C
        byte    $00, $23, $10, $2C, $18
        byte    $0C, $00, $DC, $0C, $0C
        byte    $0D, $03, $A4, $2C, $18
        byte    $00, $20, $E9, $0C, $0C
        byte    $0D, $20, $C4, $0C, $0C
        byte    $0C, $00, $DC, $0C, $0C
        byte    $00, $23, $70, $2C, $0C
        byte    $0C, $00, $C4, $0C, $0C
        byte    $00, $23, $A4, $2C, $0C
        byte    $0D, $04, $17, $2C, $0C
        byte    $00, $20, $AF, $0C, $0C
        byte    $0D, $03, $70, $2C, $0C
        byte    $00, $20, $DC, $0C, $0C
        byte    $0C, $00, $C4, $0C, $0C
        byte    $00, $23, $A4, $2C, $0C
        byte    $0C, $00, $AF, $0C, $0C
        byte    $00, $24, $17, $2C, $0C
        byte    $0D, $00, $A5, $0C, $0C
        byte    $00, $24, $97, $2C, $0C
        byte    $0D, $00, $C4, $0C, $0C
        byte    $00, $25, $27, $2C, $0C
        byte    $0C, $05, $75, $2C, $18
        byte    $00, $20, $AF, $0C, $18
        byte    $19, $00, $83, $0C, $18
        byte    $00, $25, $27, $2C, $18
        byte    $19, $00, $AF, $0C, $18
        byte    $00, $25, $75, $2C, $18
        byte    $ff

_song_galaga
        byte    $02, $EF, $AD, $79, $35          'Instrument 0
        byte    $FF                              'End of Instrument list
        byte    $00, $03, $10, $08, $1D
        byte    $00, $21, $4A, $0C, $1D
        byte    $00, $43, $10, $0B, $1D
        byte    $00, $60, $C4, $0B, $1D
        byte    $00, $80, $C4, $08, $1D
        byte    $1D, $01, $06, $0B, $0E
        byte    $00, $24, $17, $0A, $0E
        byte    $00, $41, $06, $0A, $0E
        byte    $0E, $03, $70, $09, $2B
        byte    $00, $21, $26, $0C, $1D
        byte    $00, $44, $97, $0B, $1D
        byte    $00, $61, $26, $0B, $1D
        byte    $00, $80, $DC, $09, $2B
        byte    $1D, $20, $DC, $07, $0E
        byte    $00, $45, $75, $0A, $0E
        byte    $00, $61, $5D, $0A, $0E
        byte    $0E, $03, $DC, $08, $2B
        byte    $00, $21, $06, $0B, $1D
        byte    $00, $45, $27, $0B, $1D
        byte    $00, $61, $4A, $0B, $1D
        byte    $00, $80, $F7, $08, $2B
        byte    $1D, $20, $C4, $09, $0E
        byte    $00, $44, $17, $0A, $0E
        byte    $00, $61, $06, $0A, $0E
        byte    $0E, $03, $70, $08, $1D
        byte    $00, $20, $DC, $0A, $1D
        byte    $00, $44, $97, $0B, $1D
        byte    $00, $61, $26, $0B, $1D
        byte    $00, $80, $DC, $08, $1D
        byte    $1D, $04, $97, $0A, $0E
        byte    $00, $21, $26, $0B, $0E
        byte    $00, $46, $E0, $09, $0E
        byte    $00, $61, $B8, $09, $0E
        byte    $00, $81, $26, $0A, $0E
        byte    $0E, $05, $27, $0B, $2B
        byte    $00, $21, $06, $0C, $1D
        byte    $00, $46, $20, $0A, $1D
        byte    $00, $61, $88, $0A, $1D
        byte    $00, $81, $4A, $0B, $2B
        byte    $1C, $A1, $06, $0D, $0E
        byte    $00, $24, $17, $0A, $0E
        byte    $00, $41, $06, $0A, $0E
        byte    $0F, $03, $10, $07, $0E
        byte    $00, $23, $70, $0B, $2B
        byte    $00, $41, $26, $0C, $1D
        byte    $00, $64, $97, $0C, $1D
        byte    $00, $81, $26, $0C, $1D
        byte    $00, $A0, $C4, $07, $0E
        byte    $00, $00, $DC, $0B, $2B
        byte    $1C, $A0, $DC, $0A, $0E
        byte    $00, $45, $75, $09, $0E
        byte    $00, $61, $5D, $09, $0E
        byte    $0F, $03, $DC, $08, $2B
        byte    $00, $21, $06, $0B, $1D
        byte    $00, $45, $27, $0A, $1D
        byte    $00, $61, $4A, $0A, $1D
        byte    $00, $80, $F7, $08, $2B
        byte    $1C, $A1, $88, $0A, $0E
        byte    $00, $24, $17, $0B, $0E
        byte    $00, $41, $06, $0B, $0E
        byte    $0E, $23, $10, $09, $0E
        byte    $00, $41, $EE, $0B, $1D
        byte    $00, $66, $20, $09, $1D
        byte    $00, $A1, $88, $09, $1D
        byte    $00, $00, $C4, $09, $0E
        byte    $1D, $02, $4B, $08, $0E
        byte    $00, $27, $B8, $08, $0E
        byte    $00, $41, $EE, $08, $0E
        byte    $0E, $06, $7D, $0C, $0E
        byte    $00, $22, $6E, $0D, $1D
        byte    $00, $48, $2D, $0A, $1D
        byte    $00, $62, $0B, $0A, $1D
        byte    $00, $81, $9F, $0C, $0E
        byte    $1D, $06, $20, $09, $0E
        byte    $00, $22, $4B, $0A, $0E
        byte    $00, $47, $49, $0B, $0E
        byte    $00, $61, $D2, $0B, $0E
        byte    $00, $81, $88, $09, $0E
        byte    $0E, $05, $75, $08, $0E
        byte    $00, $22, $0B, $0A, $1D
        byte    $00, $46, $7D, $0C, $1D
        byte    $00, $61, $9F, $0C, $1D
        byte    $00, $81, $5D, $08, $0E
        byte    $1D, $04, $DD, $09, $0E
        byte    $00, $21, $D2, $0B, $0E
        byte    $00, $46, $20, $08, $0E
        byte    $00, $61, $88, $08, $0E
        byte    $00, $81, $37, $09, $0E
        byte    $0E, $04, $97, $0A, $1D
        byte    $00, $21, $9F, $0C, $1D
        byte    $00, $45, $75, $0A, $1D
        byte    $00, $61, $5D, $0A, $1D
        byte    $00, $81, $26, $0A, $1D
        byte    $1D, $01, $88, $0A, $0E
        byte    $00, $24, $DD, $0B, $0E
        byte    $00, $41, $37, $0B, $0E
        byte    $0E, $03, $A4, $0A, $1D
        byte    $00, $21, $5D, $0B, $1D
        byte    $00, $44, $97, $0A, $1D
        byte    $00, $61, $26, $0A, $1D
        byte    $00, $80, $E9, $0A, $1D
        byte    $1C, $A1, $D2, $0C, $0E
        byte    $00, $03, $A4, $0A, $0E
        byte    $00, $20, $E9, $0A, $0E
        byte    $0F, $04, $DD, $0C, $0E
        byte    $00, $21, $88, $0B, $1D
        byte    $00, $47, $49, $0B, $1D
        byte    $00, $61, $D2, $0B, $1D
        byte    $00, $81, $37, $0C, $0E
        byte    $1C, $05, $75, $0A, $0E
        byte    $00, $81, $9F, $0B, $0E
        byte    $00, $A8, $2D, $0A, $0E
        byte    $00, $22, $0B, $0A, $0E
        byte    $00, $41, $5D, $0A, $0E
        byte    $0F, $04, $DD, $0B, $0E
        byte    $00, $21, $88, $0B, $1D
        byte    $00, $47, $49, $0B, $1D
        byte    $00, $61, $D2, $0B, $1D
        byte    $00, $81, $37, $0B, $0E
        byte    $1C, $01, $37, $0B, $0E
        byte    $00, $86, $20, $0A, $0E
        byte    $00, $A1, $88, $0A, $0E
        byte    $0E, $05, $75, $0A, $0E
        byte    $00, $21, $5D, $0A, $0E
        byte    $00, $46, $E0, $0A, $0E
        byte    $00, $61, $B8, $0A, $0E
        byte    $00, $81, $5D, $0A, $0E
        byte    $0F, $04, $97, $0B, $0E
        byte    $00, $21, $26, $0C, $0E
        byte    $00, $45, $75, $09, $0E
        byte    $00, $61, $5D, $09, $0E
        byte    $00, $81, $26, $0B, $0E
        byte    $0E, $03, $70, $0A, $0E
        byte    $00, $20, $DC, $0A, $0E
        byte    $00, $44, $97, $0B, $0E
        byte    $00, $61, $26, $0B, $0E
        byte    $00, $80, $DC, $0A, $0E
        byte    $0E, $04, $97, $0D, $0E
        byte    $00, $21, $26, $0C, $0E
        byte    $00, $46, $20, $0A, $0E
        byte    $00, $61, $88, $0A, $0E
        byte    $00, $81, $26, $0D, $0E
        byte    $0F, $03, $DC, $0A, $0E
        byte    $00, $20, $F7, $0A, $0E
        byte    $00, $45, $27, $0C, $0E
        byte    $00, $61, $4A, $0C, $0E
        byte    $00, $80, $F7, $0A, $0E
        byte    $0E, $03, $70, $0B, $0E
        byte    $00, $20, $DC, $0B, $0E
        byte    $00, $44, $97, $0C, $0E
        byte    $00, $61, $26, $0C, $0E
        byte    $00, $80, $DC, $0B, $0E
        byte    $ff

_song_mario
        byte    $02, $EF, $AD, $79, $35          'Instrument 0
        byte    $FF                              'End of Instrument list
        byte    $00, $00, $49, $0D, $0F
        byte    $00, $20, $93, $0D, $0F
        byte    $00, $42, $93, $0D, $0F
        byte    $10, $61, $72, $0D, $0F
        byte    $00, $80, $93, $0D, $0F
        byte    $00, $A0, $49, $0D, $0F
        byte    $00, $02, $93, $0D, $0F
        byte    $1F, $20, $49, $0D, $0F
        byte    $00, $41, $72, $0D, $0F
        byte    $00, $02, $93, $0D, $0F
        byte    $00, $60, $93, $0D, $0F
        byte    $1F, $81, $72, $0D, $0F
        byte    $00, $A0, $93, $0D, $0F
        byte    $00, $00, $49, $0D, $0F
        byte    $00, $22, $0B, $0D, $0F
        byte    $10, $41, $72, $0D, $0F
        byte    $00, $60, $49, $0D, $0F
        byte    $00, $00, $93, $0D, $0F
        byte    $00, $22, $93, $0D, $0F
        byte    $1F, $83, $10, $0D, $10
        byte    $00, $A1, $EE, $0D, $10
        byte    $00, $01, $88, $0D, $10
        byte    $00, $20, $C4, $0D, $10
        byte    $00, $40, $62, $0D, $10
        byte    $3F, $61, $88, $0D, $10
        byte    $00, $00, $C4, $0D, $10
        byte    $00, $20, $62, $0D, $10
        byte    $3E, $41, $4A, $0D, $0F
        byte    $00, $80, $C4, $0D, $0F
        byte    $00, $A0, $83, $0D, $0F
        byte    $00, $02, $0B, $0D, $0F
        byte    $2F, $21, $06, $0D, $0F
        byte    $00, $60, $A5, $0D, $0F
        byte    $00, $00, $83, $0D, $0F
        byte    $00, $41, $88, $0D, $0F
        byte    $2F, $80, $83, $0D, $0F
        byte    $00, $A1, $4A, $0D, $0F
        byte    $00, $00, $C4, $0D, $0F
        byte    $2F, $21, $06, $0D, $0F
        byte    $00, $41, $B8, $0D, $0F
        byte    $00, $60, $AF, $0D, $0F
        byte    $1F, $01, $EE, $0D, $0F
        byte    $00, $81, $26, $0D, $0F
        byte    $00, $A0, $C4, $0D, $0F
        byte    $1F, $21, $D2, $0D, $0F
        byte    $00, $41, $15, $0D, $0F
        byte    $00, $60, $B9, $0D, $0F
        byte    $10, $01, $B8, $0D, $0F
        byte    $00, $81, $06, $0D, $0F
        byte    $00, $A0, $AF, $0D, $0F
        byte    $1F, $21, $06, $0D, $14
        byte    $00, $41, $88, $0D, $14
        byte    $00, $60, $A5, $0D, $14
        byte    $15, $01, $88, $0D, $14
        byte    $00, $81, $06, $0D, $14
        byte    $00, $A0, $C4, $0D, $14
        byte    $00, $22, $93, $0D, $14
        byte    $15, $41, $EE, $0D, $14
        byte    $00, $61, $06, $0D, $14
        byte    $00, $03, $10, $0D, $14
        byte    $00, $21, $4A, $0D, $14
        byte    $14, $81, $5D, $0D, $0F
        byte    $00, $A0, $DC, $0D, $0F
        byte    $00, $03, $70, $0D, $0F
        byte    $00, $22, $0B, $0D, $0F
        byte    $20, $41, $B8, $0D, $0F
        byte    $00, $61, $26, $0D, $0F
        byte    $00, $02, $BA, $0D, $0F
        byte    $0F, $21, $EE, $0D, $1F
        byte    $00, $83, $10, $0D, $1F
        byte    $00, $A1, $4A, $0D, $1F
        byte    $20, $01, $B8, $0D, $0F
        byte    $00, $42, $93, $0D, $0F
        byte    $00, $60, $DC, $0D, $0F
        byte    $00, $21, $06, $0D, $0F
        byte    $1F, $82, $0B, $0D, $0F
        byte    $00, $A1, $4A, $0D, $0F
        byte    $00, $00, $DC, $0D, $0F
        byte    $10, $22, $4B, $0D, $0F
        byte    $00, $41, $5D, $0D, $0F
        byte    $00, $60, $F7, $0D, $0F
        byte    $0F, $01, $26, $0D, $0F
        byte    $00, $81, $EE, $0D, $0F
        byte    $00, $A0, $C4, $0D, $0F
        byte    $2F, $22, $0B, $0D, $0F
        byte    $00, $41, $4A, $0D, $0F
        byte    $00, $60, $C4, $0D, $0F
        byte    $00, $00, $83, $0D, $0F
        byte    $2F, $81, $06, $0D, $0F
        byte    $00, $A1, $88, $0D, $0F
        byte    $00, $00, $A5, $0D, $0F
        byte    $00, $20, $83, $0D, $0F
        byte    $2F, $41, $4A, $0D, $0F
        byte    $00, $60, $C4, $0D, $0F
        byte    $00, $00, $83, $0D, $0F
        byte    $2F, $21, $B8, $0D, $0F
        byte    $00, $81, $06, $0D, $0F
        byte    $00, $A0, $AF, $0D, $0F
        byte    $1F, $01, $26, $0D, $0F
        byte    $00, $40, $C4, $0D, $0F
        byte    $00, $61, $EE, $0D, $0F
        byte    $1F, $21, $D2, $0D, $0F
        byte    $00, $80, $B9, $0D, $0F
        byte    $00, $A1, $15, $0D, $0F
        byte    $10, $01, $B8, $0D, $0F
        byte    $00, $41, $06, $0D, $0F
        byte    $00, $60, $AF, $0D, $0F
        byte    $1F, $21, $06, $0D, $14
        byte    $00, $80, $A5, $0D, $14
        byte    $00, $A1, $88, $0D, $14
        byte    $15, $01, $06, $0D, $14
        byte    $00, $40, $C4, $0D, $14
        byte    $00, $61, $88, $0D, $14
        byte    $00, $22, $93, $0D, $14
        byte    $15, $81, $06, $0D, $14
        byte    $00, $A1, $4A, $0D, $14
        byte    $00, $03, $10, $0D, $14
        byte    $00, $21, $EE, $0D, $14
        byte    $14, $43, $70, $0D, $0F
        byte    $00, $62, $0B, $0D, $0F
        byte    $00, $00, $DC, $0D, $0F
        byte    $00, $21, $5D, $0D, $0F
        byte    $20, $82, $BA, $0D, $0F
        byte    $00, $A1, $B8, $0D, $0F
        byte    $00, $01, $26, $0D, $0F
        byte    $0F, $21, $EE, $0D, $1F
        byte    $00, $43, $10, $0D, $1F
        byte    $00, $61, $4A, $0D, $1F
        byte    $20, $02, $93, $0D, $0F
        byte    $00, $81, $B8, $0D, $0F
        byte    $00, $A1, $06, $0D, $0F
        byte    $00, $20, $DC, $0D, $0F
        byte    $1F, $42, $0B, $0D, $0F
        byte    $00, $61, $4A, $0D, $0F
        byte    $00, $00, $DC, $0D, $0F
        byte    $10, $22, $4B, $0D, $0F
        byte    $00, $81, $5D, $0D, $0F
        byte    $00, $A0, $F7, $0D, $0F
        byte    $0F, $01, $26, $0D, $0F
        byte    $00, $41, $EE, $0D, $0F
        byte    $00, $60, $C4, $0D, $0F
        byte    $2F, $20, $83, $0D, $2E
        byte    $1F, $83, $10, $0D, $0F
        byte    $00, $A2, $93, $0D, $0F
        byte    $10, $02, $6E, $0D, $0F
        byte    $00, $42, $E4, $0D, $0F
        byte    $00, $60, $C4, $0D, $2E
        byte    $0F, $22, $BA, $0D, $0F
        byte    $00, $82, $4B, $0D, $0F
        byte    $10, $A1, $EE, $0D, $0F
        byte    $00, $02, $6E, $0D, $0F
        byte    $10, $41, $06, $0D, $1F
        byte    $0F, $22, $93, $0D, $0F
        byte    $00, $82, $0B, $0D, $0F
        byte    $10, $00, $AF, $0D, $2E
        byte    $10, $61, $9F, $0D, $0F
        byte    $00, $A1, $4A, $0D, $0F
        byte    $0F, $21, $B8, $0D, $0F
        byte    $00, $81, $5D, $0D, $0F
        byte    $10, $42, $0B, $0D, $0F
        byte    $00, $61, $88, $0D, $0F
        byte    $00, $A1, $06, $0D, $2E
        byte    $1F, $01, $B8, $0D, $0F
        byte    $00, $21, $06, $0D, $0F
        byte    $10, $81, $4A, $0D, $0F
        byte    $00, $40, $AF, $0D, $1F
        byte    $00, $62, $0B, $0D, $0F
        byte    $0F, $02, $4B, $0D, $0F
        byte    $00, $21, $5D, $0D, $0F
        byte    $10, $A0, $83, $0D, $2E
        byte    $1F, $62, $93, $0D, $0F
        byte    $00, $83, $10, $0D, $0F
        byte    $10, $02, $6E, $0D, $0F
        byte    $00, $20, $C4, $0D, $2E
        byte    $00, $42, $E4, $0D, $0F
        byte    $0F, $62, $BA, $0D, $0F
        byte    $00, $82, $4B, $0D, $0F
        byte    $10, $A1, $EE, $0D, $0F
        byte    $00, $02, $6E, $0D, $0F
        byte    $10, $41, $06, $0D, $1F
        byte    $0F, $62, $93, $0D, $0F
        byte    $00, $82, $0B, $0D, $0F
        byte    $10, $00, $AF, $0D, $2E
        byte    $10, $23, $10, $0D, $0F
        byte    $00, $A2, $BA, $0D, $0F
        byte    $00, $64, $17, $0D, $0F
        byte    $1F, $81, $06, $0D, $2E
        byte    $00, $42, $BA, $0D, $0F
        byte    $00, $24, $17, $0D, $0F
        byte    $00, $63, $10, $0D, $0F
        byte    $0F, $A4, $17, $0D, $0F
        byte    $00, $03, $10, $0D, $0F
        byte    $00, $22, $BA, $0D, $0F
        byte    $20, $40, $AF, $0D, $1F
        byte    $1F, $60, $83, $0D, $2E
        byte    $1F, $03, $10, $0D, $0F
        byte    $00, $22, $93, $0D, $0F
        byte    $10, $A2, $6E, $0D, $0F
        byte    $00, $82, $E4, $0D, $0F
        byte    $00, $40, $C4, $0D, $2E
        byte    $0F, $02, $4B, $0D, $0F
        byte    $00, $22, $BA, $0D, $0F
        byte    $10, $61, $EE, $0D, $0F
        byte    $00, $82, $6E, $0D, $0F
        byte    $10, $A1, $06, $0D, $1F
        byte    $0F, $02, $0B, $0D, $0F
        byte    $00, $22, $93, $0D, $0F
        byte    $10, $40, $AF, $0D, $2E
        byte    $10, $61, $9F, $0D, $0F
        byte    $00, $81, $4A, $0D, $0F
        byte    $0F, $01, $5D, $0D, $0F
        byte    $00, $21, $B8, $0D, $0F
        byte    $10, $A1, $88, $0D, $0F
        byte    $00, $61, $06, $0D, $2E
        byte    $00, $82, $0B, $0D, $0F
        byte    $1F, $01, $06, $0D, $0F
        byte    $00, $21, $B8, $0D, $0F
        byte    $10, $40, $AF, $0D, $1F
        byte    $00, $81, $4A, $0D, $0F
        byte    $00, $A2, $0B, $0D, $0F
        byte    $0F, $02, $4B, $0D, $0F
        byte    $00, $21, $5D, $0D, $0F
        byte    $10, $60, $68, $0D, $1F
        byte    $1F, $82, $6E, $0D, $0F
        byte    $00, $A1, $9F, $0D, $0F
        byte    $00, $00, $D0, $0D, $2E
        byte    $00, $20, $68, $0D, $2E
        byte    $2F, $42, $4B, $0D, $0F
        byte    $00, $61, $5D, $0D, $0F
        byte    $00, $80, $E9, $0D, $2E
        byte    $00, $A0, $75, $0D, $2E
        byte    $2F, $02, $0B, $0D, $0F
        byte    $00, $21, $4A, $0D, $0F
        byte    $00, $41, $06, $0D, $1F
        byte    $00, $60, $83, $0D, $1F
        byte    $2F, $80, $62, $0D, $0F
        byte    $00, $A0, $C4, $0D, $0F
        byte    $10, $00, $C4, $0D, $0F
        byte    $00, $20, $62, $0D, $0F
        byte    $1F, $40, $83, $0D, $0F
        byte    $1F, $60, $83, $0D, $2E
        byte    $1F, $83, $10, $0D, $0F
        byte    $00, $A2, $93, $0D, $0F
        byte    $10, $02, $E4, $0D, $0F
        byte    $00, $22, $6E, $0D, $0F
        byte    $00, $40, $C4, $0D, $2E
        byte    $0F, $62, $4B, $0D, $0F
        byte    $00, $82, $BA, $0D, $0F
        byte    $10, $A2, $6E, $0D, $0F
        byte    $00, $01, $EE, $0D, $0F
        byte    $10, $21, $06, $0D, $1F
        byte    $0F, $62, $93, $0D, $0F
        byte    $00, $82, $0B, $0D, $0F
        byte    $10, $00, $AF, $0D, $2E
        byte    $10, $41, $9F, $0D, $0F
        byte    $00, $A1, $4A, $0D, $0F
        byte    $0F, $61, $B8, $0D, $0F
        byte    $00, $81, $5D, $0D, $0F
        byte    $10, $22, $0B, $0D, $0F
        byte    $00, $41, $88, $0D, $0F
        byte    $00, $A1, $06, $0D, $2E
        byte    $1F, $01, $06, $0D, $0F
        byte    $00, $61, $B8, $0D, $0F
        byte    $10, $80, $AF, $0D, $1F
        byte    $00, $22, $0B, $0D, $0F
        byte    $00, $41, $4A, $0D, $0F
        byte    $0F, $02, $4B, $0D, $0F
        byte    $00, $61, $5D, $0D, $0F
        byte    $10, $A0, $83, $0D, $2E
        byte    $1F, $23, $10, $0D, $0F
        byte    $00, $42, $93, $0D, $0F
        byte    $10, $02, $6E, $0D, $0F
        byte    $00, $60, $C4, $0D, $2E
        byte    $00, $82, $E4, $0D, $0F
        byte    $0F, $22, $BA, $0D, $0F
        byte    $00, $42, $4B, $0D, $0F
        byte    $10, $A2, $6E, $0D, $0F
        byte    $00, $01, $EE, $0D, $0F
        byte    $10, $81, $06, $0D, $1F
        byte    $0F, $22, $93, $0D, $0F
        byte    $00, $42, $0B, $0D, $0F
        byte    $10, $00, $AF, $0D, $2E
        byte    $10, $64, $17, $0D, $0F
        byte    $00, $A2, $BA, $0D, $0F
        byte    $00, $23, $10, $0D, $0F
        byte    $1F, $44, $17, $0D, $0F
        byte    $00, $82, $BA, $0D, $0F
        byte    $00, $23, $10, $0D, $0F
        byte    $00, $61, $06, $0D, $2E
        byte    $10, $A4, $17, $0D, $0F
        byte    $00, $03, $10, $0D, $0F
        byte    $00, $22, $BA, $0D, $0F
        byte    $1F, $40, $AF, $0D, $1F
        byte    $1F, $80, $83, $0D, $2E
        byte    $1F, $02, $93, $0D, $0F
        byte    $00, $23, $10, $0D, $0F
        byte    $10, $A2, $E4, $0D, $0F
        byte    $00, $62, $6E, $0D, $0F
        byte    $00, $40, $C4, $0D, $2E
        byte    $0F, $02, $BA, $0D, $0F
        byte    $00, $22, $4B, $0D, $0F
        byte    $10, $82, $6E, $0D, $0F
        byte    $00, $61, $EE, $0D, $0F
        byte    $10, $A1, $06, $0D, $1F
        byte    $0F, $02, $0B, $0D, $0F
        byte    $00, $22, $93, $0D, $0F
        byte    $10, $40, $AF, $0D, $2E
        byte    $10, $61, $9F, $0D, $0F
        byte    $00, $81, $4A, $0D, $0F
        byte    $0F, $01, $B8, $0D, $0F
        byte    $00, $21, $5D, $0D, $0F
        byte    $10, $A2, $0B, $0D, $0F
        byte    $00, $61, $88, $0D, $0F
        byte    $00, $81, $06, $0D, $2E
        byte    $1F, $01, $B8, $0D, $0F
        byte    $00, $21, $06, $0D, $0F
        byte    $10, $42, $0B, $0D, $0F
        byte    $00, $61, $4A, $0D, $0F
        byte    $00, $A0, $AF, $0D, $1F
        byte    $0F, $01, $5D, $0D, $0F
        byte    $00, $22, $4B, $0D, $0F
        byte    $10, $80, $68, $0D, $1F
        byte    $1F, $42, $6E, $0D, $0F
        byte    $00, $61, $9F, $0D, $0F
        byte    $00, $00, $D0, $0D, $2E
        byte    $00, $20, $68, $0D, $2E
        byte    $2F, $A2, $4B, $0D, $0F
        byte    $00, $81, $5D, $0D, $0F
        byte    $00, $40, $75, $0D, $2E
        byte    $00, $60, $E9, $0D, $2E
        byte    $2F, $02, $0B, $0D, $0F
        byte    $00, $21, $4A, $0D, $0F
        byte    $00, $81, $06, $0D, $1F
        byte    $00, $A0, $83, $0D, $1F
        byte    $2F, $40, $C4, $0D, $0F
        byte    $00, $60, $62, $0D, $0F
        byte    $0F, $00, $C4, $0D, $0F
        byte    $00, $20, $62, $0D, $0F
        byte    $20, $80, $83, $0D, $0F
        byte    $1F, $A2, $0B, $0D, $0F
        byte    $00, $41, $9F, $0D, $0F
        byte    $00, $60, $68, $0D, $2E
        byte    $10, $02, $0B, $0D, $0F
        byte    $00, $21, $9F, $0D, $0F
        byte    $1F, $82, $0B, $0D, $0F
        byte    $00, $41, $9F, $0D, $0F
        byte    $00, $A0, $9C, $0D, $2E
        byte    $1F, $01, $9F, $0D, $0F
        byte    $00, $22, $0B, $0D, $0F
        byte    $10, $62, $4B, $0D, $0F
        byte    $00, $41, $D2, $0D, $0F
        byte    $00, $80, $D0, $0D, $1F
        byte    $1F, $02, $93, $0D, $0F
        byte    $00, $21, $88, $0D, $0F
        byte    $00, $A0, $83, $0D, $2E
        byte    $10, $42, $0B, $0D, $0F
        byte    $00, $61, $4A, $0D, $0F
        byte    $1F, $81, $B8, $0D, $0F
        byte    $00, $01, $4A, $0D, $0F
        byte    $00, $20, $C4, $0D, $2E
        byte    $0F, $41, $88, $0D, $0F
        byte    $00, $61, $06, $0D, $0F
        byte    $20, $A1, $06, $0D, $1F
        byte    $1F, $02, $0B, $0D, $0F
        byte    $00, $80, $68, $0D, $2E
        byte    $00, $41, $9F, $0D, $0F
        byte    $10, $61, $9F, $0D, $0F
        byte    $00, $22, $0B, $0D, $0F
        byte    $1F, $A2, $0B, $0D, $0F
        byte    $00, $01, $9F, $0D, $0F
        byte    $00, $40, $9C, $0D, $2E
        byte    $1F, $21, $9F, $0D, $0F
        byte    $00, $62, $0B, $0D, $0F
        byte    $10, $80, $D0, $0D, $1F
        byte    $00, $01, $D2, $0D, $0F
        byte    $00, $A2, $4B, $0D, $0F
        byte    $0F, $22, $93, $0D, $0F
        byte    $00, $41, $88, $0D, $0F
        byte    $10, $60, $83, $0D, $2E
        byte    $2F, $00, $C4, $0D, $2E
        byte    $2F, $A1, $06, $0D, $1F
        byte    $1F, $20, $68, $0D, $2E
        byte    $00, $41, $9F, $0D, $0F
        byte    $00, $82, $0B, $0D, $0F
        byte    $10, $62, $0B, $0D, $0F
        byte    $00, $01, $9F, $0D, $0F
        byte    $1F, $A0, $9C, $0D, $2E
        byte    $00, $42, $0B, $0D, $0F
        byte    $00, $81, $9F, $0D, $0F
        byte    $1F, $01, $9F, $0D, $0F
        byte    $00, $62, $0B, $0D, $0F
        byte    $10, $20, $D0, $0D, $1F
        byte    $00, $42, $4B, $0D, $0F
        byte    $00, $81, $D2, $0D, $0F
        byte    $1F, $00, $83, $0D, $2E
        byte    $00, $61, $88, $0D, $0F
        byte    $00, $A2, $93, $0D, $0F
        byte    $10, $41, $4A, $0D, $0F
        byte    $00, $82, $0B, $0D, $0F
        byte    $1F, $21, $4A, $0D, $0F
        byte    $00, $60, $C4, $0D, $2E
        byte    $00, $A1, $B8, $0D, $0F
        byte    $0F, $41, $06, $0D, $0F
        byte    $00, $81, $88, $0D, $0F
        byte    $20, $01, $06, $0D, $1F
        byte    $1F, $20, $93, $0D, $0F
        byte    $00, $A0, $49, $0D, $0F
        byte    $00, $42, $93, $0D, $0F
        byte    $00, $81, $72, $0D, $0F
        byte    $10, $60, $49, $0D, $0F
        byte    $00, $00, $93, $0D, $0F
        byte    $00, $21, $72, $0D, $0F
        byte    $00, $42, $93, $0D, $0F
        byte    $1F, $80, $49, $0D, $0F
        byte    $00, $A0, $93, $0D, $0F
        byte    $00, $02, $93, $0D, $0F
        byte    $00, $21, $72, $0D, $0F
        byte    $1F, $42, $0B, $0D, $0F
        byte    $00, $61, $72, $0D, $0F
        byte    $00, $00, $93, $0D, $0F
        byte    $00, $20, $49, $0D, $0F
        byte    $10, $81, $72, $0D, $0F
        byte    $00, $A2, $93, $0D, $0F
        byte    $00, $00, $93, $0D, $0F
        byte    $00, $20, $49, $0D, $0F
        byte    $1F, $41, $88, $0D, $10
        byte    $00, $60, $C4, $0D, $10
        byte    $00, $00, $62, $0D, $10
        byte    $00, $23, $10, $0D, $10
        byte    $00, $81, $EE, $0D, $10
        byte    $3F, $A1, $88, $0D, $10
        byte    $00, $00, $C4, $0D, $10
        byte    $00, $20, $62, $0D, $10
        byte    $3E, $41, $4A, $0D, $0F
        byte    $00, $62, $0B, $0D, $0F
        byte    $00, $80, $83, $0D, $0F
        byte    $00, $00, $C4, $0D, $0F
        byte    $2F, $21, $88, $0D, $0F
        byte    $00, $A1, $06, $0D, $0F
        byte    $00, $00, $A5, $0D, $0F
        byte    $00, $40, $83, $0D, $0F
        byte    $2F, $60, $C4, $0D, $0F
        byte    $00, $81, $4A, $0D, $0F
        byte    $00, $00, $83, $0D, $0F
        byte    $2F, $21, $B8, $0D, $0F
        byte    $00, $41, $06, $0D, $0F
        byte    $00, $A0, $AF, $0D, $0F
        byte    $1F, $01, $EE, $0D, $0F
        byte    $00, $61, $26, $0D, $0F
        byte    $00, $80, $C4, $0D, $0F
        byte    $1F, $21, $D2, $0D, $0F
        byte    $00, $41, $15, $0D, $0F
        byte    $00, $A0, $B9, $0D, $0F
        byte    $10, $01, $06, $0D, $0F
        byte    $00, $61, $B8, $0D, $0F
        byte    $00, $80, $AF, $0D, $0F
        byte    $1F, $21, $06, $0D, $14
        byte    $00, $41, $88, $0D, $14
        byte    $00, $A0, $A5, $0D, $14
        byte    $15, $01, $06, $0D, $14
        byte    $00, $60, $C4, $0D, $14
        byte    $00, $82, $93, $0D, $14
        byte    $00, $21, $88, $0D, $14
        byte    $15, $41, $4A, $0D, $14
        byte    $00, $A1, $06, $0D, $14
        byte    $00, $03, $10, $0D, $14
        byte    $00, $21, $EE, $0D, $14
        byte    $14, $62, $0B, $0D, $0F
        byte    $00, $83, $70, $0D, $0F
        byte    $00, $01, $5D, $0D, $0F
        byte    $00, $20, $DC, $0D, $0F
        byte    $20, $42, $BA, $0D, $0F
        byte    $00, $A1, $B8, $0D, $0F
        byte    $00, $01, $26, $0D, $0F
        byte    $0F, $21, $4A, $0D, $1F
        byte    $00, $61, $EE, $0D, $1F
        byte    $00, $83, $10, $0D, $1F
        byte    $20, $02, $93, $0D, $0F
        byte    $00, $41, $B8, $0D, $0F
        byte    $00, $A1, $06, $0D, $0F
        byte    $00, $20, $DC, $0D, $0F
        byte    $1F, $62, $0B, $0D, $0F
        byte    $00, $81, $4A, $0D, $0F
        byte    $00, $00, $DC, $0D, $0F
        byte    $10, $21, $5D, $0D, $0F
        byte    $00, $42, $4B, $0D, $0F
        byte    $00, $A0, $F7, $0D, $0F
        byte    $0F, $01, $EE, $0D, $0F
        byte    $00, $61, $26, $0D, $0F
        byte    $00, $80, $C4, $0D, $0F
        byte    $2F, $22, $0B, $0D, $0F
        byte    $00, $41, $4A, $0D, $0F
        byte    $00, $A0, $83, $0D, $0F
        byte    $00, $00, $C4, $0D, $0F
        byte    $2F, $61, $06, $0D, $0F
        byte    $00, $81, $88, $0D, $0F
        byte    $00, $00, $83, $0D, $0F
        byte    $00, $20, $A5, $0D, $0F
        byte    $2F, $40, $83, $0D, $0F
        byte    $00, $A0, $C4, $0D, $0F
        byte    $00, $01, $4A, $0D, $0F
        byte    $2F, $20, $AF, $0D, $0F
        byte    $00, $61, $B8, $0D, $0F
        byte    $00, $81, $06, $0D, $0F
        byte    $1F, $00, $C4, $0D, $0F
        byte    $00, $41, $26, $0D, $0F
        byte    $00, $A1, $EE, $0D, $0F
        byte    $1F, $20, $B9, $0D, $0F
        byte    $00, $61, $15, $0D, $0F
        byte    $00, $81, $D2, $0D, $0F
        byte    $10, $01, $B8, $0D, $0F
        byte    $00, $41, $06, $0D, $0F
        byte    $00, $A0, $AF, $0D, $0F
        byte    $1F, $21, $88, $0D, $14
        byte    $00, $61, $06, $0D, $14
        byte    $00, $80, $A5, $0D, $14
        byte    $15, $02, $93, $0D, $14
        byte    $00, $41, $06, $0D, $14
        byte    $00, $A0, $C4, $0D, $14
        byte    $00, $21, $88, $0D, $14
        byte    $15, $61, $4A, $0D, $14
        byte    $00, $81, $06, $0D, $14
        byte    $00, $01, $EE, $0D, $14
        byte    $00, $23, $10, $0D, $14
        byte    $14, $40, $DC, $0D, $0F
        byte    $00, $A2, $0B, $0D, $0F
        byte    $00, $03, $70, $0D, $0F
        byte    $00, $21, $5D, $0D, $0F
        byte    $20, $61, $B8, $0D, $0F
        byte    $00, $82, $BA, $0D, $0F
        byte    $00, $01, $26, $0D, $0F
        byte    $0F, $21, $EE, $0D, $1F
        byte    $00, $43, $10, $0D, $1F
        byte    $00, $A1, $4A, $0D, $1F
        byte    $20, $01, $B8, $0D, $0F
        byte    $00, $60, $DC, $0D, $0F
        byte    $00, $81, $06, $0D, $0F
        byte    $00, $22, $93, $0D, $0F
        byte    $1F, $40, $DC, $0D, $0F
        byte    $00, $A2, $0B, $0D, $0F
        byte    $00, $01, $4A, $0D, $0F
        byte    $10, $20, $F7, $0D, $0F
        byte    $00, $62, $4B, $0D, $0F
        byte    $00, $81, $5D, $0D, $0F
        byte    $0F, $00, $C4, $0D, $0F
        byte    $00, $41, $EE, $0D, $0F
        byte    $00, $A1, $26, $0D, $0F
        byte    $2F, $22, $93, $0D, $0F
        byte    $00, $62, $0B, $0D, $0F
        byte    $00, $80, $83, $0D, $2E
        byte    $10, $01, $B8, $0D, $0F
        byte    $00, $42, $0B, $0D, $0F
        byte    $1F, $A0, $C4, $0D, $2E
        byte    $00, $21, $88, $0D, $0F
        byte    $00, $61, $4A, $0D, $0F
        byte    $2F, $01, $06, $0D, $1F
        byte    $00, $41, $9F, $0D, $0F
        byte    $00, $81, $4A, $0D, $0F
        byte    $1F, $21, $5D, $0D, $0F
        byte    $00, $61, $B8, $0D, $0F
        byte    $00, $A0, $57, $0D, $2E
        byte    $10, $42, $0B, $0D, $0F
        byte    $00, $82, $BA, $0D, $0F
        byte    $1F, $02, $BA, $0D, $0F
        byte    $00, $22, $0B, $0D, $0F
        byte    $00, $60, $83, $0D, $2E
        byte    $10, $41, $5D, $0D, $0F
        byte    $00, $81, $B8, $0D, $0F
        byte    $1F, $A0, $AF, $0D, $1F
        byte    $1F, $00, $62, $0D, $2E
        byte    $00, $21, $EE, $0D, $14
        byte    $00, $41, $88, $0D, $14
        byte    $15, $83, $70, $0D, $14
        byte    $00, $62, $BA, $0D, $14
        byte    $15, $A3, $70, $0D, $14
        byte    $00, $22, $BA, $0D, $14
        byte    $05, $40, $93, $0D, $2E
        byte    $0F, $63, $70, $0D, $14
        byte    $00, $82, $BA, $0D, $14
        byte    $15, $02, $93, $0D, $14
        byte    $00, $23, $10, $0D, $14
        byte    $0B, $A0, $C4, $0D, $1F
        byte    $0A, $62, $BA, $0D, $14
        byte    $00, $82, $4B, $0D, $14
        byte    $15, $42, $93, $0D, $0F
        byte    $00, $02, $0B, $0D, $0F
        byte    $00, $20, $83, $0D, $2E
        byte    $10, $62, $0B, $0D, $0F
        byte    $00, $81, $B8, $0D, $0F
        byte    $1F, $A1, $B8, $0D, $0F
        byte    $00, $01, $5D, $0D, $0F
        byte    $00, $40, $C4, $0D, $2E
        byte    $10, $61, $88, $0D, $0F
        byte    $00, $81, $4A, $0D, $0F
        byte    $1F, $21, $06, $0D, $1F
        byte    $1F, $02, $93, $0D, $0F
        byte    $00, $A0, $83, $0D, $2E
        byte    $00, $62, $0B, $0D, $0F
        byte    $10, $82, $0B, $0D, $0F
        byte    $00, $41, $B8, $0D, $0F
        byte    $1F, $21, $4A, $0D, $0F
        byte    $00, $01, $88, $0D, $0F
        byte    $00, $60, $C4, $0D, $2E
        byte    $2F, $41, $9F, $0D, $0F
        byte    $00, $81, $06, $0D, $1F
        byte    $00, $A1, $4A, $0D, $0F
        byte    $1F, $00, $57, $0D, $2E
        byte    $00, $21, $5D, $0D, $0F
        byte    $00, $61, $B8, $0D, $0F
        byte    $10, $42, $BA, $0D, $0F
        byte    $00, $A2, $0B, $0D, $0F
        byte    $1F, $80, $83, $0D, $2E
        byte    $00, $22, $BA, $0D, $0F
        byte    $00, $62, $0B, $0D, $0F
        byte    $10, $41, $B8, $0D, $0F
        byte    $00, $A1, $5D, $0D, $0F
        byte    $1F, $00, $AF, $0D, $1F
        byte    $1F, $20, $C4, $0D, $2E
        byte    $00, $60, $62, $0D, $2E
        byte    $00, $41, $88, $0D, $0F
        byte    $00, $A1, $EE, $0D, $0F
        byte    $10, $82, $4B, $0D, $0F
        byte    $00, $02, $BA, $0D, $0F
        byte    $1F, $42, $4B, $0D, $0F
        byte    $00, $A0, $C4, $0D, $0F
        byte    $00, $00, $62, $0D, $0F
        byte    $00, $82, $BA, $0D, $0F
        byte    $0F, $22, $BA, $0D, $14
        byte    $00, $62, $4B, $0D, $14
        byte    $00, $00, $62, $0D, $14
        byte    $00, $40, $C4, $0D, $14
        byte    $15, $80, $DC, $0D, $14
        byte    $00, $A0, $6E, $0D, $14
        byte    $00, $02, $93, $0D, $14
        byte    $00, $22, $0B, $0D, $14
        byte    $15, $40, $7B, $0D, $14
        byte    $00, $60, $F7, $0D, $14
        byte    $00, $01, $EE, $0D, $14
        byte    $00, $22, $4B, $0D, $14
        byte    $15, $82, $0B, $0D, $0F
        byte    $00, $A1, $88, $0D, $0F
        byte    $00, $01, $06, $0D, $1F
        byte    $00, $20, $83, $0D, $1F
        byte    $10, $41, $4A, $0D, $0F
        byte    $0F, $60, $62, $0D, $1F
        byte    $00, $80, $C4, $0D, $1F
        byte    $10, $A1, $4A, $0D, $0F
        byte    $0F, $01, $06, $0D, $0F
        byte    $00, $20, $41, $0D, $1F
        byte    $00, $40, $83, $0D, $1F
        byte    $20, $60, $62, $0D, $1F
        byte    $1F, $82, $93, $0D, $0F
        byte    $00, $A0, $83, $0D, $2E
        byte    $00, $02, $0B, $0D, $0F
        byte    $10, $21, $B8, $0D, $0F
        byte    $00, $42, $0B, $0D, $0F
        byte    $1F, $60, $C4, $0D, $2E
        byte    $00, $01, $88, $0D, $0F
        byte    $00, $81, $4A, $0D, $0F
        byte    $2F, $21, $4A, $0D, $0F
        byte    $00, $41, $06, $0D, $1F
        byte    $00, $A1, $9F, $0D, $0F
        byte    $1F, $01, $B8, $0D, $0F
        byte    $00, $81, $5D, $0D, $0F
        byte    $00, $60, $57, $0D, $2E
        byte    $10, $22, $BA, $0D, $0F
        byte    $00, $A2, $0B, $0D, $0F
        byte    $1F, $42, $BA, $0D, $0F
        byte    $00, $02, $0B, $0D, $0F
        byte    $00, $80, $83, $0D, $2E
        byte    $0F, $21, $B8, $0D, $0F
        byte    $00, $A1, $5D, $0D, $0F
        byte    $20, $60, $AF, $0D, $1F
        byte    $1F, $01, $88, $0D, $14
        byte    $00, $41, $EE, $0D, $14
        byte    $00, $20, $62, $0D, $2E
        byte    $15, $A3, $70, $0D, $14
        byte    $00, $82, $BA, $0D, $14
        byte    $15, $63, $70, $0D, $14
        byte    $00, $02, $BA, $0D, $14
        byte    $05, $40, $93, $0D, $2E
        byte    $0F, $83, $70, $0D, $14
        byte    $00, $A2, $BA, $0D, $14
        byte    $15, $23, $10, $0D, $14
        byte    $00, $02, $93, $0D, $14
        byte    $0B, $60, $C4, $0D, $1F
        byte    $0A, $82, $BA, $0D, $14
        byte    $00, $A2, $4B, $0D, $14
        byte    $15, $40, $83, $0D, $2E
        byte    $00, $02, $0B, $0D, $0F
        byte    $00, $22, $93, $0D, $0F
        byte    $10, $82, $0B, $0D, $0F
        byte    $00, $A1, $B8, $0D, $0F
        byte    $1F, $60, $C4, $0D, $2E
        byte    $00, $01, $B8, $0D, $0F
        byte    $00, $21, $5D, $0D, $0F
        byte    $0F, $81, $88, $0D, $0F
        byte    $00, $A1, $4A, $0D, $0F
        byte    $20, $41, $06, $0D, $1F
        byte    $1F, $00, $83, $0D, $2E
        byte    $00, $22, $0B, $0D, $0F
        byte    $00, $82, $93, $0D, $0F
        byte    $10, $A2, $0B, $0D, $0F
        byte    $00, $61, $B8, $0D, $0F
        byte    $1F, $41, $4A, $0D, $0F
        byte    $00, $21, $88, $0D, $0F
        byte    $00, $80, $C4, $0D, $2E
        byte    $2F, $61, $9F, $0D, $0F
        byte    $00, $A1, $4A, $0D, $0F
        byte    $00, $01, $06, $0D, $1F
        byte    $1F, $20, $57, $0D, $2E
        byte    $00, $41, $5D, $0D, $0F
        byte    $00, $81, $B8, $0D, $0F
        byte    $10, $62, $0B, $0D, $0F
        byte    $00, $A2, $BA, $0D, $0F
        byte    $1F, $00, $83, $0D, $2E
        byte    $00, $42, $0B, $0D, $0F
        byte    $00, $82, $BA, $0D, $0F
        byte    $0F, $61, $B8, $0D, $0F
        byte    $00, $A1, $5D, $0D, $0F
        byte    $20, $20, $AF, $0D, $1F
        byte    $1F, $41, $EE, $0D, $0F
        byte    $00, $81, $88, $0D, $0F
        byte    $00, $60, $62, $0D, $2E
        byte    $00, $A0, $C4, $0D, $2E
        byte    $10, $02, $4B, $0D, $0F
        byte    $00, $22, $BA, $0D, $0F
        byte    $1F, $40, $C4, $0D, $0F
        byte    $00, $80, $62, $0D, $0F
        byte    $00, $02, $BA, $0D, $0F
        byte    $00, $22, $4B, $0D, $0F
        byte    $0F, $62, $4B, $0D, $14
        byte    $00, $A2, $BA, $0D, $14
        byte    $00, $00, $C4, $0D, $14
        byte    $00, $20, $62, $0D, $14
        byte    $15, $42, $93, $0D, $14
        byte    $00, $82, $0B, $0D, $14
        byte    $00, $00, $DC, $0D, $14
        byte    $00, $20, $6E, $0D, $14
        byte    $15, $61, $EE, $0D, $14
        byte    $00, $A0, $F7, $0D, $14
        byte    $00, $00, $7B, $0D, $14
        byte    $00, $22, $4B, $0D, $14
        byte    $15, $42, $0B, $0D, $0F
        byte    $00, $81, $06, $0D, $1F
        byte    $00, $00, $83, $0D, $1F
        byte    $00, $21, $88, $0D, $0F
        byte    $10, $61, $4A, $0D, $0F
        byte    $0F, $A0, $62, $0D, $1F
        byte    $00, $20, $C4, $0D, $1F
        byte    $10, $41, $4A, $0D, $0F
        byte    $0F, $00, $41, $0D, $1F
        byte    $00, $60, $83, $0D, $1F
        byte    $00, $81, $06, $0D, $0F
        byte    $20, $20, $62, $0D, $1F
        byte    $1F, $40, $68, $0D, $2E
        byte    $00, $A1, $9F, $0D, $0F
        byte    $00, $82, $0B, $0D, $0F
        byte    $10, $02, $0B, $0D, $0F
        byte    $00, $61, $9F, $0D, $0F
        byte    $1F, $20, $9C, $0D, $2E
        byte    $00, $81, $9F, $0D, $0F
        byte    $00, $A2, $0B, $0D, $0F
        byte    $1F, $01, $9F, $0D, $0F
        byte    $00, $62, $0B, $0D, $0F
        byte    $10, $41, $D2, $0D, $0F
        byte    $00, $82, $4B, $0D, $0F
        byte    $00, $A0, $D0, $0D, $1F
        byte    $1F, $02, $93, $0D, $0F
        byte    $00, $21, $88, $0D, $0F
        byte    $00, $60, $83, $0D, $2E
        byte    $10, $42, $0B, $0D, $0F
        byte    $00, $81, $4A, $0D, $0F
        byte    $1F, $A0, $C4, $0D, $2E
        byte    $00, $01, $B8, $0D, $0F
        byte    $00, $21, $4A, $0D, $0F
        byte    $0F, $41, $88, $0D, $0F
        byte    $00, $81, $06, $0D, $0F
        byte    $20, $61, $06, $0D, $1F
        byte    $1F, $00, $68, $0D, $2E
        byte    $00, $22, $0B, $0D, $0F
        byte    $00, $41, $9F, $0D, $0F
        byte    $10, $82, $0B, $0D, $0F
        byte    $00, $A1, $9F, $0D, $0F
        byte    $1F, $60, $9C, $0D, $2E
        byte    $00, $22, $0B, $0D, $0F
        byte    $00, $41, $9F, $0D, $0F
        byte    $1F, $82, $0B, $0D, $0F
        byte    $00, $A1, $9F, $0D, $0F
        byte    $10, $00, $D0, $0D, $1F
        byte    $00, $22, $4B, $0D, $0F
        byte    $00, $41, $D2, $0D, $0F
        byte    $0F, $62, $93, $0D, $0F
        byte    $00, $81, $88, $0D, $0F
        byte    $10, $A0, $83, $0D, $2E
        byte    $2F, $20, $C4, $0D, $2E
        byte    $2F, $41, $06, $0D, $1F
        byte    $1F, $61, $9F, $0D, $0F
        byte    $00, $82, $0B, $0D, $0F
        byte    $00, $00, $68, $0D, $2E
        byte    $10, $A2, $0B, $0D, $0F
        byte    $00, $21, $9F, $0D, $0F
        byte    $1F, $41, $9F, $0D, $0F
        byte    $00, $62, $0B, $0D, $0F
        byte    $00, $80, $9C, $0D, $2E
        byte    $1F, $22, $0B, $0D, $0F
        byte    $00, $A1, $9F, $0D, $0F
        byte    $10, $02, $4B, $0D, $0F
        byte    $00, $41, $D2, $0D, $0F
        byte    $00, $60, $D0, $0D, $1F
        byte    $1F, $22, $93, $0D, $0F
        byte    $00, $81, $88, $0D, $0F
        byte    $00, $A0, $83, $0D, $2E
        byte    $10, $02, $0B, $0D, $0F
        byte    $00, $41, $4A, $0D, $0F
        byte    $1F, $60, $C4, $0D, $2E
        byte    $00, $21, $B8, $0D, $0F
        byte    $00, $81, $4A, $0D, $0F
        byte    $0F, $01, $88, $0D, $0F
        byte    $00, $41, $06, $0D, $0F
        byte    $20, $A1, $06, $0D, $1F
        byte    $1F, $20, $49, $0D, $0F
        byte    $00, $80, $93, $0D, $0F
        byte    $00, $01, $72, $0D, $0F
        byte    $00, $42, $93, $0D, $0F
        byte    $10, $62, $93, $0D, $0F
        byte    $00, $A1, $72, $0D, $0F
        byte    $00, $00, $93, $0D, $0F
        byte    $00, $20, $49, $0D, $0F
        byte    $1F, $42, $93, $0D, $0F
        byte    $00, $81, $72, $0D, $0F
        byte    $00, $00, $93, $0D, $0F
        byte    $00, $20, $49, $0D, $0F
        byte    $1F, $62, $0B, $0D, $0F
        byte    $00, $A1, $72, $0D, $0F
        byte    $00, $00, $49, $0D, $0F
        byte    $00, $20, $93, $0D, $0F
        byte    $10, $42, $93, $0D, $0F
        byte    $00, $81, $72, $0D, $0F
        byte    $00, $00, $49, $0D, $0F
        byte    $00, $20, $93, $0D, $0F
        byte    $1F, $63, $10, $0D, $10
        byte    $00, $A1, $EE, $0D, $10
        byte    $00, $01, $88, $0D, $10
        byte    $00, $20, $C4, $0D, $10
        byte    $00, $40, $62, $0D, $10
        byte    $3E, $81, $88, $0D, $10
        byte    $00, $00, $62, $0D, $10
        byte    $00, $20, $C4, $0D, $10
        byte    $3F, $40, $83, $0D, $2E
        byte    $00, $62, $0B, $0D, $0F
        byte    $00, $A2, $93, $0D, $0F
        byte    $10, $01, $B8, $0D, $0F
        byte    $00, $22, $0B, $0D, $0F
        byte    $1F, $81, $4A, $0D, $0F
        byte    $00, $61, $88, $0D, $0F
        byte    $00, $A0, $C4, $0D, $2E
        byte    $2F, $01, $06, $0D, $1F
        byte    $00, $21, $4A, $0D, $0F
        byte    $00, $41, $9F, $0D, $0F
        byte    $1F, $60, $57, $0D, $2E
        byte    $00, $81, $B8, $0D, $0F
        byte    $00, $A1, $5D, $0D, $0F
        byte    $10, $22, $BA, $0D, $0F
        byte    $00, $42, $0B, $0D, $0F
        byte    $1F, $02, $0B, $0D, $0F
        byte    $00, $80, $83, $0D, $2E
        byte    $00, $A2, $BA, $0D, $0F
        byte    $10, $21, $B8, $0D, $0F
        byte    $00, $41, $5D, $0D, $0F
        byte    $1F, $60, $AF, $0D, $1F
        byte    $1F, $00, $62, $0D, $2E
        byte    $00, $A1, $EE, $0D, $14
        byte    $00, $21, $88, $0D, $14
        byte    $15, $42, $BA, $0D, $14
        byte    $00, $83, $70, $0D, $14
        byte    $15, $63, $70, $0D, $14
        byte    $00, $22, $BA, $0D, $14
        byte    $05, $A0, $93, $0D, $2E
        byte    $0F, $42, $BA, $0D, $14
        byte    $00, $83, $70, $0D, $14
        byte    $15, $02, $93, $0D, $14
        byte    $00, $23, $10, $0D, $14
        byte    $0B, $60, $C4, $0D, $1F
        byte    $0A, $42, $4B, $0D, $14
        byte    $00, $82, $BA, $0D, $14
        byte    $15, $A2, $0B, $0D, $0F
        byte    $00, $02, $93, $0D, $0F
        byte    $00, $20, $83, $0D, $2E
        byte    $10, $41, $B8, $0D, $0F
        byte    $00, $82, $0B, $0D, $0F
        byte    $1F, $60, $C4, $0D, $2E
        byte    $00, $01, $B8, $0D, $0F
        byte    $00, $A1, $5D, $0D, $0F
        byte    $10, $41, $88, $0D, $0F
        byte    $00, $81, $4A, $0D, $0F
        byte    $1F, $21, $06, $0D, $1F
        byte    $1F, $00, $83, $0D, $2E
        byte    $00, $A2, $93, $0D, $0F
        byte    $00, $42, $0B, $0D, $0F
        byte    $10, $82, $0B, $0D, $0F
        byte    $00, $61, $B8, $0D, $0F
        byte    $1F, $20, $C4, $0D, $2E
        byte    $00, $41, $88, $0D, $0F
        byte    $00, $A1, $4A, $0D, $0F
        byte    $2F, $61, $4A, $0D, $0F
        byte    $00, $81, $06, $0D, $1F
        byte    $00, $01, $9F, $0D, $0F
        byte    $1F, $41, $B8, $0D, $0F
        byte    $00, $A0, $57, $0D, $2E
        byte    $00, $21, $5D, $0D, $0F
        byte    $10, $02, $BA, $0D, $0F
        byte    $00, $62, $0B, $0D, $0F
        byte    $1F, $80, $83, $0D, $2E
        byte    $00, $22, $BA, $0D, $0F
        byte    $00, $42, $0B, $0D, $0F
        byte    $10, $01, $B8, $0D, $0F
        byte    $00, $61, $5D, $0D, $0F
        byte    $1F, $A0, $AF, $0D, $1F
        byte    $1F, $20, $62, $0D, $2E
        byte    $00, $41, $EE, $0D, $0F
        byte    $00, $01, $88, $0D, $0F
        byte    $00, $60, $C4, $0D, $2E
        byte    $10, $82, $BA, $0D, $0F
        byte    $00, $A2, $4B, $0D, $0F
        byte    $1F, $02, $BA, $0D, $0F
        byte    $00, $42, $4B, $0D, $0F
        byte    $00, $80, $C4, $0D, $0F
        byte    $00, $A0, $62, $0D, $0F
        byte    $0F, $20, $C4, $0D, $14
        byte    $00, $60, $62, $0D, $14
        byte    $00, $02, $4B, $0D, $14
        byte    $00, $42, $BA, $0D, $14
        byte    $15, $82, $0B, $0D, $14
        byte    $00, $A0, $DC, $0D, $14
        byte    $00, $00, $6E, $0D, $14
        byte    $00, $22, $93, $0D, $14
        byte    $15, $40, $7B, $0D, $14
        byte    $00, $60, $F7, $0D, $14
        byte    $00, $01, $EE, $0D, $14
        byte    $00, $22, $4B, $0D, $14
        byte    $15, $80, $83, $0D, $1F
        byte    $00, $A1, $06, $0D, $1F
        byte    $00, $02, $0B, $0D, $0F
        byte    $00, $21, $88, $0D, $0F
        byte    $10, $41, $4A, $0D, $0F
        byte    $0F, $60, $62, $0D, $1F
        byte    $00, $00, $C4, $0D, $1F
        byte    $10, $21, $4A, $0D, $0F
        byte    $10, $40, $83, $0D, $1F
        byte    $00, $80, $41, $0D, $1F
        byte    $00, $A1, $06, $0D, $0F
        byte    $1F, $00, $62, $0D, $1F
        byte    $1F, $22, $0B, $0D, $0F
        byte    $00, $61, $4A, $0D, $0F
        byte    $00, $A0, $C4, $0D, $2E
        byte    $00, $40, $62, $0D, $2E
        byte    $2F, $80, $A5, $0D, $2E
        byte    $00, $00, $52, $0D, $2E
        byte    $00, $21, $88, $0D, $0F
        byte    $00, $61, $06, $0D, $0F
        byte    $2F, $40, $83, $0D, $1F
        byte    $00, $A0, $41, $0D, $1F
        byte    $00, $21, $4A, $0D, $0F
        byte    $00, $60, $C4, $0D, $0F
        byte    $1F, $00, $AF, $0D, $34
        byte    $00, $80, $57, $0D, $34
        byte    $00, $21, $B8, $0D, $14
        byte    $00, $61, $5D, $0D, $34
        byte    $15, $41, $EE, $0D, $14
        byte    $15, $A1, $B8, $0D, $14
        byte    $15, $20, $45, $0D, $34
        byte    $00, $40, $8B, $0D, $34
        byte    $00, $01, $9F, $0D, $14
        byte    $00, $61, $5D, $0D, $34
        byte    $14, $81, $D2, $0D, $14
        byte    $15, $A1, $9F, $0D, $14
        byte    $15, $00, $83, $0D, $80, $EA
        byte    $00, $80, $41, $0D, $80, $EA
        byte    $00, $21, $88, $0D, $80, $EA
        byte    $00, $41, $4A, $0D, $0F
        byte    $10, $61, $26, $0D, $0F
        byte    $0F, $A1, $4A, $0D, $80, $AC
        byte    $ff

_song_zelda
        byte    $02, $EF, $AD, $79, $35          'Instrument 0
        byte    $FF                              'End of Instrument list
        byte    $00, $00, $83, $0C, $82, $DF
        byte    $00, $20, $AF, $0C, $82, $DF
        byte    $B8, $41, $EE, $0C, $3D
        byte    $1F, $61, $06, $0C, $1F
        byte    $1E, $41, $B8, $0C, $3D
        byte    $1F, $61, $06, $0C, $1F
        byte    $1F, $41, $5D, $0C, $3D
        byte    $1E, $61, $06, $0C, $1F
        byte    $1F, $41, $EE, $0C, $3D
        byte    $1F, $61, $06, $0C, $1F
        byte    $1E, $41, $B8, $0C, $3D
        byte    $1F, $61, $06, $0C, $1F
        byte    $1F, $41, $5D, $0C, $3D
        byte    $1E, $61, $06, $0C, $1F
        byte    $1F, $41, $EE, $0C, $3D
        byte    $1F, $61, $06, $0C, $1F
        byte    $1E, $41, $B8, $0C, $3D
        byte    $1F, $61, $06, $0C, $1F
        byte    $1E, $41, $4A, $0C, $1F
        byte    $1F, $41, $06, $0C, $1F
        byte    $00, $61, $26, $0C, $1F
        byte    $1F, $00, $A5, $0C, $80, $B8
        byte    $00, $21, $4A, $0C, $80, $98
        byte    $00, $40, $7B, $0C, $80, $B8
        byte    $1E, $60, $F7, $0C, $1F
        byte    $3E, $60, $F7, $0C, $1F
        byte    $3D, $20, $F7, $0C, $1F
        byte    $1F, $00, $AF, $0C, $82, $28
        byte    $00, $21, $EE, $0C, $3D
        byte    $00, $40, $83, $0C, $82, $28
        byte    $1E, $61, $06, $0C, $1F
        byte    $1F, $21, $B8, $0C, $3D
        byte    $1F, $61, $06, $0C, $1F
        byte    $1E, $21, $5D, $0C, $3D
        byte    $1F, $61, $06, $0C, $1F
        byte    $1E, $21, $EE, $0C, $3D
        byte    $1F, $61, $06, $0C, $1F
        byte    $1F, $21, $B8, $0C, $3D
        byte    $1E, $61, $06, $0C, $1F
        byte    $1F, $21, $5D, $0C, $3D
        byte    $1F, $61, $06, $0C, $1F
        byte    $1E, $21, $EE, $0C, $3D
        byte    $1F, $61, $06, $0C, $1F
        byte    $1F, $21, $B8, $0C, $3D
        byte    $1E, $61, $06, $0C, $1F
        byte    $1F, $21, $4A, $0C, $1F
        byte    $1F, $21, $26, $0C, $1F
        byte    $00, $61, $06, $0C, $1F
        byte    $1E, $80, $7B, $0C, $80, $B8
        byte    $00, $A1, $4A, $0C, $80, $98
        byte    $00, $00, $A5, $0C, $80, $B8
        byte    $1E, $20, $F7, $0C, $1F
        byte    $3D, $20, $F7, $0C, $1F
        byte    $3D, $20, $F7, $0C, $1F
        byte    $20, $00, $93, $0C, $81, $70
        byte    $00, $20, $DC, $0C, $81, $70
        byte    $00, $41, $5D, $0C, $3D
        byte    $1F, $60, $DC, $0C, $1F
        byte    $1E, $41, $06, $0C, $3D
        byte    $1F, $60, $DC, $0C, $1F
        byte    $1F, $40, $F7, $0C, $3D
        byte    $1E, $60, $DC, $0C, $1F
        byte    $1F, $41, $5D, $0C, $3D
        byte    $1F, $60, $DC, $0C, $1F
        byte    $1E, $41, $06, $0C, $3D
        byte    $1F, $60, $DC, $0C, $1F
        byte    $1E, $40, $F7, $0C, $3D
        byte    $1F, $60, $DC, $0C, $1F
        byte    $1F, $00, $C4, $0C, $81, $70
        byte    $00, $20, $83, $0C, $81, $70
        byte    $00, $41, $5D, $0C, $3D
        byte    $1E, $60, $C4, $0C, $1F
        byte    $1F, $41, $4A, $0C, $3D
        byte    $1F, $60, $C4, $0C, $1F
        byte    $1E, $40, $F7, $0C, $1F
        byte    $1F, $40, $C4, $0C, $1F
        byte    $00, $60, $DC, $0C, $1F
        byte    $1F, $40, $F7, $0C, $80, $98
        byte    $1E, $60, $C4, $0C, $1F
        byte    $3E, $60, $C4, $0C, $1F
        byte    $3D, $40, $C4, $0C, $1F
        byte    $1E, $60, $93, $0C, $81, $70
        byte    $00, $80, $DC, $0C, $81, $70
        byte    $00, $A1, $5D, $0C, $3D
        byte    $1F, $00, $DC, $0C, $1F
        byte    $1F, $01, $06, $0C, $3D
        byte    $1E, $20, $DC, $0C, $1F
        byte    $1F, $00, $F7, $0C, $3D
        byte    $1F, $20, $DC, $0C, $1F
        byte    $1E, $01, $5D, $0C, $3D
        byte    $1F, $20, $DC, $0C, $1F
        byte    $1F, $01, $06, $0C, $3D
        byte    $1E, $20, $DC, $0C, $1F
        byte    $1F, $00, $F7, $0C, $3D
        byte    $1F, $20, $DC, $0C, $1F
        byte    $1E, $01, $5D, $0C, $3D
        byte    $00, $40, $83, $0C, $81, $70
        byte    $00, $60, $C4, $0C, $81, $70
        byte    $1F, $20, $C4, $0C, $1F
        byte    $1E, $01, $4A, $0C, $3D
        byte    $1F, $20, $C4, $0C, $1F
        byte    $1F, $01, $4A, $0C, $3D
        byte    $00, $21, $EE, $0C, $3D
        byte    $1E, $80, $C4, $0C, $1F
        byte    $1F, $01, $4A, $0C, $3D
        byte    $00, $21, $88, $0C, $3D
        byte    $1F, $80, $C4, $0C, $1F
        byte    $1E, $01, $88, $0C, $3D
        byte    $1F, $20, $C4, $0C, $1F
        byte    $3D, $00, $C4, $0C, $1F
        byte    $1F, $01, $B8, $0C, $1E
        byte    $00, $21, $5D, $0C, $1E
        byte    $00, $40, $75, $0C, $81, $70
        byte    $00, $60, $AF, $0C, $81, $70
        byte    $1F, $00, $AF, $0C, $1F
        byte    $1C, $20, $E9, $0C, $1F
        byte    $02, $81, $5D, $0C, $1E
        byte    $00, $A1, $B8, $0C, $1E
        byte    $1D, $00, $AF, $0C, $1F
        byte    $1F, $01, $26, $0C, $1F
        byte    $01, $21, $5D, $0C, $3D
        byte    $00, $81, $B8, $0C, $3D
        byte    $1D, $A0, $AF, $0C, $1F
        byte    $21, $01, $B8, $0C, $1E
        byte    $00, $22, $4B, $0C, $1E
        byte    $1E, $00, $AF, $0C, $1F
        byte    $1D, $20, $E9, $0C, $1F
        byte    $02, $01, $B8, $0C, $1E
        byte    $00, $82, $4B, $0C, $1E
        byte    $1D, $20, $AF, $0C, $1F
        byte    $1F, $01, $26, $0C, $1F
        byte    $01, $21, $B8, $0C, $3D
        byte    $00, $82, $4B, $0C, $3D
        byte    $3E, $01, $4A, $0C, $1E
        byte    $00, $21, $88, $0C, $1E
        byte    $00, $40, $6E, $0C, $81, $70
        byte    $00, $60, $A5, $0C, $81, $70
        byte    $1E, $00, $A5, $06, $1F
        byte    $1F, $00, $DC, $07, $1F
        byte    $00, $21, $88, $0C, $1E
        byte    $00, $81, $4A, $0C, $1E
        byte    $1F, $00, $A5, $06, $1F
        byte    $1E, $21, $06, $08, $1F
        byte    $00, $81, $88, $0C, $3D
        byte    $00, $A1, $4A, $0C, $3D
        byte    $1F, $00, $A5, $06, $1F
        byte    $1F, $02, $0B, $0C, $3D
        byte    $00, $21, $4A, $0C, $1E
        byte    $1E, $20, $A5, $07, $1F
        byte    $1F, $00, $C4, $07, $1F
        byte    $00, $21, $88, $0C, $5B
        byte    $00, $81, $4A, $0C, $5B
        byte    $1E, $A0, $A5, $06, $1F
        byte    $1F, $01, $06, $07, $1E
        byte    $3D, $00, $62, $0C, $81, $70
        byte    $00, $20, $93, $0C, $81, $70
        byte    $00, $81, $5D, $0C, $1F
        byte    $00, $A1, $26, $0C, $1F
        byte    $1F, $40, $93, $07, $1F
        byte    $1F, $40, $AF, $07, $1F
        byte    $00, $61, $26, $0C, $1F
        byte    $00, $81, $5D, $0C, $1F
        byte    $1E, $A0, $93, $06, $1F
        byte    $1F, $40, $E9, $08, $1F
        byte    $00, $61, $5D, $0C, $3D
        byte    $00, $81, $26, $0C, $3D
        byte    $1F, $40, $93, $06, $1F
        byte    $1E, $61, $D2, $0C, $1F
        byte    $00, $81, $5D, $0C, $1F
        byte    $1F, $40, $93, $07, $1F
        byte    $1F, $40, $AF, $07, $1F
        byte    $00, $61, $5D, $0C, $1F
        byte    $00, $81, $D2, $0C, $1F
        byte    $1E, $A0, $93, $06, $1F
        byte    $1F, $41, $5D, $0C, $3D
        byte    $00, $60, $E9, $07, $1E
        byte    $00, $81, $D2, $0C, $3D
        byte    $3D, $01, $06, $0C, $3D
        byte    $00, $21, $4A, $0C, $3D
        byte    $00, $40, $57, $0C, $81, $70
        byte    $00, $60, $83, $0C, $81, $70
        byte    $1F, $80, $83, $06, $1F
        byte    $1E, $00, $A5, $07, $1F
        byte    $00, $21, $26, $0C, $3D
        byte    $00, $A1, $06, $0C, $3D
        byte    $1F, $00, $83, $05, $1F
        byte    $1F, $01, $06, $0C, $3D
        byte    $00, $21, $B8, $0C, $3D
        byte    $00, $80, $DC, $08, $1F
        byte    $1E, $A0, $A5, $06, $1F
        byte    $1F, $01, $06, $0C, $80, $98
        byte    $00, $21, $4A, $0C, $80, $98
        byte    $1F, $80, $83, $06, $1F
        byte    $1E, $A0, $A5, $07, $1F
        byte    $1F, $80, $83, $05, $1F
        byte    $1F, $80, $DC, $06, $1E
        byte    $3D, $00, $AF, $0C, $81, $70
        byte    $00, $21, $B8, $0C, $1E
        byte    $00, $41, $5D, $0C, $1E
        byte    $00, $60, $75, $0C, $81, $70
        byte    $1E, $20, $AF, $07, $1F
        byte    $1F, $21, $5D, $0C, $1E
        byte    $00, $41, $B8, $0C, $1E
        byte    $00, $80, $E9, $07, $1F
        byte    $1F, $20, $AF, $06, $1F
        byte    $1E, $41, $B8, $0C, $3D
        byte    $00, $81, $5D, $0C, $3D
        byte    $00, $A1, $26, $08, $1F
        byte    $1F, $20, $E9, $07, $1F
        byte    $1F, $22, $4B, $0C, $1E
        byte    $00, $41, $B8, $0C, $1E
        byte    $1E, $20, $AF, $07, $1F
        byte    $1F, $22, $4B, $0C, $1E
        byte    $00, $41, $B8, $0C, $1E
        byte    $00, $80, $E9, $08, $1F
        byte    $1F, $20, $AF, $06, $1F
        byte    $1E, $41, $26, $08, $1F
        byte    $00, $81, $B8, $0C, $3D
        byte    $00, $A2, $4B, $0C, $3D
        byte    $3E, $00, $A5, $0C, $81, $70
        byte    $00, $20, $6E, $0C, $81, $70
        byte    $00, $41, $88, $0C, $1E
        byte    $00, $61, $4A, $0C, $1E
        byte    $1E, $40, $A5, $07, $1F
        byte    $1F, $40, $DC, $07, $1F
        byte    $00, $61, $88, $0C, $1E
        byte    $00, $81, $4A, $0C, $1E
        byte    $1E, $60, $A5, $06, $1F
        byte    $1F, $41, $88, $0C, $3D
        byte    $00, $61, $4A, $0C, $3D
        byte    $00, $81, $06, $08, $1F
        byte    $1F, $80, $A5, $06, $1F
        byte    $1E, $42, $0B, $0C, $3D
        byte    $00, $61, $4A, $0C, $1E
        byte    $1F, $60, $A5, $06, $1F
        byte    $1F, $40, $C4, $07, $1F
        byte    $00, $61, $88, $0C, $5B
        byte    $00, $81, $4A, $0C, $5B
        byte    $1E, $A0, $A5, $06, $1F
        byte    $1F, $41, $06, $07, $1E
        byte    $3D, $40, $AF, $0C, $81, $70
        byte    $00, $60, $75, $0C, $81, $70
        byte    $00, $81, $26, $0C, $1E
        byte    $00, $A1, $5D, $0C, $1F
        byte    $1F, $00, $AF, $06, $1F
        byte    $1F, $01, $88, $0C, $1F
        byte    $00, $20, $DC, $08, $1F
        byte    $00, $81, $26, $0C, $1E
        byte    $1E, $80, $AF, $05, $1F
        byte    $1F, $01, $26, $0C, $1E
        byte    $00, $21, $26, $08, $1F
        byte    $00, $81, $B8, $0C, $1F
        byte    $1E, $00, $AF, $05, $1F
        byte    $1F, $01, $D2, $0C, $1F
        byte    $00, $21, $5D, $0C, $1E
        byte    $1F, $00, $AF, $06, $1F
        byte    $1E, $20, $E9, $08, $1F
        byte    $00, $81, $5D, $0C, $1E
        byte    $00, $A2, $0B, $0C, $1F
        byte    $1F, $00, $AF, $05, $1F
        byte    $1F, $01, $26, $08, $1F
        byte    $00, $21, $5D, $0C, $1E
        byte    $00, $82, $4B, $0C, $1F
        byte    $1E, $20, $AF, $06, $1F
        byte    $1F, $00, $AF, $0C, $80, $B8
        byte    $00, $20, $7B, $0C, $81, $50
        byte    $00, $41, $5D, $0C, $1E
        byte    $00, $61, $B8, $0C, $1F
        byte    $1F, $40, $AF, $06, $1F
        byte    $1E, $60, $DC, $08, $1F
        byte    $00, $81, $5D, $0C, $1E
        byte    $00, $A1, $EE, $0C, $1F
        byte    $1F, $40, $AF, $06, $1F
        byte    $1F, $41, $5D, $0C, $1E
        byte    $00, $61, $26, $08, $1F
        byte    $00, $82, $4B, $0C, $1F
        byte    $1E, $40, $DC, $07, $1F
        byte    $1F, $00, $A5, $09, $3D
        byte    $00, $41, $4A, $0C, $80, $98
        byte    $00, $62, $93, $0C, $80, $98
        byte    $00, $80, $A5, $0C, $80, $98
        byte    $3D, $00, $F7, $08, $3D
        byte    $3D, $01, $4A, $08, $80, $B8
        byte    $ff

_song_tron_win
        byte    $02, $EF, $AD, $79, $35          'Instrument 0
        byte    $06, $EF, $AD, $79, $35          'Instrument 1
        byte    $FF                              'End of Instrument list
        byte    $00, $00, $AF, $0F, $0D
        byte    $00, $21, $88, $0F, $0D
        byte    $00, $41, $5D, $0F, $0D
        byte    $00, $62, $4B, $0F, $2B
        byte    $0D, $80, $AF, $0F, $0D
        byte    $00, $A1, $5D, $0F, $0D
        byte    $00, $01, $88, $0F, $0D
        byte    $08, $20, $93, $0F, $0B
        byte    $00, $40, $62, $0F, $15
        byte    $06, $01, $5D, $0F, $0D
        byte    $00, $80, $AF, $0F, $0D
        byte    $00, $A1, $88, $0F, $0D
        byte    $10, $20, $AF, $0F, $0D
        byte    $00, $01, $88, $0F, $0D
        byte    $00, $81, $5D, $0F, $0D
        byte    $00, $A0, $93, $0F, $0B
        byte    $00, $43, $10, $0F, $20
        byte    $0D, $60, $AF, $0F, $0D
        byte    $00, $A1, $88, $0F, $0D
        byte    $00, $01, $5D, $0F, $0D
        byte    $08, $20, $62, $0F, $15
        byte    $00, $80, $93, $0F, $0B
        byte    $06, $01, $88, $0F, $0D
        byte    $00, $60, $AF, $0F, $0D
        byte    $00, $A1, $5D, $0F, $0D
        byte    $05, $44, $17, $0F, $0B
        byte    $0B, $80, $9C, $0F, $0B
        byte    $00, $04, $55, $0F, $2B
        byte    $00, $60, $B9, $0F, $0D
        byte    $00, $A1, $72, $0F, $0D
        byte    $00, $21, $9F, $0F, $0D
        byte    $0D, $40, $B9, $0F, $0D
        byte    $00, $81, $9F, $0F, $0D
        byte    $00, $21, $72, $0F, $0D
        byte    $08, $60, $9C, $0F, $0B
        byte    $00, $A0, $68, $0F, $15
        byte    $05, $20, $B9, $0F, $0D
        byte    $00, $41, $9F, $0F, $0D
        byte    $00, $81, $72, $0F, $0D
        byte    $11, $60, $B9, $0F, $0D
        byte    $00, $21, $72, $0F, $0D
        byte    $00, $41, $9F, $0F, $0D
        byte    $00, $80, $9C, $0F, $0B
        byte    $00, $A3, $3F, $0F, $2B
        byte    $0D, $01, $72, $0F, $0D
        byte    $00, $81, $9F, $0F, $0D
        byte    $00, $20, $B9, $0F, $0D
        byte    $08, $40, $9C, $0F, $0B
        byte    $00, $60, $68, $0F, $15
        byte    $05, $00, $B9, $0F, $0D
        byte    $00, $21, $9F, $0F, $0D
        byte    $00, $81, $72, $0F, $0D
        byte    $10, $40, $C4, $0F, $0D
        byte    $00, $03, $DC, $0F, $0D
        byte    $00, $21, $88, $0F, $0D
        byte    $00, $81, $B8, $0F, $0D
        byte    $00, $60, $A5, $0F, $0B
        byte    $0E, $A3, $3F, $0F, $0D
        byte    $00, $61, $88, $0F, $0D
        byte    $00, $00, $C4, $0F, $0D
        byte    $00, $21, $B8, $0F, $0D
        byte    $08, $40, $6E, $0F, $15
        byte    $00, $80, $A5, $0F, $0B
        byte    $05, $01, $B8, $0F, $0D
        byte    $00, $21, $88, $0F, $0D
        byte    $00, $63, $DC, $0F, $0D
        byte    $00, $A0, $C4, $0F, $0D
        byte    $0E, $85, $27, $0F, $53
        byte    $02, $01, $88, $0F, $0D
        byte    $00, $21, $B8, $0F, $0D
        byte    $00, $60, $A5, $0F, $0B
        byte    $00, $A0, $C4, $0F, $0D
        byte    $0E, $40, $C4, $0F, $0D
        byte    $00, $61, $B8, $0F, $0D
        byte    $00, $01, $88, $0F, $0D
        byte    $08, $20, $A5, $0F, $0B
        byte    $00, $A0, $6E, $0F, $15
        byte    $05, $01, $88, $0F, $0D
        byte    $00, $41, $B8, $0F, $0D
        byte    $00, $60, $C4, $0F, $0D
        byte    $10, $21, $9F, $0F, $0D
        byte    $00, $02, $BA, $0F, $0D
        byte    $00, $41, $72, $0F, $0D
        byte    $00, $60, $B9, $0F, $0D
        byte    $00, $A0, $9C, $0F, $0B
        byte    $0E, $A1, $72, $0F, $0D
        byte    $00, $02, $0B, $0F, $0D
        byte    $00, $20, $B9, $0F, $0D
        byte    $00, $41, $9F, $0F, $0D
        byte    $08, $60, $9C, $0F, $0B
        byte    $05, $01, $9F, $0F, $0D
        byte    $00, $21, $72, $0F, $0D
        byte    $00, $40, $B9, $0F, $0D
        byte    $10, $A0, $52, $0F, $36
        byte    $00, $61, $4A, $0F, $36
        byte    $00, $80, $52, $0F, $36
        byte    $ff

_song_tron_lose
        byte    $02, $EF, $AD, $79, $35          'Instrument 0
        byte    $06, $EF, $AD, $79, $35          'Instrument 1
        byte    $FF                              'End of Instrument list
        byte    $00, $01, $EE, $0F, $0D
        byte    $00, $20, $7B, $0F, $56
        byte    $00, $43, $DC, $0F, $2B
        byte    $0D, $61, $EE, $0F, $0D
        byte    $00, $81, $5D, $0F, $0D
        byte    $0E, $A1, $EE, $0F, $0D
        byte    $00, $01, $5D, $0F, $0D
        byte    $10, $61, $EE, $0F, $0D
        byte    $00, $85, $27, $0F, $20
        byte    $00, $01, $5D, $0F, $0D
        byte    $0D, $A1, $EE, $0F, $0D
        byte    $00, $41, $5D, $0F, $0D
        byte    $0E, $01, $5D, $0F, $0D
        byte    $00, $61, $EE, $0F, $0D
        byte    $05, $43, $DC, $0F, $0B
        byte    $0B, $A4, $DD, $0F, $20
        byte    $00, $80, $A5, $0F, $40
        byte    $00, $01, $4A, $0F, $0D
        byte    $01, $61, $D2, $0F, $0D
        byte    $0C, $21, $4A, $0F, $0D
        byte    $02, $41, $D2, $0F, $0D
        byte    $0B, $01, $4A, $0F, $0D
        byte    $02, $61, $D2, $0F, $0D
        byte    $04, $23, $A4, $0F, $15
        byte    $0B, $41, $37, $0F, $0D
        byte    $00, $A1, $EE, $0F, $0D
        byte    $0D, $01, $37, $0F, $0D
        byte    $00, $64, $97, $0F, $0D
        byte    $00, $21, $EE, $0F, $0D
        byte    $08, $40, $9C, $0F, $15
        byte    $05, $A1, $26, $0F, $0D
        byte    $00, $83, $70, $0F, $0D
        byte    $00, $01, $9F, $0F, $0D
        byte    $0E, $24, $55, $0F, $0D
        byte    $02, $60, $93, $0F, $56
        byte    $00, $01, $26, $0F, $0D
        byte    $00, $81, $9F, $0F, $0D
        byte    $0E, $A1, $26, $0F, $0D
        byte    $00, $41, $9F, $0F, $0D
        byte    $00, $24, $17, $0F, $0D
        byte    $0D, $01, $26, $0F, $0D
        byte    $00, $83, $A4, $0F, $0D
        byte    $00, $21, $9F, $0F, $0D
        byte    $0E, $43, $3F, $0F, $1B
        byte    $02, $A1, $9F, $0F, $0D
        byte    $00, $01, $26, $0F, $0D
        byte    $0E, $21, $9F, $0F, $0D
        byte    $00, $81, $26, $0F, $0D
        byte    $0D, $02, $E4, $0F, $1B
        byte    $00, $A1, $9F, $0F, $0D
        byte    $00, $41, $26, $0F, $0D
        byte    $10, $20, $93, $0F, $2B
        byte    $00, $80, $AF, $0F, $0B
        byte    $00, $41, $72, $0F, $2B
        byte    $0E, $A4, $17, $0F, $0D
        byte    $00, $61, $06, $0F, $20
        byte    $0D, $03, $DC, $0F, $0D
        byte    $0D, $83, $70, $0F, $0D
        byte    $03, $A0, $AF, $0F, $1B
        byte    $00, $00, $7B, $0F, $2B
        byte    $00, $21, $5D, $0F, $15
        byte    $0D, $43, $10, $0F, $0D
        byte    $08, $61, $72, $0F, $15
        byte    $06, $82, $BA, $0F, $0D
        byte    $00, $20, $F7, $0F, $0D
        byte    $0D, $40, $E9, $0F, $56
        byte    $03, $A0, $75, $0F, $56
        byte    $00, $22, $93, $0F, $56
        byte    $00, $81, $4A, $0F, $56
        byte    $ff
_end_of_songs
       